/**
 * Copyright 2013 Peergreen S.A.S.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ow2.util.ee.metadata.car.impl.configurator;

import org.ow2.util.archive.api.IArchive;
import org.ow2.util.ee.metadata.car.api.ICarMetadata;
import org.ow2.util.ee.metadata.car.api.ICarView;
import org.ow2.util.ee.metadata.car.impl.CarMetadata;
import org.ow2.util.ee.metadata.car.impl.view.CarViewFactory;
import org.ow2.util.ee.metadata.common.impl.configurator.CommonAnnotationConfigurator;
import org.ow2.util.ee.metadata.common.impl.view.CommonMetadataViewFactory;
import org.ow2.util.ee.metadata.common.impl.view.CommonView;
import org.ow2.util.scan.api.configurator.IAnnotationConfigurator;
import org.ow2.util.scan.api.configurator.IClassConfigurator;
import org.ow2.util.scan.api.configurator.IViewConfigurator;
import org.ow2.util.scan.api.configurator.basic.SessionConfigurator;
import org.ow2.util.scan.api.configurator.basic.ViewConfigurator;
import org.ow2.util.scan.api.metadata.IClassMetadata;

/**
 * CarSessionConfigurator.
 * @author Florent Benoit
 */
public class CarSessionConfigurator extends SessionConfigurator {

    /**
     * archive metadata.
     */
    private final ICarMetadata carMetadata;

    /**
     * annotationParsingDesactived.
     */
    private boolean annotationParsingDesactived;

    /**
     * Constructor.
     * @param warDeployable the web archive
     */
    public CarSessionConfigurator(final IArchive archive) {
        super();
        this.carMetadata = new CarMetadata(archive);

        // add a new view
        IViewConfigurator viewConfigurator =  new ViewConfigurator();
        viewConfigurator.registerView(CommonView.class, new CommonMetadataViewFactory());
        viewConfigurator.registerView(ICarView.class, new CarViewFactory());
        carMetadata.addViewConfigurator(viewConfigurator);
        getViewConfigurators().add(viewConfigurator);


        IAnnotationConfigurator commonAnnotationConfigurator = new CommonAnnotationConfigurator();
        getAnnotationConfigurators().add(commonAnnotationConfigurator);

        //IAnnotationConfigurator wsAnnotationConfigurator = new WebservicesAnnotationConfigurator();
        //getAnnotationConfigurators().add(wsAnnotationConfigurator);

        annotationParsingDesactived = false;
    }

    /**
     * @return the archive metadata
     */
    public ICarMetadata getCarMetadata() {
        return this.carMetadata;
    }

    /**
     * @return true if annotation parsing is desactived
     */
    public boolean isAnnotationParsingDesactived() {
        return this.annotationParsingDesactived;
    }

    /**
     * Set annotationParsingDesactived.
     * @param annotationParsingDesactived true if you want to desactive
     *        annotation parsing
     */
    public void setAnnotationParsingDesactived(final boolean annotationParsingDesactived) {
        this.annotationParsingDesactived = annotationParsingDesactived;
    }

    @Override
    public IClassConfigurator createClassConfigurator(IClassMetadata classMetadata) {
        return new CarClassMetadataConfigurator(classMetadata, this.carMetadata);
    }


}
