/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.car.impl.view;

import javax.security.auth.callback.CallbackHandler;

import org.ow2.util.ee.metadata.car.api.ICarView;
import org.ow2.util.scan.api.metadata.IMetadata;

/**
 * This class represents the annotation metadata of a Bean.<br>
 * From this class, we can access to all methods of a bean with its associated
 * information.
 * @author Florent Benoit
 */
public class CarView implements ICarView {

    private final IMetadata metadata;

    public CarView(IMetadata metadata) {
        this.metadata = metadata;
    }
    /**
     * @return true if this class is the callbackHandler.
     */
    @Override
    public boolean isCallbackHandler() {
        return metadata.getProperty(CallbackHandler.class.getName());
    }

    /**
     * @param callbackHandler true if you want this class becomes the callbackHandler.
     */
    @Override
    public void setCallbackHandler(final boolean callbackHandler) {
        this.metadata.setProperty(CallbackHandler.class.getName(), callbackHandler);
    }

}
