/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.car.impl.xml.parsing;

import org.ow2.util.ee.metadata.common.impl.xml.parsing.IEntityResolver;
import org.ow2.util.xml.SchemaEntityResolver;

/**
 * Entity resolver allowing to find schema within the classloader.
 * @author Florent Benoit
 */
public class CAREntityResolver extends SchemaEntityResolver implements IEntityResolver {

    /**
     * All schemas used by Clients.
     */
    private static final String[] CAR_SCHEMAS = new String[] {PREFIX + EJB31_SCHEMA,
        PREFIX + EJB30_SCHEMA,
        PREFIX + EJB2_SCHEMA,
        PREFIX + CLIENT50_SCHEMA,
        PREFIX + CLIENT60_SCHEMA,
        PREFIX + CLIENT14_SCHEMA,
            PREFIX + JAVAEE5_SCHEMA, PREFIX + J2EE14_SCHEMA,
            PREFIX + JAVAEE_WEBSERVICES12_CLIENT_SCHEMA,
            PREFIX + JAVAEE_WEBSERVICES13_CLIENT_SCHEMA,
            PREFIX + J2EE_WEBSERVICES_CLIENT_SCHEMA, PREFIX + XML_SCHEMA };

    /**
     * All Public ID used by Clients.
     */
    private static final String[] CAR_PUBLIC_IDS = new String[] {
            XMLSCHEMA_PUBLIC_ID,
            DATATYPES_PUBLIC_ID,
            CLIENT12_PUBLIC_ID,
            CLIENT13_PUBLIC_ID
    };

    /**
     * All DTDs filename used by Clients.
     */
    private static final String[] CAR_DTDS = new String[] {
            PREFIX + XMLSCHEMA_DTD,
            PREFIX + DATATYPES_DTD,
            PREFIX + CLIENT12_DTD,
            PREFIX + CLIENT13_DTD
    };


    /**
     * Constructor. Finds the XSD with classloader.
     */
    public CAREntityResolver() {
        super(CAR_SCHEMAS, CAR_PUBLIC_IDS, CAR_DTDS);
    }

}
