/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.car.test;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import javax.jms.JMSException;
import javax.jms.QueueConnectionFactory;


/**
 * Client App sample.
 * @author Gael Lalire
 */
public final class MyClientApp {

    /**
     * Utility class.
     */
    private MyClientApp() {
    }

    /**
     * A resource.
     */
    @Resource(mappedName = "QCF")
    private static QueueConnectionFactory connectionFactory;

    /**
     * My ejb.
     */
    private static IMyEjb myEjb;

    /**
     * Post contruct method.
     */
    @PostConstruct
    public static void myPostConstruct() {
        try {
            connectionFactory.createConnection();
        } catch (JMSException e) {
            e.printStackTrace();
        }
        myEjb.echo();
        System.out.println("myPostConstruct");
    }

    /**
     * Information is in xml.
     */
    public static void myPreDestroy() {
        System.out.println("myPreDestroy");
    }


    /**
     * Main method.
     * @param args the args
     */
    public static void main(final String[] args) {
    }

    /**
     * @param myEjb the myEjb to set
     */
    public static void setMyEjb(final IMyEjb myEjb) {
        MyClientApp.myEjb = myEjb;
    }

}
