/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.car.test;

import static org.testng.Assert.assertNotNull;

import java.io.IOException;
import java.util.Arrays;
import java.util.jar.Attributes;

import org.ow2.util.archive.api.IArchiveMetadata;
import org.ow2.util.archive.impl.MemoryArchive;
import org.ow2.util.ee.metadata.car.api.ICarMetadata;
import org.ow2.util.ee.metadata.car.api.ICarView;
import org.ow2.util.ee.metadata.car.api.exceptions.CARMetadataException;
import org.ow2.util.ee.metadata.car.impl.CarMetadataFactory;
import org.ow2.util.ee.metadata.common.impl.view.CommonView;
import org.ow2.util.scan.api.metadata.IClassMetadata;
import org.ow2.util.scan.api.metadata.IFieldMetadata;
import org.ow2.util.scan.api.metadata.IMethodMetadata;
import org.ow2.util.scan.impl.ASMScannerImpl;
import org.testng.Assert;
import org.testng.annotations.AfterClass;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.Test;

/**
 * @author Gael Lalire
 */
public class TestCarMetadata {

    /**
     * archive.
     */
    private MemoryArchive archive = null;

    /**
     * Create directories for the test.
     * @throws IOException if directories are not created
     */
    @BeforeClass
    public void init() throws IOException {
        archive = new MemoryArchive(IMyEjb.class.getClassLoader(), Arrays.asList(IMyEjb.class.getName(),
                MyClientApp.class.getName(), MyCallbackHandler.class.getName()));
        archive.addResource("META-INF/application-client.xml", TestCarMetadata.class.getResource("application-client.xml"));
        IArchiveMetadata metadata = archive.getMetadata();
        // Add Main-Class entry
        metadata.put(Attributes.Name.MAIN_CLASS.toString(), MyClientApp.class.getName());
    }

    /**
     * Remote the temp folder created at the end of the test.
     */
    @AfterClass
    public void remove() {
    }

    /**
     * The metadata of memory archive.
     */
    private ICarMetadata carMetadata;


    /**
     * Add metadata factory.
     * @throws WARMetadataException
     */
    @Test
    public void testMetadataFactory() throws CARMetadataException {
        CarMetadataFactory metadataFactory = new CarMetadataFactory(new ASMScannerImpl());
        carMetadata = metadataFactory.createArchiveMetadata(archive);
        assertNotNull(carMetadata);
    }


    /**
     * Verify the validity of metadata archive.
     */
    @Test(dependsOnMethods = "testMetadataFactory")
    public void testMetadataValidity() {
        // EJB stateless
        IClassMetadata carClassMetadata = carMetadata.getClassMetadata(MyClientApp.class.getName().replace('.',
                '/'));

        // test @PostConstruct (annotation)
        IMethodMetadata myPostConstruct = carClassMetadata.searchMethodMetadata("myPostConstruct").get(0);
        CommonView myPostConstructView = myPostConstruct.as(CommonView.class);
        Assert.assertTrue(myPostConstructView.isPostConstruct());

        // test @PreDestroy (xml)
        IMethodMetadata myPreDestroy = carClassMetadata.searchMethodMetadata("myPreDestroy").get(0);
        CommonView myPreDestroyView = myPreDestroy.as(CommonView.class);
        Assert.assertTrue(myPreDestroyView.isPreDestroy());

        // test @resource (annotation)
        IFieldMetadata connectionFactory = carClassMetadata.searchFieldMetadata("connectionFactory").get(0);
        CommonView connectionFactoryView = connectionFactory.as(CommonView.class);
        Assert.assertEquals(connectionFactoryView.getJAnnotationResource().getMappedName(), "QCF");

        // test @ejb (xml)
        IFieldMetadata myEjb = carClassMetadata.searchFieldMetadata("myEjb").get(0);
        CommonView myEjbView = myEjb.as(CommonView.class);
        Assert.assertNotNull(myEjbView.getJEjbEJB());

        // test callbackHandler (xml)
        IClassMetadata cbCarClassMetadata = carMetadata.getClassMetadata(MyCallbackHandler.class.getName().replace('.', '/'));
        ICarView cbCarClassMetadataView = cbCarClassMetadata.as(ICarView.class);
        Assert.assertTrue(cbCarClassMetadataView.isCallbackHandler());

        // test env-entry (xml)
       // carDeployableMetadata.getE


    }

}
