/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.api.enc;

import java.util.List;
import java.util.Map;

import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationResource;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationSqlDataSourceDefinition;
import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceContext;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceUnit;
import org.ow2.util.ee.metadata.common.api.struct.IJaxwsWebServiceRef;

/**
 * Manage different types that need to be stored in ENC env.
 * @author Florent BENOIT
 */
public interface IENCBindingHolder {

    /**
     * @return the list of persistence context bindings.
     */
    List<IENCBinding<IJavaxPersistenceContext>> getPersistenceContextBindings();

    /**
     * @return the list of persistence unit bindings.
     */
    List<IENCBinding<IJavaxPersistenceUnit>> getPersistenceUnitBindings();

    /**
     * @return the list of resource bindings.
     */
    List<IENCBinding<IJAnnotationResource>> getResourceBindings();

    /**
     * @return the list of EJB bindings.
     */
    List<IENCBinding<IJEjbEJB>> getEJBBindings();

    /**
     * @return the list of WS bindings.
     */
    List<IENCBinding<IJaxwsWebServiceRef>> getWebServicesBindings();

    /**
     * @param className the name of the class for which the fields are requested
     * @return the injection target enc objects for a given classname
     */
    List<IInjectionTargetEnc> getFieldInjectionTargets(final String className);

    /**
     * @param className the name of the class for which the methods are requested
     * @return the injection target enc objects for a given classname
     */
    List<IInjectionTargetEnc> getMethodInjectionTargets(final String className);

    /**
     * List of fields/method that needs to be set for a given class.
     * @return a map with key = classname and then map = field/attribute name <--> value
     */
    Map<String, Map<String, String>> getInjectionMap();

    List<IENCBinding<IJAnnotationSqlDataSourceDefinition>> getDataSourceBindings();

}
