/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.api.interfaces;

import java.io.Serializable;

/**
 * This interface represents methods which can be call on
 * ClassAnnotationMetadata and MethodAnnotationMetadata.<br>
 * It manages &#64;{@link javax.interceptor.ExcludeDefaultInterceptors} annotation.
 * @author Florent Benoit
 */
public interface IInterceptorExcludeDefaultInterceptors extends Serializable {

    /**
     * @return true if this class won't use default interceptors.
     */
    boolean isExcludedDefaultInterceptors();

    /**
     * Flag this class as a class which exclude default interceptors.
     * @param excludeDefaultInterceptors true if this class is a class which exclude default interceptors.
     */
    void setExcludeDefaultInterceptors(final boolean excludeDefaultInterceptors);

}
