/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.api.interfaces;

import java.io.Serializable;

import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceContext;

/**
 * This interface represents methods which can be call on
 * ClassAnnotationMetadata, MethodAnnotationMetadata and FieldAnnotationMetadata.<br>
 * It manages &#64;{@link javax.persistence.PersistenceContext} annotation.
 * @author Florent Benoit
 */
public interface IPersistenceContext extends Serializable {
    /**
     * @return true if this field is used as a persistence context.
     */
     boolean isPersistenceContext();

    /**
     * @return the persistence context infos.
     */
    IJavaxPersistenceContext getJavaxPersistenceContext();

    /**
     * Sets the persistence context info on this field.
     * @param javaxPersistenceContext information on persistence context.
     */
    void setJavaxPersistenceContext(IJavaxPersistenceContext javaxPersistenceContext);
}
