/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.api.struct;

import java.io.Serializable;

import javax.annotation.Resource.AuthenticationType;

/**
 * Manages Resource annotation.
 * @author Florent BENOIT
 */
public interface IJAnnotationResource extends Serializable {

    /**
     * @return Name (resource to be looked up).
     */
    String getName();

    /**
     * Sets Name (resource to be looked up).
     * @param name the given name.
     */
    void setName(final String name);

    /**
     * @return the authentication type.
     */
    AuthenticationType getAuthenticationType();

    /**
     * Sets the authentication type.
     * @param authenticationType value to set.
     */
    void setAuthenticationType(final AuthenticationType authenticationType);

    /**
     * @return the description.
     */
    String getDescription();

    /**
     * Sets the description.
     * @param description value to set.
     */
    void setDescription(final String description);

    /**
     * @return the lookup name.
     */
    String getLookup();

    /**
     * Sets the lookup.
     * @param lookup name to lookup.
     */
    void setLookup(final String lookup);

    /**
     * @return true if it is shareable.
     */
    boolean isShareable();

    /**
     * Sets the shareable attribute (false/true).
     * @param shareable a boolean.
     */
    void setShareable(final boolean shareable);

    /**
     * @return the type of resource (class).
     */
    String getType();

    /**
     * Sets the class type of this object.
     * @param type the class value (as string format).
     */
    void setType(final String type);

    /**
     * @return MappedName.
     */
    String getMappedName();

    /**
     * Sets mapped Name.
     * @param mappedName the given mappedName.
     */
    void setMappedName(final String mappedName);

    /**
     * @return the message-Destination-Link.
     */
    String getMessageDestinationLink();

    /**
     * Sets the message destination link.
     * @param messageDestinationLink the link value
     */
    void setMessageDestinationLink(String messageDestinationLink);


}
