/**
 * OW2 Utilities
 * Copyright (C) 2009-2012 Bull S.A.S.
 * Contact: utilities@ow2.org
 *
 * Licensed  under the  Apache License,  Version 2.0  (the "License");
 * you may not use  this file  except in  compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed  under the  License is distributed on an "AS IS" BASIS,
 * WITHOUT  WARRANTIES OR CONDITIONS  OF ANY KIND, either  express  or
 * implied.
 *
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.api.struct;

import java.io.Serializable;

/**
 * Manage  &#64;{@link javax.annotation.sql.DataSourceDefinition} metadata
 *
 * @author Loic Albertin
 */
public interface IJAnnotationSqlDataSourceDefinition extends Serializable {
    /**
     * JNDI name by which the data source name will be registered.
     */
    String getName();

    /**
     * JNDI name by which the data source name will be registered.
     *
     * @param name the given JNDI name
     */
    void setName(String name);

    /**
     * DataSource implementation class className.
     */
    String getClassName();

    /**
     * DataSource implementation class className.
     *
     * @param className the given DataSource implementation class name
     */
    void setClassName(String className);

    /**
     * Description of the data source.
     */
    String getDescription();

    /**
     * Description of the data source
     *
     * @param description the given description
     */
    void setDescription(String description);

    /**
     * A JDBC url. If the url property is specified along with other standard DataSource properties such as
     * serverName and
     * portNumber, the more specific properties will take precedence and the url will be ignored
     */
    String getUrl();

    /**
     * A JDBC url. If the url property is specified along with other standard DataSource properties such as
     * serverName and
     * portNumber, the more specific properties will take precedence and the url will be ignored
     *
     * @param url the given JDBC url
     */
    void setUrl(String url);

    /**
     * User name for connection authentications
     */
    String getUser();

    /**
     * User name for connection authentications
     *
     * @param user the given user name
     */
    void setUser(String user);

    /**
     * password for connection authentications
     */
    String getPassword();

    /**
     * password for connection authentications
     *
     * @param password the given password
     */
    void setPassword(String password);

    /**
     * Name of a database on a server
     */
    String getDatabaseName();

    /**
     * Name of a database on a server
     *
     * @param databaseName the given name of the database
     */
    void setDatabaseName(String databaseName);

    /**
     * Port number where a server is listening for requests
     */
    int getPortNumber();

    /**
     * Port number where a server is listening for requests
     *
     * @param portNumber the given port number
     */
    void setPortNumber(int portNumber);

    /**
     * Database server name
     */
    String getServerName();

    /**
     * Database server name
     *
     * @param serverName the given Database server name
     */
    void setServerName(String serverName);

    /**
     * Isolation level for connections.
     */
    int getIsolationLevel();

    /**
     * Isolation level for connections.
     *
     * @param isolationLevel the given isolation level
     */
    void setIsolationLevel(int isolationLevel);

    /**
     * Indicates whether a connection is transactional or not.
     */
    boolean isTransactional();

    /**
     * Indicates whether a connection is transactional or not.
     *
     * @param transactional Indicates whether a connection is transactional or not.
     */
    void setTransactional(boolean transactional);

    /**
     * Number of connections that should be created when a connection pool is initialized
     */
    int getInitialPoolSize();

    /**
     * Number of connections that should be created when a connection pool is initialized
     *
     * @param initialPoolSize the given initial connection pool size
     */
    void setInitialPoolSize(int initialPoolSize);

    /**
     * Maximum number of connections that should be concurrently allocated for a connection pool
     */
    int getMaxPoolSize();

    /**
     * Maximum number of connections that should be concurrently allocated for a connection pool
     *
     * @param maxPoolSize the given maximum connection pool size
     */
    void setMaxPoolSize(int maxPoolSize);

    /**
     * Minimum number of connections that should be allocated for a connection pool
     */
    int getMinPoolSize();

    /**
     * Minimum number of connections that should be allocated for a connection pool
     *
     * @param minPoolSize the given minimum connection pool size
     */
    void setMinPoolSize(int minPoolSize);

    /**
     * The number of seconds that a physical connection should remain unused in the pool before the connection is
     * closed for a
     * connection pool
     */
    int getMaxIdleTime();

    /**
     * The number of seconds that a physical connection should remain unused in the pool before the connection is
     * closed for a connection pool
     *
     * @param maxIdleTime the given maximum idle time
     */
    void setMaxIdleTime(int maxIdleTime);

    /**
     * The total number of statements that a connection pool should keep open. A value of 0 indicates that the
     * caching of
     * statements is disabled for a connection pool.
     */
    int getMaxStatements();

    /**
     * The total number of statements that a connection pool should keep open. A value of 0 indicates that the
     * caching of statements is disabled for a connection pool.
     *
     * @param maxStatements the given maximum statements caching
     */
    void setMaxStatements(int maxStatements);

    /**
     * Used to specify vendor specific properties and less commonly used DataSource properties.
     */
    String[] getProperties();

    /**
     * Used to specify vendor specific properties and less commonly used DataSource properties.
     *
     * @param properties the given properties
     */
    void setProperties(String[] properties);

    /**
     * The maximum time in seconds that this data source will wait while attempting to connect to a database. A value
     * of 0
     * specifies that the timeout is the default system timeout if there is one, otherwise it specifies that there is
     * no timeout
     */
    int getLoginTimeout();

    /**
     * The maximum time in seconds that this data source will wait while attempting to connect to a database. A value
     * of 0
     * specifies that the timeout is the default system timeout if there is one, otherwise it specifies that there is
     * no timeout
     *
     * @param loginTimeout the given login timeout
     */
    void setLoginTimeout(int loginTimeout);
}
