/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.api.xml.struct;

/**
 * Interface used for env-entry element.
 * @author Florent Benoit
 */
public interface IEnvEntry extends IResourceGroup {

    /**
     * Name of this element.
     */
    String NAME = "env-entry";

    /**
     * Sets the description.
     * @param description the description to use
     */
    void setDescription(final String description);

    /**
     * Sets the name.
     * @param envEntryName the name to use
     */
    void setEnvEntryName(final String envEntryName);

    /**
     * Sets the value.
     * @param envEntryValue the value to use
     */
    void setEnvEntryValue(final String envEntryValue);

    /**
     * Sets the type.
     * @param envEntryType the type to use
     */
    void setEnvEntryType(final String envEntryType);

    /**
     * @return the description of the &lt;env-entry&gt; element.
     */
    String getDescription();

    /**
     * @return the name of the &lt;env-entry&gt; element.
     */
    String getEnvEntryName();

    /**
     * @return the value of the &lt;env-entry&gt; element.
     */
    String getEnvEntryValue();

    /**
     * @return the type of the &lt;env-entry&gt; element.
     */
    String getEnvEntryType();

}
