/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.api.xml.struct;

import java.io.Serializable;
import java.util.Map;

import javax.xml.namespace.QName;

/**
 * The IHandler represents a <code>handler</code>.
 *
 * @author Guillaume Sauthier
 */
public interface IHandler extends Serializable {

    /**
     * Name of the XML element.
     */
    static final String NAME = "handler";

    /**
     * @return the handler's name.
     */
    String getHandlerName();

    /**
     * @return the handler's classname.
     */
    String getHandlerClass();

    /**
     * @return the init-params map.
     */
    Map<String, String> getInitParams();

    /**
     * @return the name of the soap-header used by this handler.
     */
    QName getSoapHeader();

    /**
     * @return the soap-role.
     */
    String getSoapRole();
}
