/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.api.xml.struct;

import java.io.Serializable;
import java.util.List;

import javax.xml.namespace.QName;

/**
 * The IHandlerChain represents a <code>handler-chain</code>.
 *
 * @author Guillaume Sauthier
 */
public interface IHandlerChain extends Serializable {

    /**
     * Name of the XML element.
     */
    static final String NAME = "handler-chain";

    /**
     * @return a QName representing a pattern for matching a service name.
     */
    QName getServiceNamePattern();

    /**
     * @return a QName representing a pattern for matching a port name.
     */
    QName getPortNamePattern();

    /**
     * @return a list of protocol bindings IDs
     */
    List<String> getProtocolBindings();

    /**
     * @return the list of <code>handler</code> composing this chain.
     */
    List<IHandler> getHandlers();
}
