/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.api.xml.struct;

import java.io.Serializable;
import java.util.List;

/**
 * Interface used for a method element.
 * @author Florent Benoit
 */
public interface IMethodDD extends Serializable {

    /**
     * Gets the name of the method.
     * @return the method's name.
     */
    String getName();

    /**
     * Sets the name of the method.
     * @param name the name of the method.
     */
    void setName(final String name);

    /**
     * Gets the params of this method.
     * @return the method's name.
     */
    List<String> getParams();

    /**
     * Add a param for this method.
     * @param param the given parameter of the method
     */
    void addParam(final String param);

    /**
     * @return name of the EJB.
     */
    String getEjbName();

    /**
     * Sets the name of the EJB.
     * @param ejbName the given name.
     */
    void setEjbName(final String ejbName);

    /**
     * @return string representation of this module.
     */
    String toString();

}
