/**
 * Copyright 2013 Peergreen S.A.S.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ow2.util.ee.metadata.common.impl.configurator;

import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxAnnotationResourceVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxEjbEJBVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxInterceptorInterceptorsVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxJwsHandlerChainVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxPersistencePersistenceContextVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxPersistencePersistenceUnitVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxXmlWsWebServiceRefVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxAnnotationManagedBeanVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxAnnotationResourcesVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxAnnotationSecurityRunAsVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxAnnotationSqlDataSourceDefinitionVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxAnnotationSqlDataSourceDefinitionsVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxEjbEJBsVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxPersistencePersistenceContextsVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxPersistencePersistenceUnitsVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxXmlWsWebServiceRefsVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.method.JavaxAnnotationPostConstructVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.method.JavaxAnnotationPreDestroyVisitor;
import org.ow2.util.scan.api.configurator.basic.AnnotationConfigurator;

public class CommonAnnotationConfigurator extends AnnotationConfigurator {

    public CommonAnnotationConfigurator() {
        super();
        registerVisitors();
    }

    protected void registerVisitors() {

        // add @PostConstruct
        registerAnnotationVisitor(new JavaxAnnotationPostConstructVisitor());

        // add @PreDestroy
        registerAnnotationVisitor(new JavaxAnnotationPreDestroyVisitor());

        // add @EJB
        registerAnnotationVisitor(new JavaxEjbEJBVisitor());

        // add @Resource
        registerAnnotationVisitor(new JavaxAnnotationResourceVisitor());

        // add @PersistenceContext
        registerAnnotationVisitor(new JavaxPersistencePersistenceContextVisitor());

        // add @PersistenceUnit
        registerAnnotationVisitor(new JavaxPersistencePersistenceUnitVisitor());

        // add @WebServiceRef
        registerAnnotationVisitor(new JavaxXmlWsWebServiceRefVisitor());

        // add @HandlerChain
        registerAnnotationVisitor(new JavaxJwsHandlerChainVisitor());

        // add @EJBs
        this.registerAnnotationVisitor(new JavaxEjbEJBsVisitor());

        // add @Resources
        this.registerAnnotationVisitor(new JavaxAnnotationResourcesVisitor());

        // add @DataSourceDefinition
        this.registerAnnotationVisitor(new JavaxAnnotationSqlDataSourceDefinitionVisitor());

        // add @DataSourceDefinitions
        this.registerAnnotationVisitor(new JavaxAnnotationSqlDataSourceDefinitionsVisitor());

        // add @PersistenceContexts
        this.registerAnnotationVisitor(new JavaxPersistencePersistenceContextsVisitor());

        // add @PersistenceUnits
        this.registerAnnotationVisitor(new JavaxPersistencePersistenceUnitsVisitor());

        // add @WebServiceRefs
        this.registerAnnotationVisitor(new JavaxXmlWsWebServiceRefsVisitor());

        // add @RunAs
        this.registerAnnotationVisitor(new JavaxAnnotationSecurityRunAsVisitor());

         // add @ManagedBeans
        this.registerAnnotationVisitor(new JavaxAnnotationManagedBeanVisitor());

        // add @Interceptors
        registerAnnotationVisitor(new JavaxInterceptorInterceptorsVisitor());

    }

}
