/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.configurator.visitor;

import static java.lang.annotation.ElementType.FIELD;
import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.ElementType.TYPE;

import org.ow2.util.ee.metadata.common.api.struct.IJwsHandlerChain;
import org.ow2.util.ee.metadata.common.impl.struct.JwsHandlerChain;
import org.ow2.util.scan.api.IAnnotationVisitorContext;
import org.ow2.util.scan.api.annotation.VisitorTarget;
import org.ow2.util.scan.api.annotation.VisitorType;
import org.ow2.util.scan.api.visitor.DefaultAnnotationVisitor;

/**
 * This class manages the handling of &#64;{@link javax.jws.HandlerChain}
 * annotation.
 * @author Guillaume Sauthier
 */
@VisitorTarget({TYPE, METHOD, FIELD})
@VisitorType("javax.jws.HandlerChain")
public class JavaxJwsHandlerChainVisitor extends DefaultAnnotationVisitor<IJwsHandlerChain> {

    /**
     * 'file' attribute name.
     */
    private static final String ATTR_FILE = "file";

    /**
     * Visits a primitive value of the annotation.<br>
     * @param name the value name.
     * @param value the actual value, whose type must be {@link Byte},
     *        {@link Boolean}, {@link Character}, {@link Short},
     *        {@link Integer}, {@link Long}, {@link Float}, {@link Double},
     *        {@link String} or {@link org.ow2.util.scan.api.IType}.
     */
    @Override
    public void visit(final String name, final Object value, IAnnotationVisitorContext<IJwsHandlerChain> visitorContext) {
        IJwsHandlerChain jwsHandlerChain = visitorContext.getLocal();
        if (name.equals(ATTR_FILE)) {
            jwsHandlerChain.setFile((String) value);
        }
    }

    /**
     * Visits the end of the annotation.
     */
    @Override
    public void visitEnd(IAnnotationVisitorContext<IJwsHandlerChain> visitorContext) {
        visitorContext.set(visitorContext.getLocal());
    }

    @Override
    public IJwsHandlerChain buildInstance() {
        return new JwsHandlerChain();
    }

}
