/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz;

import static java.lang.annotation.ElementType.TYPE;

import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationManagedBean;
import org.ow2.util.ee.metadata.common.impl.struct.JAnnotationManagedBean;
import org.ow2.util.scan.api.IAnnotationVisitorContext;
import org.ow2.util.scan.api.annotation.VisitorTarget;
import org.ow2.util.scan.api.annotation.VisitorType;
import org.ow2.util.scan.api.visitor.DefaultAnnotationVisitor;

/**
 * @author Loic Albertin
 */
@VisitorTarget(TYPE)
@VisitorType("javax.annotation.ManagedBean")
public class JavaxAnnotationManagedBeanVisitor extends DefaultAnnotationVisitor<IJAnnotationManagedBean> {

    /**
     * Empty visit method.
     * @param name annotation name
     * @param value annotation value
     */
    @Override
    public void visit(final String name, final Object value, IAnnotationVisitorContext<IJAnnotationManagedBean> annotationVisitorContext) {
        IJAnnotationManagedBean annotationManagedBean = annotationVisitorContext.getLocal();
        annotationManagedBean.setName((String) value);
    }


    @Override
    public void visitEnd(IAnnotationVisitorContext<IJAnnotationManagedBean> visitorContext) {
        IJAnnotationManagedBean managedBean = visitorContext.getLocal();
        String value = managedBean.getName();
        if (value == null || value.equals("")) {
            // Set the class name if there is no value
            value = visitorContext.getVisitedMember().getName();
            if (value.contains("/")) {
                value = value.substring(value.lastIndexOf("/") + 1);
            }
            managedBean.setName(value);
        }
        visitorContext.set(managedBean);

    }

    @Override
    public IJAnnotationManagedBean buildInstance() {
        return new JAnnotationManagedBean();
    }
}
