/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz;

import static java.lang.annotation.ElementType.TYPE;

import org.ow2.util.ee.metadata.common.api.struct.IJavaxAnnotationSecurityRunAs;
import org.ow2.util.ee.metadata.common.impl.struct.JAnnotationSecurityRunAs;
import org.ow2.util.scan.api.IAnnotationVisitorContext;
import org.ow2.util.scan.api.annotation.VisitorTarget;
import org.ow2.util.scan.api.annotation.VisitorType;
import org.ow2.util.scan.api.visitor.DefaultAnnotationVisitor;

/**
 * This class manages the handling of &#64;{@link javax.annotation.security.RunAs}
 * annotation.
 * @author Florent Benoit
 */
@VisitorTarget(TYPE)
@VisitorType("javax.annotation.security.RunAs")
public class JavaxAnnotationSecurityRunAsVisitor extends DefaultAnnotationVisitor<IJavaxAnnotationSecurityRunAs> {

    /**
     * Empty visit method.
     * @param name annotation name
     * @param value annotation value
     */
    @Override
    public void visit(final String name, final Object value, IAnnotationVisitorContext<IJavaxAnnotationSecurityRunAs> visitorContext) {
        visitorContext.getLocal().setValue((String) value);
    }
    /**
     * Visits the end of the annotation.<br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd(IAnnotationVisitorContext<IJavaxAnnotationSecurityRunAs> visitorContext) {
        visitorContext.set(visitorContext.getLocal());
    }


    @Override
    public IJavaxAnnotationSecurityRunAs buildInstance() {
        return new JAnnotationSecurityRunAs();
    }}
