/**
 * OW2 Utilities
 * Copyright (C) 2009-2012 Bull S.A.S.
 * Contact: utilities@ow2.org
 *
 * Licensed  under the  Apache License,  Version 2.0  (the "License");
 * you may not use  this file  except in  compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed  under the  License is distributed on an "AS IS" BASIS,
 * WITHOUT  WARRANTIES OR CONDITIONS  OF ANY KIND, either  express  or
 * implied.
 *
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz;

import static java.lang.annotation.ElementType.TYPE;

import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationSqlDataSourceDefinition;
import org.ow2.util.scan.api.IAnnotationVisitor;
import org.ow2.util.scan.api.IAnnotationVisitorContext;
import org.ow2.util.scan.api.annotation.VisitorTarget;
import org.ow2.util.scan.api.annotation.VisitorType;
import org.ow2.util.scan.api.visitor.DefaultAnnotationVisitor;

/**
 * This class manages the handling of &#64;{@link javax.annotation.sql.DataSourceDefinitions} annotation.
 * @author Loic Albertin
 */
@VisitorTarget(TYPE)
@VisitorType("javax.annotation.sql.DataSourceDefinitions")
public class JavaxAnnotationSqlDataSourceDefinitionsVisitor extends DefaultAnnotationVisitor<IJAnnotationSqlDataSourceDefinition> {

    @Override
    public IAnnotationVisitor<IJAnnotationSqlDataSourceDefinition> visitAnnotation(String name, String desc, IAnnotationVisitorContext<IJAnnotationSqlDataSourceDefinition> visitorContext) {
        // delegate
        if ("Ljavax/annotation/sql/DataSourceDefinition;".equals(desc)) {
            return new JavaxAnnotationSqlDataSourceDefinitionVisitor();
        }
        return this;
    }

    @Override
    public IJAnnotationSqlDataSourceDefinition buildInstance() {
        return null;
    }

}
