/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz;

import static java.lang.annotation.ElementType.TYPE;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.struct.IJaxwsWebServiceRef;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxXmlWsWebServiceRefVisitor;
import org.ow2.util.ee.metadata.common.impl.view.CommonView;
import org.ow2.util.scan.api.IAnnotationVisitor;
import org.ow2.util.scan.api.IAnnotationVisitorContext;
import org.ow2.util.scan.api.annotation.VisitorTarget;
import org.ow2.util.scan.api.annotation.VisitorType;
import org.ow2.util.scan.api.visitor.DefaultAnnotationVisitor;

/**
 * This class manages the handling of &#64;{@link javax.xml.ws.WebServiceRefs}
 * annotation.
 * @author Guillaume Sauthier
 */
@VisitorTarget(TYPE)
@VisitorType("javax.xml.ws.WebServiceRefs")
public class JavaxXmlWsWebServiceRefsVisitor extends DefaultAnnotationVisitor<IJaxwsWebServiceRef> {

    @Override
    public IAnnotationVisitor<IJaxwsWebServiceRef> visitAnnotation(String name, String desc, IAnnotationVisitorContext<IJaxwsWebServiceRef> visitorContext) {
        // delegate
        if ("Ljavax/xml/ws/WebServiceRef;".equals(desc)) {
            return new JavaxXmlWsWebServiceRefVisitorWithGlobalScope();
        }
        return this;
    }

    @Override
    public IJaxwsWebServiceRef buildInstance() {
        return null;
    }
}

class JavaxXmlWsWebServiceRefVisitorWithGlobalScope extends JavaxXmlWsWebServiceRefVisitor {

    /**
     * Visits the end of the annotation. <br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd(IAnnotationVisitorContext<IJaxwsWebServiceRef> visitorContext) {
        CommonView commonView = visitorContext.getView(CommonView.class);
        List<IJaxwsWebServiceRef> list = commonView.getJaxwsWebServiceRefs();
        if (list == null) {
            list = new ArrayList<>();
            commonView.setJaxwsWebServiceRefs(list);
        }
        list.add(visitorContext.getLocal());
    }
}

