/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.enc;

import org.ow2.util.ee.metadata.common.api.enc.IENCBinding;

/**
 * JNDI Binding used in ENC for a given type (like persistence context, ejb,
 * etc.).
 * @param <T> the given type
 * @author Florent BENOIT
 */
public class ENCBinding<T> implements IENCBinding<T> {

    /**
     * Name of the binding.
     */
    private String name = null;

    /**
     * Value of the binding.
     */
    private T value = null;

    /**
     * Build the given ENC binding.
     * @param name the given name.
     * @param value the given value.
     */
    public ENCBinding(final String name, final T value) {
        this.name = name;
        this.value = value;
    }

    /**
     * @return the name used for the ENC.
     */
    public String getName() {
        return name;
    }

    /**
     * @return the object associated to the ENC name.
     */
    public T getValue() {
        return value;
    }
}

