/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.struct;

import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;


/**
 * Acts as an implementation of &#64;{@link javax.ejb.EJB} annotation.
 * @author Florent Benoit
 */
public class JEjbEJB implements IJEjbEJB {

    /**
     * Name (resource to be looked up).
     */
    private String name = null;

    /**
     * Business or home Interface.
     */
    private String beanInterface = null;

    /**
     * Bean name (Name of stateless, stateful, etc. or ejb-name).
     */
    private String beanName = null;

    /**
     * mapped name.
     */
    private String mappedName = null;

    /**
     * A portable lookup string containing the JNDI name for the target EJB component.
     */
    private String lookup = null;


    /**
     * Constructor.<br>
     * Build object with default values.
     */
    public JEjbEJB() {
        this.name = "";
        this.beanName = "";
        this.mappedName = null;
    }

    /**
     * @return Name (resource to be looked up).
     */
    public String getName() {
        return name;
    }

    /**
     * Sets Name (resource to be looked up).
     * @param name the given name.
     */
    public void setName(final String name) {
        this.name = name;
    }

    /**
     * @return Bean name (Name of stateless, stateful, etc. or ejb-name).
     */
    public String getBeanName() {
        return beanName;
    }

    /**
     * Sets bean name (Name of stateless, stateful, etc. or ejb-name).
     * @param beanName the given name.
     */
    public void setBeanName(final String beanName) {
        this.beanName = beanName;
    }


    /**
     * @return business or home Interface.
     */
    public String getBeanInterface() {
        return beanInterface;
    }

    /**
     * Sets the business or home Interface.
     * @param beanInterface the given interface.
     */
    public void setBeanInterface(final String beanInterface) {
        this.beanInterface = beanInterface;
    }


    /**
     * @return lookup.
     */
    public String getLookup() {
        return lookup;
    }

    /**
     * Sets lookup the lookup Name.
     * @param lookup the given lookup.
     */
    public void setLookup(final String lookup) {
        this.lookup = lookup;
    }

    /**
     * @return MappedName.
     */
    public String getMappedName() {
        return mappedName;
    }

    /**
     * Sets mapped Name.
     * @param mappedName the given mappedName.
     */
    public void setMappedName(final String mappedName) {
        this.mappedName = mappedName;
    }

    /**
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));

        // name
        sb.append("[name=");
        sb.append(name);

        // mappedName
        sb.append(", mappedName=");
        sb.append(mappedName);

        // beanInterface
        sb.append(", beanInterface=");
        sb.append(beanInterface);

        // property value
        sb.append(", beanName=");
        sb.append(beanName);

        // property value
        if (lookup != null) {
            sb.append(", lookup=");
            sb.append(lookup);
        }

        sb.append("]");
        return sb.toString();
    }
}
