/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.struct;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.struct.IJInterceptors;


/**
 * List of interceptor classes.
 * @author Florent Benoit
 */
public class JInterceptors implements IJInterceptors {

    /**
     * List of classes.
     */
    private List<String> classes = null;

    /**
     * Constructor.
     */
    public JInterceptors() {
        classes = new ArrayList<String>();
    }

    /**
     * Add a class.
     * @param cls name of the class (asm)
     */
    public void addClass(final String cls) {
        classes.add(cls);
    }

    /**
     * @return list of classes.
     */
    public List<String> getClasses() {
        return classes;
    }

    /**
     * @param cls the name of an encoded class.
     * @return true if the class is already in the list.
     */
    public boolean contains(final String cls) {
        return classes.contains(cls);
    }

    /**
     * @return the size.
     */
    public int size() {
        return classes.size();
    }

    /**
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));

        // list
        sb.append(classes);
        return sb.toString();
    }

}
