/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.struct;

import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceUnit;



/**
 * This class allow to set informations on javax.persistence.PersistenceUnit
 * annotation.
 * @author Florent Benoit
 */
public class JavaxPersistenceUnit implements IJavaxPersistenceUnit {

    /**
     * Name of this persistence unit.
     */
    private String name = null;

    /**
     * Unit name of this persistence context.
     */
    private String unitName = null;

    /**
     * Build new object with default values.
     */
    public JavaxPersistenceUnit() {
        // default values
        this.unitName = "";
        this.name = "";
    }

    /**
     * @return the unit name used by this persistence context.
     */
    public String getName() {
        return name;
    }

    /**
     * sets the name of this persistence context.
     * @param name the name of the persistence context
     */
    public void setName(final String name) {
        this.name = name;
    }

    /**
     * @return the unit name used by this persistence context.
     */
    public String getUnitName() {
        return unitName;
    }

    /**
     * sets the unit name of this persistence context.
     * @param unitName the name of the persistence unit
     */
    public void setUnitName(final String unitName) {
        this.unitName = unitName;
    }

}
