/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.struct;

import org.ow2.util.ee.metadata.common.api.struct.IJavaxJwsWebMethod;


/**
 * Acts as an implementation of &#64;{@link javax.jws.WebMethod} annotation.
 * @author Florent Benoit
 */
public class JwsWebMethod implements IJavaxJwsWebMethod {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = 6693679073386907747L;

    /**
     * The action for this operation.
     */
    private String action = null;

    /**
     * excluded ?
     */
    private boolean excluded = false;

    /**
     * The name of the wsdl:operation matching this method.
     */
    private String operationName = null;


    /**
     * Constructor.<br>
     * Build object with default values.
     */
    public JwsWebMethod() {
        this.action = "";
        this.excluded = false;
        this.operationName = "";
    }

    /**
     * @return The action for this operation.
     */
    public String getAction() {
        return action;
    }

    /**
     * Sets the action for this operation.
     * @param action the given action
     */
    public void setAction(final String action) {
        this.action = action;
    }


    /**
     * Sets the exclude flag.
     * @param isExclude true/false
     */
    public void setExclude(final boolean isExclude) {
        this.excluded = isExclude;
    }

    /**
     * @return true if the method is excluded.
     */
    public boolean getExclude() {
        return excluded;
    }

    /**
     * Sets the name of the wsdl:operation matching this method.
     * @param operationName the given operation name
     */
    public void setOperationName(final String operationName) {
        this.operationName = operationName;
    }

    /**
     * @return the name of the wsdl:operation matching this method.
     */
    public String getOperationName() {
        return operationName;
    }

    /**
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));

        // action
        sb.append("[action=");
        sb.append(action);

        // excluded
        sb.append(", excluded=");
        sb.append(excluded);

        // operationName
        sb.append(", operationName=");
        sb.append(operationName);

        sb.append("]");
        return sb.toString();
    }
}
