/**
 * Copyright 2013 Peergreen S.A.S.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ow2.util.ee.metadata.common.impl.view;

import java.util.Collection;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.interfaces.IEnvironmentRefAccessor;
import org.ow2.util.ee.metadata.common.api.interfaces.ISharedMetadataView;
import org.ow2.util.ee.metadata.common.api.struct.IEnvEntry;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationManagedBean;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationResource;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationSqlDataSourceDefinition;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationSqlDataSourceDefinitions;
import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;
import org.ow2.util.ee.metadata.common.api.struct.IJInterceptors;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxAnnotationSecurityRunAs;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceContext;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceUnit;
import org.ow2.util.ee.metadata.common.api.struct.IJaxwsWebServiceRef;
import org.ow2.util.ee.metadata.common.api.struct.IJwsHandlerChain;
import org.ow2.util.ee.metadata.common.api.view.ICommonView;
import org.ow2.util.ee.metadata.common.api.view.IJavaxPersistenceView;
import org.ow2.util.ee.metadata.common.impl.struct.JAnnotationManagedBean;
import org.ow2.util.ee.metadata.common.impl.struct.JAnnotationSqlDataSourceDefinitions;
import org.ow2.util.scan.api.metadata.IMetadata;


public class CommonView implements ICommonView, ISharedMetadataView, IEnvironmentRefAccessor, IJavaxPersistenceView {

    /**
     *
     */
    private static final long serialVersionUID = 5615310949411917279L;
    private final IMetadata metadata;

    public CommonView(IMetadata metadata) {
        this.metadata = metadata;
    }


    /**
     * @return JEjbEJB object representing javax.ejb.EJB annotation.
     */
    @Override
    public final IJEjbEJB getJEjbEJB() {
        return this.metadata.get(IJEjbEJB.class);
    }

    /**
     * Set JAnnotationEJB object.
     * @param jEjbEJB object representing javax.annotation.EJB annotation.
     */
    @Override
    public final void setJEjbEJB(final IJEjbEJB jEjbEJB) {
        this.metadata.set(IJEjbEJB.class, jEjbEJB);
    }

    /**
     * @return JAnnotationResource object representing javax.annotation.Resource
     *         annotation.
     */
    @Override
    public final IJAnnotationResource getJAnnotationResource() {
        return this.metadata.get(IJAnnotationResource.class);
    }

    /**
     * Set JAnnotationResource object.
     * @param jAnnotationResource object representing javax.annotation.Resource
     *        annotation.
     */
    @Override
    public final void setJAnnotationResource(final IJAnnotationResource jAnnotationResource) {
        this.metadata.set(IJAnnotationResource.class,  jAnnotationResource);
    }

    /**
     * @return true if this field is used as a persistence context.
     */
    @Override
    public final boolean isPersistenceContext() {
        return getJavaxPersistenceContext() != null;
    }

    /**
     * @return the persistence context infos.
     */
    @Override
    public final IJavaxPersistenceContext getJavaxPersistenceContext() {
        return metadata.get(IJavaxPersistenceContext.class);
    }

    /**
     * Sets the persistence context info on this field.
     * @param javaxPersistenceContext information on persistence context.
     */
    @Override
    public final void setJavaxPersistenceContext(final IJavaxPersistenceContext javaxPersistenceContext) {
        this.metadata.set(IJavaxPersistenceContext.class,  javaxPersistenceContext);
    }

    /**
     * @return true if this field is used as a persistence unit.
     */
    @Override
    public final boolean isPersistenceUnit() {
        return getJavaxPersistenceUnit() != null;
    }

    /**
     * @return the persistence unit infos.
     */
    @Override
    public final IJavaxPersistenceUnit getJavaxPersistenceUnit() {
        return metadata.get(IJavaxPersistenceUnit.class);
    }

    /**
     * Sets the persistence unit info on this field.
     * @param javaxPersistenceUnit information on persistence unit.
     */
    @Override
    public final void setJavaxPersistenceUnit(final IJavaxPersistenceUnit javaxPersistenceUnit) {
        this.metadata.set(IJavaxPersistenceUnit.class, javaxPersistenceUnit);
    }

    /**
     * @return jEjbEJBs list representing &#64;{@link javax.ejb.EJBs} annotation.
     */
    @Override
    public final List<IJEjbEJB> getJEjbEJBs() {
        return metadata.getProperty("javax.ejb.EJBs");
    }

    /**
     * Set JEjbEJBs object.
     * @param jEjbEJBs list representing javax.ejb.EJBs annotation.
     */
    @Override
    public final void setJEjbEJBs(final List<IJEjbEJB> jEjbEJBs) {
        metadata.setProperty("javax.ejb.EJBs", jEjbEJBs);
    }

    /**
     * @return JAnnotationResources list representing &#64;{@link javax.annotation.Resources} annotation.
     */
    @Override
    public final List<IJAnnotationResource> getJAnnotationResources() {
        return metadata.getProperty("javax.annotation.Resources");
    }

    /**
     * Sets JAnnotationResources object.
     * @param jAnnotationResources list representing javax.annotation.Resources annotation.
     */
    @Override
    public final void setJAnnotationResources(final List<IJAnnotationResource> jAnnotationResources) {
        metadata.setProperty("javax.annotation.Resources", jAnnotationResources);
    }

    @Override
    public List<IJAnnotationSqlDataSourceDefinition> getJAnnotationSqlDataSourceDefinitions() {
        IJAnnotationSqlDataSourceDefinitions list = metadata.get(IJAnnotationSqlDataSourceDefinitions.class);
        if (list == null) {
            list = new JAnnotationSqlDataSourceDefinitions();
            metadata.set(IJAnnotationSqlDataSourceDefinitions.class, list);
        }
        return list.getDatasourceDefinitions();
    }

    @Override
    public void setJAnnotationSqlDataSourceDefinitions(
            List<IJAnnotationSqlDataSourceDefinition> jAnnotationSqlDataSourceDefinitions) {
        IJAnnotationSqlDataSourceDefinitions list = metadata.get(IJAnnotationSqlDataSourceDefinitions.class);
        if (list == null) {
            list = new JAnnotationSqlDataSourceDefinitions();
            metadata.set(IJAnnotationSqlDataSourceDefinitions.class, list);
        }
        list.setDatasourceDefinitions(jAnnotationSqlDataSourceDefinitions);
    }

    /**
     * @return javaxPersistencePersistenceContexts list representing &#64;{@link javax.persistence.PersistenceContexts}
     *         annotation.
     */
    @Override
    public final List<IJavaxPersistenceContext> getJavaxPersistencePersistenceContexts() {
        return metadata.getProperty("javax.annotation.PersistenceContexts");
    }

    /**
     * Sets JavaxPersistencePersistenceContexts object.
     * @param javaxPersistencePersistenceContexts list representing &#64;{@link javax.persistence.PersistenceContexts}
     *        annotation.
     */
    @Override
    public final void setJavaxPersistencePersistenceContexts(
            final List<IJavaxPersistenceContext> javaxPersistencePersistenceContexts) {
        metadata.setProperty("javax.annotation.PersistenceContexts", javaxPersistencePersistenceContexts);
    }

    /**
     * @return javaxPersistencePersistenceUnits list representing &#64;{@link javax.persistence.PersistenceUnits} annotation.
     */
    @Override
    public final List<IJavaxPersistenceUnit> getJavaxPersistencePersistenceUnits() {
        return metadata.getProperty("javax.annotation.PersistenceUnits");
    }

    /**
     * Sets setJavaxPersistencePersistenceUnits object.
     * @param javaxPersistencePersistenceUnits list representing &#64;{@link javax.persistence.PersistenceUnits} annotation.
     */
    @Override
    public final void setJavaxPersistencePersistenceUnits(final List<IJavaxPersistenceUnit> javaxPersistencePersistenceUnits) {
        metadata.setProperty("javax.annotation.PersistenceUnits", javaxPersistencePersistenceUnits);
    }

    /**
     * @return jaxwsWebServiceRefs list representing
     *         &#64;{@link javax.xml.ws.WebServiceRefs} annotation.
     */
    @Override
    public List<IJaxwsWebServiceRef> getJaxwsWebServiceRefs() {
        return metadata.getProperty("javax.xml.ws.WebServiceRefs");
    }

    /**
     * Sets jaxwsWebServiceRefs object.
     *
     * @param jaxwsWebServiceRefs list representing
     *                            &#64;{@link javax.xml.ws.WebServiceRefs} annotation.
     */
    @Override
    public void setJaxwsWebServiceRefs(final List<IJaxwsWebServiceRef> jaxwsWebServiceRefs) {
        this.metadata.setProperty("javax.xml.ws.WebServiceRefs", jaxwsWebServiceRefs);
    }

    /**
     * @return IJWebServiceRef object representing javax.xml.ws.WebServiceRef annotation.
     */
    @Override
    public IJaxwsWebServiceRef getJaxwsWebServiceRef() {
        return metadata.get(IJaxwsWebServiceRef.class);
    }

    /**
     * Set JWebServiceRef object.
     *
     * @param wsr object representing javax.xml.ws.WebServiceRef annotation.
     */
    @Override
    public void setJaxwsWebServiceRef(final IJaxwsWebServiceRef wsr) {
        metadata.set(IJaxwsWebServiceRef.class, wsr);
    }

    /**
     * @return IJwsHandlerChain object representing &#64;{@link javax.jws.HandlerChain} annotation.
     */
    @Override
    public IJwsHandlerChain getJwsHandlerChain() {
        return metadata.get(IJwsHandlerChain.class);
    }

    /**
     * Set JwsHandlerChain object.
     *
     * @param jwshandlerChain object representing &#64;{@link javax.jws.HandlerChain} annotation.
     */
    @Override
    public void setJwsHandlerChain(final IJwsHandlerChain jwshandlerChain) {
        metadata.set(IJwsHandlerChain.class, jwshandlerChain);
    }

    /**
     * Set the value of the run-as property.
     * @param runAs the run-as property.
     */
    public void setRunAs(final String runAsProperty) {
        IJavaxAnnotationSecurityRunAs runAs = metadata.get(IJavaxAnnotationSecurityRunAs.class);
        if (runAs != null) {
            runAs.setValue(runAsProperty);
        }
    }

    /**
     * @return the name of the security-role of the run-as element.
     */
    public String getRunAs() {
        IJavaxAnnotationSecurityRunAs runAs = metadata.get(IJavaxAnnotationSecurityRunAs.class);
        if (runAs != null) {
            return runAs.getValue();
        }
        return null;
    }

    /**
     * Set the name value of a ManagedBean.
     *
     * @param managedBeanName the ManagedBean name.
     */
    @Override
    public void setManagedBeanName(String managedBeanName) {
        IJAnnotationManagedBean managedBean = new JAnnotationManagedBean(managedBeanName);
        metadata.set(IJAnnotationManagedBean.class, managedBean);
    }

    /**
     * Returns the ManagedBean name or null if class is not annotated with @ManagedBean
     *
     * @return the ManagedBean name or null.
     */
    @Override
    public String getManagedBeanName() {
        IJAnnotationManagedBean managedBean = metadata.get(IJAnnotationManagedBean.class);
        if (managedBean != null) {
            return managedBean.getName();
        }
        return null;
    }

    /**
     * Returns true if class is not annotated with @ManagedBean
     * @return true if class is not annotated with @ManagedBean
     */
    @Override
    public boolean isManagedBean() {
        return this.getManagedBeanName() != null;
    }


    /**
     * @return true if method has &#64;{@link javax.annotation.PostConstruct}.
     */
    public boolean isPostConstruct() {
        return metadata.getBoolean("javax.annotation.PostConstruct");
    }

    /**
     * Sets true if method has &#64;{@link javax.annotation.PostConstruct}.
     * @param postConstruct true/false.
     */
    public void setPostConstruct(final boolean postConstruct) {
        metadata.setProperty("javax.annotation.PostConstruct", postConstruct);
    }

    /**
     * @return true if method has &#64;{@link javax.annotation.PreDestroy}.
     */

    public boolean isPreDestroy() {
        return metadata.getBoolean("javax.annotation.PreDestroy");
    }

    /**
     * Sets true if method has &#64;{@link javax.annotation.PreDestroy}.
     * @param preDestroy true/false.
     */
    public void setPreDestroy(final boolean preDestroy) {
        metadata.setProperty("javax.annotation.PreDestroy", preDestroy);
    }


    @Override
    public Collection<? extends IEnvEntry> getEnvEntryCollection() {
        // TODO Auto-generated method stub
        return null;
    }


    @Override
    public void setEnvEntryCollection(Collection<? extends IEnvEntry> envEntryCollection) {
        // TODO Auto-generated method stub

    }


    @Override
    public String getEnvironmentName() {
        // TODO Auto-generated method stub
        return null;
    }


    public void setRolesAllowed(List<String> rolesAllowed) {
        metadata.setProperty("javax.annotation.security.RolesAllowed", rolesAllowed);
    }


    /**
     * @return object representing list of &#64;
     *         {@link javax.interceptor.Interceptors}.
     */
    public IJInterceptors getAnnotationInterceptors() {
        return this.metadata.get(IJInterceptors.class);
    }

    /**
     * Sets the object representing the &#64;
     * {@link javax.interceptor.Interceptors} annotation.
     * @param annotationInterceptors list of classes
     */
    public void setAnnotationsInterceptors(final IJInterceptors annotationInterceptors) {
        this.metadata.set(IJInterceptors.class, annotationInterceptors);
    }

    /**
     * This class has PermitAll annotation.
     * @param permitAll the boolean value.
     */
    public void setPermitAll(final boolean permitAll) {
        this.metadata.setProperty("metadata.common.permitAll", permitAll);
    }

    /**
     * @return true if PermitAll annotation.
     */
    public boolean hasPermitAll() {
        return this.metadata.getProperty("metadata.common.permitAll");
    }

    /**
     * @return true if this class won't use default interceptors.
     */
    public boolean isExcludedDefaultInterceptors() {
        return this.metadata.getBoolean("common.metadata.excludeDefaultInterceptors");
    }

    /**
     * Flag this class as a class which exclude default interceptors.
     * @param excludeDefaultInterceptors true if this class is a class which
     *        exclude default interceptors.
     */
    public void setExcludeDefaultInterceptors(final boolean excludeDefaultInterceptors) {
        this.metadata.setProperty("common.metadata.excludeDefaultInterceptors", excludeDefaultInterceptors);
    }

}
