/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.xml.parsing;

import java.net.URL;

import org.w3c.dom.Element;

/**
 * Common stuff for parsing XML files.
 * @author Florent BENOIT
 */
public abstract class AbsDeploymentDescLoader {

    /**
     * Java EE namespace (Java EE).
     */
    public static final String JAVAEE_NS = "http://java.sun.com/xml/ns/javaee";

    /**
     * J2EE namespace (J2EE).
     */
    public static final String J2EE_NS = "http://java.sun.com/xml/ns/j2ee";

    /**
     * Validating with schema ?
     */
    private static boolean validating = true;

    /**
     * URL of the file being analyzed.
     */
    private URL url = null;

    /**
     * Namespace to use when analyzing the XML file. It depends if the archive is J2EE or Java EE module.
     */
    private String xmlns = "*";

    /**
    * Create a new Desc Loader for the given URL.
     * @param url the url that is pointing to the EJB Xml file.
     */
    protected AbsDeploymentDescLoader(final URL url) {
        this.url = url;
    }

    /**
     * @return the URL used by this loader.
     */
    protected URL getURL() {
        return url;
    }

    /**
     * @return true if the deployment is being validated.
     */
    public static boolean isValidating() {
        return validating;
    }

    /**
     * Set the flag XML validation
     * @param flag
     */
     public void setValidating(boolean flag) {
        validating =flag;
    }
    
    /**
     * Defines the namespace that needs to be used for this XML parsing.
     * @param element the DOM element used to get the namespace.
     * @throws ParsingException if no namespace is found
     */
    protected void defineXMLNS(final Element element) throws ParsingException {
        // get the namespace of this element
        String ns = element.getNamespaceURI();
        if (JAVAEE_NS.equals(ns)) {
            this.xmlns = JAVAEE_NS;
        } else if (J2EE_NS.equals(ns)) {
            this.xmlns = J2EE_NS;
        } else {
            throw new ParsingException("Unsupported XML namespace: " + ns);
        }
    }

    /**
     * @return the Namespace to use when analyzing the XML file.
     */
    protected String getXMLNS() {
        return xmlns;
    }

}
