/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.xml.parsing;


/**
 * Defines some constants.
 * @author Florent BENOIT
 */
public interface IEntityResolver {

    /**
     * Schema prefix.
     */
    String PREFIX = "org/ow2/util/ee/metadata/common/impl/xml/";

    /**
     * Client 5.0 Schema.
     */
    String CLIENT50_SCHEMA = "application-client_5.xsd";

    /**
     * Client 6.0 Schema.
     */
    String CLIENT60_SCHEMA = "application-client_6.xsd";

    /**
     * Client 1.4 Schema.
     */
    String CLIENT14_SCHEMA = "application-client_1_4.xsd";

    /**
     * Client 1.3 DTD.
     */
    String CLIENT13_DTD = "application-client_1_3.dtd";

    /**
     * Client 1.3 Public ID.
     */
    String CLIENT13_PUBLIC_ID = "-//Sun Microsystems, Inc.//DTD J2EE Application Client 1.3//EN";

    /**
     * Client 1.2 DTD.
     */
    String CLIENT12_DTD = "application-client_1_2.dtd";

    /**
     * Client 1.2 Public ID.
     */
    String CLIENT12_PUBLIC_ID = "-//Sun Microsystems, Inc.//DTD J2EE Application Client 1.2//EN";

    /**
     * XML Schema DTD.
     */
    String XMLSCHEMA_DTD = "XMLSchema.dtd";

    /**
     * XML Schema Public ID.
     */
    String XMLSCHEMA_PUBLIC_ID = "-//W3C//DTD XMLSCHEMA 200102//EN";

    /**
     * Datatypes DTD.
     */
    String DATATYPES_DTD = "datatypes.dtd";

    /**
     * Datatypes Public ID.
     */
    String DATATYPES_PUBLIC_ID = "datatypes";

    /**
     * EJB 3.0 Schema.
     */
    String EJB30_SCHEMA = "ejb-jar_3_0.xsd";

    /**
     * EJB 3.1 Schema.
     */
    String EJB31_SCHEMA = "ejb-jar_3_1.xsd";

    /**
     * EJB 2.1 Schema.
     */
    String EJB2_SCHEMA = "ejb-jar_2_1.xsd";

    /**
     * JSP 2.0 Schema.
     */
    String JSP20_SCHEMA = "jsp_2_0.xsd";

    /**
     * JSP 2.0 Schema.
     */
    String JSP21_SCHEMA = "jsp_2_1.xsd";

    /**
     * JSP 2.2 Schema.
     */
    String JSP22_SCHEMA = "jsp_2_2.xsd";

    /**
     * WebApp 2.4 Schema.
     */
    String WEBAPP24_SCHEMA = "web-app_2_4.xsd";

    /**
     * WebApp 2.5 Schema.
     */
    String WEBAPP25_SCHEMA = "web-app_2_5.xsd";

    /**
     * WebApp Common 3.0 Schema.
     */
    String WEBAPPCOMMON30_SCHEMA = "web-common_3_0.xsd";

    /**
     * WebApp 3.0 Schema.
     */
    String WEBAPP30_SCHEMA = "web-app_3_0.xsd";

    /**
     * WebApp 2.2 DTD.
     */
    String WEBAPP22_DTD = "web-app_2_2.dtd";

    /**
     * WebApp 2.2 Public ID.
     */
    String WEBAPP22_PUBLIC_ID = "-//Sun Microsystems, Inc.//DTD Web Application 2.2//EN";

    /**
     * Client 1.2 DTD.
     */
    String WEBAPP23_DTD  = "web-app_2_3.dtd";

    /**
     * Client 1.2 Public ID.
     */
    String WEBAPP23_PUBLIC_ID  = "-//Sun Microsystems, Inc.//DTD Web Application 2.3//EN";

    /**
     * JAVA EE 6 Schema.
     */
    String JAVAEE6_SCHEMA = "javaee_6.xsd";

    /**
     * JAVA EE 5 Schema.
     */
    String JAVAEE5_SCHEMA = "javaee_5.xsd";

    /**
     * J2EE 1.4 Schema.
     */
    String J2EE14_SCHEMA = "j2ee_1_4.xsd";

    /**
     * JAVA EE Web services 1.3 client Schema.
     */
    String JAVAEE_WEBSERVICES13_CLIENT_SCHEMA = "javaee_web_services_client_1_3.xsd";


    /**
     * JAVA EE Web services 1.2 client Schema.
     */
    String JAVAEE_WEBSERVICES12_CLIENT_SCHEMA = "javaee_web_services_client_1_2.xsd";

    /**
     * J2EE Web services client Schema.
     */
    String J2EE_WEBSERVICES_CLIENT_SCHEMA = "j2ee_web_services_client_1_1.xsd";

    /**
     * JAVA EE Web services 1.3 schema.
     */
    String JAVAEE_WEBSERVICES13_SCHEMA = "javaee_web_services_1_3.xsd";


    /**
     * JAVA EE Web services 1.2 schema.
     */
    String JAVAEE_WEBSERVICES12_SCHEMA = "javaee_web_services_1_2.xsd";

    /**
     * J2EE Web services 1.1 Schema.
     */
    String J2EE_WEBSERVICES11_SCHEMA = "j2ee_web_services_1_1.xsd";

    /**
     * Handler Chains (JSR 181 2.0) Schema.
     */
    String JAVAEE_HANDLER_CHAINS_SCHEMA = "javaee_web_services_metadata_handler_2_0.xsd";

    /**
     * XML schema.
     */
    String XML_SCHEMA = "xml.xsd";

}
