/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.xml.struct;

import org.ow2.util.ee.metadata.common.api.xml.struct.ICommonEJBRef;

/**
 * Class representing ejb-ref elements used in Java EE components.
 * @author Florent Benoit
 */
public class AbsEJBRef extends AbsResourceGroup implements ICommonEJBRef {

    /**
     * Default constructor.
     */
    public AbsEJBRef() {
        super();
    }

    /**
     * Name of this ejb-ref.
     */
    private String ejbRefName = null;

    /**
     * Type of this ejb-ref.
     */
    private String ejbRefType = null;

    /**
     * EJB-Link.
     */
    private String ejbLink = null;

    /**
     * @return the ejb-link value
     */
    public String getEjbLink() {
        return ejbLink;
    }

    /**
     * Sets the ejb-link value.
     * @param ejbLink value of ejb-link element
     */
    public void setEjbLink(final String ejbLink) {
        this.ejbLink = ejbLink;
    }

    /**
     * @return name of this ejb-ref
     */
    public String getEjbRefName() {
        return ejbRefName;
    }

    /**
     * Sets the name of this ejb-ref.
     * @param ejbRefName name of this reference
     */
    public void setEjbRefName(final String ejbRefName) {
        this.ejbRefName = ejbRefName;
    }

    /**
     * @return the type of this ejb-ref.
     */
    public String getEjbRefType() {
        return ejbRefType;
    }

    /**
     * Sets the type of this reference.
     * @param ejbRefType type of reference
     */
    public void setEjbRefType(final String ejbRefType) {
        this.ejbRefType = ejbRefType;
    }

}
