/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.xml.struct;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.xml.struct.IInjectionTarget;
import org.ow2.util.ee.metadata.common.api.xml.struct.IResourceGroup;

/**
 * Defines the java EE resourceGroup type.<br>
 * It defines mapped-name and injection-target
 * @author Florent Benoit
 */
public class AbsResourceGroup implements IResourceGroup {


    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = 2664044278558086531L;

    /**
     * Injection target (if any).
     */
    private List<IInjectionTarget> injectionTargetList = null;

    /**
     * Default constructor.
     */
    public AbsResourceGroup() {
        injectionTargetList = new ArrayList<IInjectionTarget>();
    }

    /**
     * Mapped name.
     */
    private String mappedName = null;
    
    /**
     * Lookup name.
     */
    private String lookupName = null;

    /**
     * Gets the mapped name.
     * @return the mapped name
     */
    public String getMappedName() {
        return mappedName;
    }

    /**
     * Set the mapped name.
     * @param mappedName the given mapped name.
     */
    public void setMappedName(final String mappedName) {
        this.mappedName = mappedName;
    }

    /**
     * @return the injectionTarget list
     */
    public List<IInjectionTarget> getInjectionTargetList() {
        return injectionTargetList;
    }

    /**
     * Adds the igiven njection target value.
     * @param injectionTarget value of injectionTarget element
     */
    public void addInjectionTarget(final IInjectionTarget injectionTarget) {
        injectionTargetList.add(injectionTarget);
    }
    
    /**
     * @return lookup.
     */
    public String getLookupName() {
        return lookupName;
    }

    /**
     * Sets lookup the lookup Name.
     * @param lookupName the given lookup.
     */
    public void setLookupName(final String lookupName) {
        this.lookupName = lookupName;
    }
}
