/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.xml.struct;

import org.ow2.util.ee.metadata.common.api.xml.struct.IEnvEntry;

/**
 * This class defines the implementation of the &lt;env-entry&gt; element.
 * @author Florent Benoit
 */
public class EnvEntry extends AbsResourceGroup implements IEnvEntry {

    /**
     * Description of the &lt;env-entry&gt; element.
     */
    private String description = null;

    /**
     * Name of the &lt;env-entry&gt; element.
     */
    private String envEntryName = null;

    /**
     * Value of the &lt;env-entry&gt; element.
     */
    private String envEntryValue = null;

    /**
     * Type of the &lt;env-entry&gt; element.
     */
    private String envEntryType = null;

    /**
     * Sets the description.
     * @param description the description to use
     */
    public void setDescription(final String description) {
        this.description = description;
    }

    /**
     * Sets the name.
     * @param envEntryName the name to use
     */
    public void setEnvEntryName(final String envEntryName) {
        this.envEntryName = envEntryName;
    }

    /**
     * Sets the value.
     * @param envEntryValue the value to use
     */
    public void setEnvEntryValue(final String envEntryValue) {
        this.envEntryValue = envEntryValue;
    }

    /**
     * Sets the type.
     * @param envEntryType the type to use
     */
    public void setEnvEntryType(final String envEntryType) {
        this.envEntryType = envEntryType;
    }

    /**
     * @return the description of the &lt;env-entry&gt; element.
     */
    public String getDescription() {
        return description;
    }

    /**
     * @return the name of the &lt;env-entry&gt; element.
     */
    public String getEnvEntryName() {
        return envEntryName;
    }

    /**
     * @return the value of the &lt;env-entry&gt; element.
     */
    public String getEnvEntryValue() {
        return envEntryValue;
    }

    /**
     * @return the type of the &lt;env-entry&gt; element.
     */
    public String getEnvEntryType() {
        return envEntryType;
    }
}
