/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.xml.struct;

import org.ow2.util.ee.metadata.common.api.xml.struct.IHandler;

import javax.xml.namespace.QName;
import java.util.Map;
import java.util.HashMap;

/**
 * The Handler is the representatn of the XML element <code>handler</code>
 *
 * @author Guillaume Sauthier
 */
public class Handler implements IHandler {

    /**
     * handler's name.
     */
    private String handlerName;

    /**
     * Handler's class.
     */
    private String handlerClass;

    /**
     * Handler's initialisation params.
     */
    private Map<String, String> initParams = new HashMap<String, String>();

    /**
     * SOAP header.
     */
    private QName soapHeader;

    /**
     * SOAP role.
     */
    private String soapRole;

    public Handler(String handlerName, String handlerClass) {
        this.handlerName = handlerName;
        this.handlerClass = handlerClass;
    }

    /**
     * @return the handler's name.
     */
    public String getHandlerName() {
        return handlerName;
    }

    /**
     * @return the handler's classname.
     */
    public String getHandlerClass() {
        return handlerClass;
    }

    /**
     * @return the init-params map.
     */
    public Map<String, String> getInitParams() {
        return initParams;
    }

    public void addInitParam(String name, String value) {
        this.initParams.put(name, value);
    }

    /**
     * @return the name of the soap-header used by this handler.
     */
    public QName getSoapHeader() {
        return soapHeader;
    }

    public void setSoapHeader(QName soapHeader) {
        this.soapHeader = soapHeader;
    }

    /**
     * @return the soap-role.
     */
    public String getSoapRole() {
        return soapRole;
    }

    public void setSoapRole(String soapRole) {
        this.soapRole = soapRole;
    }
}
