/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.xml.struct;

import org.ow2.util.ee.metadata.common.api.xml.struct.IHandlerChain;
import org.ow2.util.ee.metadata.common.api.xml.struct.IHandler;

import javax.xml.namespace.QName;
import java.util.List;
import java.util.ArrayList;

/**
 * The HandlerChain is the representant of the XML element <code>handler-chain</code>
 *
 * @author Guillaume Sauthier
 */
public class HandlerChain implements IHandlerChain {

    /**
     * Pattern matching service name.
     */
    private QName serviceNamePattern;

    /**
     * Pattern matching port name.
     */
    private QName portNamePattern;

    /**
     * List of requested protocol bindings ID.
     */
    private List<String> protocolBindings = new ArrayList<String>();

    /**
     * List of handlers cpomposing this chain.
     */
    private List<IHandler> handlers = new ArrayList<IHandler>();

    /**
     * @return a QName representing a pattern for matching a service name.
     */
    public QName getServiceNamePattern() {
        return serviceNamePattern;
    }

    public void setServiceNamePattern(QName serviceNamePattern) {
        this.serviceNamePattern = serviceNamePattern;
    }

    /**
     * @return a QName representing a pattern for matching a port name.
     */
    public QName getPortNamePattern() {
        return portNamePattern;
    }

    public void setPortNamePattern(QName portNamePattern) {
        this.portNamePattern = portNamePattern;
    }

    /**
     * @return a list of protocol bindings IDs
     */
    public List<String> getProtocolBindings() {
        return protocolBindings;
    }

    public void addProtocolBinding(String binding) {
        this.protocolBindings.add(binding);
    }

    /**
     * @return the list of <code>handler</code> composing this chain.
     */
    public List<IHandler> getHandlers() {
        return handlers;
    }

    public void addHandler(IHandler handler) {
        this.handlers.add(handler);
    }
}
