/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.xml.struct;

import java.util.LinkedList;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.xml.struct.IMethodDD;

/**
 * This class defines the &lt;method&gt; element.
 * @author Florent Benoit
 */
public class MethodDD implements IMethodDD {

    /**
     * Name of the method.
     */
    private String name = null;

    /**
     * List of params.
     */
    private List<String> params = null;

    /**
     * EJB-Name associated to this method.
     */
    private String ejbName = null;

    /**
     * Default constructor.
     */
    public MethodDD() {
        
    }

    /**
     * Gets the name of the method.
     * @return the method's name.
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the name of the method.
     * @param name the name of the method.
     */
    public void setName(final String name) {
        this.name = name;
    }

    /**
     * Gets the params of this method.
     * @return the method's name.
     */
    public List<String> getParams() {
        return params;
    }

    /**
     * Add a param for this method.
     * @param param the given parameter of the method
     */
    public void addParam(final String param) {
        initParams();
        params.add(param);
    }

    /**
     * @return name of the EJB.
     */
    public String getEjbName() {
        return ejbName;
    }

    /**
     * Sets the name of the EJB.
     * @param ejbName the given name.
     */
    public void setEjbName(final String ejbName) {
        this.ejbName = ejbName;
    }
    
    /**
     * Initialize the list of parameters.
     */
    public void initParams() {
        if (this.params == null) {
            this.params = new LinkedList<String>(); 
        }
    }

    /**
     * @return string representation of this module.
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder(MethodDD.class.getSimpleName());
        sb.append("[name=");
        sb.append(name);

        if (ejbName != null) {
            sb.append(", ejbName=");
            sb.append(ejbName);
        }

        if (params != null && params.size() > 0) {
            sb.append(", params={");
            for (String param : params) {
                sb.append(param);
                sb.append(",");
            }
            sb.append("}");
        }
        sb.append("]");
        return sb.toString();
    }
}
