/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.xml.struct;

import java.util.Properties;

import org.ow2.util.ee.metadata.common.api.xml.struct.IPortComponentRef;

/**
 * This class defines the implementation of the &lt;port-component-ref&gt; element.
 * @author Guillaume Sauthier
 */
public class PortComponentRef implements IPortComponentRef {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = -8508665352218354998L;

    /**
     * Service Endpoint Interface of the &lt;port-component-ref&gt; element.
     */
    private String serviceEndpointInterface = null;

    /**
     * Is MTOM enabled of the &lt;port-component-ref&gt; element.
     */
    private boolean enableMTOM = false;

    /**
     * PortComponent link of the &lt;port-component-ref&gt; element.
     */
    private String portComponentLink = null;

    /**
     * Stub properties.
     */
    private Properties stubProperties = null;

    /**
     * Default constructor.
     */
    public PortComponentRef() {
        this.stubProperties = new Properties();
    }



    public boolean isEnableMTOM() {
        return enableMTOM;
    }

    public void setEnableMTOM(final boolean enableMTOM) {
        this.enableMTOM = enableMTOM;
    }

    public String getPortComponentLink() {
        return portComponentLink;
    }

    public void setPortComponentLink(final String portComponentLink) {
        this.portComponentLink = portComponentLink;
    }

    public String getServiceEndpointInterface() {
        return serviceEndpointInterface;
    }

    public void setServiceEndpointInterface(final String serviceEndpointInterface) {
        this.serviceEndpointInterface = serviceEndpointInterface;
    }

    /**
     * Sets stub properties.
     * @param stubProperties the given properties
     */
    public void setStubProperties(final Properties stubProperties) {
        this.stubProperties = stubProperties;
    }

    /**
     * @return stub properties
     */
    public Properties getStubProperties() {
        return stubProperties;
    }
}
