/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.xml.struct;

import java.net.URI;
import java.util.ArrayList;
import java.util.List;

import javax.xml.namespace.QName;

import org.ow2.util.ee.metadata.common.api.xml.struct.IPortComponentRef;
import org.ow2.util.ee.metadata.common.api.xml.struct.IServiceRef;
import org.ow2.util.ee.metadata.common.api.xml.struct.IHandlerChains;

/**
 * Class representing service-ref elements used in Java EE components.
 * @author Guillaume Sauthier
 */
public class ServiceRef extends AbsResourceGroup implements IServiceRef {
    /**
     * Name of this service-ref.
     */
    private String name;

    /**
     * Interface of the service. (javax.xml.rpc.Service or javax.xml.ws.Service)
     */
    private String serviceInterface;

    /**
     * Type of this service-ref.
     */
    private String serviceRefType;

    /**
     * WSDL file (relative to the root of this module).
     */
    private URI wsdlFile;

    /**
     * Name of the wsdl:service element refered to.
     */
    private QName serviceQName;

    /**
     * List of this service's port-components.
     */
    private List<IPortComponentRef> portComponentRefList;

    /**
     * the handler-chains.
     */
    private IHandlerChains handlerChains = null;

    /**
     * Constructs an empty ServiceRef element.
     */
    public ServiceRef() {
        portComponentRefList = new ArrayList<IPortComponentRef>();
    }

    public String getName() {
        return name;
    }

    public void setName(final String name) {
        this.name = name;
    }

    public String getServiceInterface() {
        return serviceInterface;
    }

    public void setServiceInterface(final String serviceInterface) {
        this.serviceInterface = serviceInterface;
    }

    public QName getServiceQName() {
        return serviceQName;
    }

    public void setServiceQName(final QName serviceQName) {
        this.serviceQName = serviceQName;
    }

    public String getServiceRefType() {
        return serviceRefType;
    }

    public void setServiceRefType(final String serviceRefType) {
        this.serviceRefType = serviceRefType;
    }

    public URI getWsdlFile() {
        return wsdlFile;
    }

    public void setWsdlFile(final URI wsdlFile) {
        this.wsdlFile = wsdlFile;
    }

    public void addPortComponentRef(final IPortComponentRef portComponentRef) {
        portComponentRefList.add(portComponentRef);
    }

    public List<IPortComponentRef> getPortComponentRefList() {
        return portComponentRefList;
    }

    public void setHandlerChains(final IHandlerChains handlerChains) {
        this.handlerChains = handlerChains;
    }

    public IHandlerChains getHandlerChains() {
        return handlerChains;
    }
}
