/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl;

import java.util.Arrays;
import java.util.List;
import java.util.Map;

import org.ow2.util.archive.impl.MemoryArchive;
import org.ow2.util.scan.api.metadata.IClassMetadata;
import org.ow2.util.scan.api.metadata.IFieldMetadata;
import org.ow2.util.scan.api.metadata.IMethodMetadata;
import org.testng.annotations.BeforeTest;
import org.testng.annotations.Test;

/**
 * @author Guillaume Sauthier
 */
public abstract class AbstractAnnotationParsingTestCase {

    protected IClassMetadata classMetadata = null;

    @BeforeTest
    protected void setUp() {
        classMetadata = null;
    }

    protected IFieldMetadata getUniqueFieldMetadata(final String fieldName) {
        List<IFieldMetadata> fields = classMetadata.searchFieldMetadata(fieldName);

        org.testng.Assert.assertNotNull(fields);
        org.testng.Assert.assertEquals(1, fields.size(), "Wrong number of '" + fieldName + "' fields");

        return fields.get(0);
    }

    protected IMethodMetadata getUniqueMethodMetadata(final String methodName) {
        List<IMethodMetadata> methodMetadatas = classMetadata.searchMethodMetadata(methodName);

        org.testng.Assert.assertNotNull(methodMetadatas);
        org.testng.Assert.assertEquals(1, methodMetadatas.size(), "Wrong number of '" + methodName + "' methods");

        return methodMetadatas.get(0);
    }

    @Test
    public void createMetadata() throws Exception {

        // List of classnames to init class scan
        List<String> classnames = Arrays.asList(getParsedClassName());

        // Creates a virtual/in-memory IArchive that only contains the class
        // under test
        MemoryArchive archive = new MemoryArchive(getParsedClassClassLoader(), classnames);

        // Creates a MetadataFactory that supports only common annotation
        // parsing
        TestCommonDeployableMetadataFactory factory = new TestCommonDeployableMetadataFactory();

        // Parse the clazz
        Map<String, IClassMetadata> map = null;
        try {
            map = factory.createDeployableMetadata(classnames, false, archive);
        } catch (Exception e) {
            e.printStackTrace(System.err);
            throw e;
        }

        // Return the parsed structure of metadata
        String type = getParsedClassName();
        classMetadata = map.get(type);
    }

    protected abstract String getParsedClassName();
    protected abstract ClassLoader getParsedClassClassLoader();
}
