/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl;

import java.net.URL;

import org.ow2.util.ee.metadata.common.api.xml.struct.IEnvironment;
import org.ow2.util.ee.metadata.common.impl.xml.parsing.CommonDeploymentDescLoader;
import org.ow2.util.ee.metadata.common.impl.xml.parsing.ParsingException;
import org.ow2.util.xml.DocumentParser;
import org.ow2.util.xml.DocumentParserException;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

/**
 * Created by IntelliJ IDEA.
 * User: sauthieg
 * Date: 6 août 2008
 * Time: 18:10:41
 * To change this template use File | Settings | File Templates.
 */
public class CommonDeploymentDescLoaderTested extends CommonDeploymentDescLoader {

    /**
     * Utility class, no public constructor.
     *
     * @param url the url that is pointing to the EJB Xml file.
     */
    public CommonDeploymentDescLoaderTested(final URL url) {
        super(url);
    }

    /**
     * Analyze the environment (could be a bean, servlet, etc).
     *
     * @param envElement the dom element.
     * @param env        the structure representing object.
     */
    @Override
    public synchronized void analyzeEnvironment(final Element envElement, final IEnvironment env) {
        super.analyzeEnvironment(envElement, env);
    }

    public synchronized Element parse() throws ParsingException {
        // Get document
        Document document = null;
        try {
            document = DocumentParser.getDocument(getURL(), false, null);
        } catch (DocumentParserException e) {
            throw new ParsingException("Cannot parse the url", e);
        }

        // Root element
        Element rootElement = document.getDocumentElement();

        // Lets find the first child Element
        NodeList list = rootElement.getChildNodes();
        Element first = null;
        int i = 0;
        while (first == null) {
            Node node = list.item(i);
            if (node instanceof Element) {
                first = (Element) node;
            }
            i++;
        }

        // Define NS
        defineXMLNS(first);

        return rootElement;
    }
}
