/**
 * OW2 Utilities
 * Copyright (C) 2009-2012 Bull S.A.S.
 * Contact: utilities@ow2.org
 *
 * Licensed  under the  Apache License,  Version 2.0  (the "License");
 * you may not use  this file  except in  compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed  under the  License is distributed on an "AS IS" BASIS,
 * WITHOUT  WARRANTIES OR CONDITIONS  OF ANY KIND, either  express  or
 * implied.
 *
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl;

import java.util.List;

import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationSqlDataSourceDefinition;
import org.ow2.util.ee.metadata.common.impl.clazz.DataSourceDefinitionsClass;
import org.ow2.util.ee.metadata.common.impl.view.CommonView;
import org.testng.Assert;
import org.testng.annotations.Test;

/**
 * @author Loic Albertin
 */
public class DataSourceDefinitionsParsingTestCase extends AbstractAnnotationParsingTestCase {


    @Test(dependsOnMethods = "createMetadata")
    public void testAllAttributesParsed() throws Exception {
        CommonView view = classMetadata.as(CommonView.class);


        List<IJAnnotationSqlDataSourceDefinition> jAnnotationSqlDataSourceDefinitions =
            view.getJAnnotationSqlDataSourceDefinitions();
        Assert.assertNotNull(jAnnotationSqlDataSourceDefinitions, "annotation not found on Class");
        Assert.assertEquals(jAnnotationSqlDataSourceDefinitions.size(), 2, "annotation not properly parsed");

        for (IJAnnotationSqlDataSourceDefinition jAnnotationSqlDataSourceDefinition :
            jAnnotationSqlDataSourceDefinitions) {
            if ("java:app/AcmeDataSourceName".equals(jAnnotationSqlDataSourceDefinition.getName())) {
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getClassName(), "com.acme.driver");
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getUrl(), "jdbc://acme@acme/acmedb");
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getDatabaseName(), "");
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getDescription(), "");
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getPassword(), "");
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getServerName(), "localhost");
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getUser(), "");
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getInitialPoolSize(), -1);
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getIsolationLevel(), -1);
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getLoginTimeout(), 0);
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getMaxIdleTime(), -1);
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getMaxPoolSize(), -1);
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getMaxStatements(), -1);
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getMinPoolSize(), -1);
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getPortNumber(), -1);
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getProperties().length, 2);
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getProperties()[0], "vendor.prop.1=true");
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getProperties()[1], "vendor.prop.2=foo");
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.isTransactional(), true);
            } else if ("java:comp/env/AcmeDataSourceName".equals(jAnnotationSqlDataSourceDefinition.getName())) {
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getClassName(), "com.acme.driver");
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getUrl(), "jdbc://acme@acme/acmedb");
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getDatabaseName(), "");
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getDescription(), "");
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getPassword(), "");
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getServerName(), "localhost");
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getUser(), "");
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getInitialPoolSize(), -1);
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getIsolationLevel(), -1);
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getLoginTimeout(), 0);
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getMaxIdleTime(), -1);
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getMaxPoolSize(), -1);
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getMaxStatements(), -1);
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getMinPoolSize(), -1);
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getPortNumber(), -1);
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getProperties().length, 2);
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getProperties()[0], "vendor.prop.1=true");
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.getProperties()[1], "vendor.prop.2=foo");
                Assert.assertEquals(jAnnotationSqlDataSourceDefinition.isTransactional(), true);
            }

        }
    }

    @Override
    protected String getParsedClassName() {
        return DataSourceDefinitionsClass.class.getName();
    }

    @Override
    protected ClassLoader getParsedClassClassLoader() {
        return DataSourceDefinitionsClass.class.getClassLoader();
    }
}
