/**
 * OW2 Utilities
 * Copyright (C) 2009-2012 Bull S.A.S.
 * Contact: utilities@ow2.org
 *
 * Licensed  under the  Apache License,  Version 2.0  (the "License");
 * you may not use  this file  except in  compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed  under the  License is distributed on an "AS IS" BASIS,
 * WITHOUT  WARRANTIES OR CONDITIONS  OF ANY KIND, either  express  or
 * implied.
 *
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl;

import java.util.List;

import org.ow2.util.ee.metadata.common.api.enc.IENCBinding;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationSqlDataSourceDefinition;
import org.ow2.util.ee.metadata.common.impl.clazz.DataSourceDefinitionClass;
import org.ow2.util.ee.metadata.common.impl.enc.ENCBindingHolder;
import org.ow2.util.ee.metadata.common.impl.enc.TestENCBindingBuilder;
import org.testng.Assert;
import org.testng.annotations.Test;

/**
 * @author Loic Albertin
 */
public class DataSourceENCBindingBuilderTestCase extends AbstractAnnotationParsingTestCase {

    @Override
    protected String getParsedClassName() {
        return DataSourceDefinitionClass.class.getName();
    }

    @Override
    protected ClassLoader getParsedClassClassLoader() {
        return DataSourceDefinitionClass.class.getClassLoader();
    }

    private ENCBindingHolder holder = null;

    @Test(dependsOnMethods = "createMetadata")
    public void createBindingHolder() throws Exception {
        TestENCBindingBuilder builder = new TestENCBindingBuilder(classMetadata);
        builder.analyze();
        holder = builder.getHolder();

        Assert.assertNotNull(holder, "No BindingHolder created");
    }

    @Test(dependsOnMethods = "createBindingHolder")
    public void testWebServiceRefsInHolder() throws Exception {
        List<IENCBinding<IJAnnotationSqlDataSourceDefinition>> bindings = holder.getDataSourceBindings();

        Assert.assertNotNull(bindings, "Null Bindings for DataSources");
        Assert.assertEquals(bindings.size(), 1, "Wrong number of bindings");
    }
}
