/**
 * Copyright 2013 Peergreen S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl;


import static javax.annotation.Resource.AuthenticationType.APPLICATION;
import static javax.annotation.Resource.AuthenticationType.CONTAINER;
import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertFalse;
import static org.testng.Assert.assertNotNull;
import static org.testng.Assert.assertTrue;

import java.util.List;

import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationResource;
import org.ow2.util.ee.metadata.common.impl.clazz.ResourceClass;
import org.ow2.util.ee.metadata.common.impl.view.CommonView;
import org.ow2.util.scan.api.metadata.IFieldMetadata;
import org.ow2.util.scan.api.metadata.IMethodMetadata;
import org.testng.annotations.Test;

/**
 * @author Florent Benoit
 */
public class JavaxAnnotationResourceTestCase extends AbstractAnnotationParsingTestCase {
    @Override
    protected String getParsedClassName() {
        return ResourceClass.class.getName();
    }

    @Override
    protected ClassLoader getParsedClassClassLoader() {
        return ResourceClass.class.getClassLoader();
    }

    @Test(dependsOnMethods = "createMetadata")
    public void testParsingOnClass() {
        // view
        CommonView view = this.classMetadata.as(CommonView.class);
        IJAnnotationResource jAnnotationResource = view.getJAnnotationResource();
        assertNotNull(jAnnotationResource);

        assertEquals(jAnnotationResource.getAuthenticationType(), APPLICATION);
        assertEquals(jAnnotationResource.getDescription(), "desc3");
        assertEquals(jAnnotationResource.getLookup(), "lookup3");
        assertEquals(jAnnotationResource.getMappedName(), "mappedName3");
        assertEquals(jAnnotationResource.getMessageDestinationLink(), null);
        assertEquals(jAnnotationResource.getName(), "name3");
        assertTrue(jAnnotationResource.isShareable());
        assertEquals(jAnnotationResource.getType(), Integer.class.getName());

    }


    @Test(dependsOnMethods = "createMetadata")
    public void testParsingOnField1() {

        IFieldMetadata field = getUniqueFieldMetadata("myResource");
        CommonView view = field.as(CommonView.class);
        IJAnnotationResource jAnnotationResource = view.getJAnnotationResource();
        assertNotNull(jAnnotationResource);

        assertEquals(jAnnotationResource.getAuthenticationType(), APPLICATION);
        assertEquals(jAnnotationResource.getDescription(), "descField");
        assertEquals(jAnnotationResource.getLookup(), "lookupField");
        assertEquals(jAnnotationResource.getMappedName(), "mappedNameField");
        assertEquals(jAnnotationResource.getMessageDestinationLink(), null);
        assertEquals(jAnnotationResource.getName(), "nameField");
        assertTrue(jAnnotationResource.isShareable());
        assertEquals(jAnnotationResource.getType(), Integer.class.getName());

    }

    @Test(dependsOnMethods = "createMetadata")
    public void testParsingOnField2() {

        IFieldMetadata field = getUniqueFieldMetadata("defaultResource");
        CommonView view = field.as(CommonView.class);
        IJAnnotationResource jAnnotationResource = view.getJAnnotationResource();
        assertNotNull(jAnnotationResource);

        assertEquals(jAnnotationResource.getAuthenticationType(), CONTAINER);
        assertEquals(jAnnotationResource.getDescription(), "");
        assertEquals(jAnnotationResource.getLookup(), null);
        assertEquals(jAnnotationResource.getMappedName(), null);
        assertEquals(jAnnotationResource.getMessageDestinationLink(), null);
        assertEquals(jAnnotationResource.getName(), "");
        assertTrue(jAnnotationResource.isShareable());
        assertEquals(jAnnotationResource.getType(), Object.class.getName());

    }


    @Test(dependsOnMethods = "createMetadata")
    public void testParsingOnMethod1() {

        IMethodMetadata method = getUniqueMethodMetadata("setterMethod");
        CommonView view = method.as(CommonView.class);
        IJAnnotationResource jAnnotationResource = view.getJAnnotationResource();
        assertNotNull(jAnnotationResource);

        assertEquals(jAnnotationResource.getAuthenticationType(), CONTAINER);
        assertEquals(jAnnotationResource.getDescription(), "descMethod");
        assertEquals(jAnnotationResource.getLookup(), "lookupMethod");
        assertEquals(jAnnotationResource.getMappedName(), "mappedNameMethod");
        assertEquals(jAnnotationResource.getMessageDestinationLink(), null);
        assertEquals(jAnnotationResource.getName(), "nameMethod");
        assertFalse(jAnnotationResource.isShareable());
        assertEquals(jAnnotationResource.getType(), Float.class.getName());

    }


    @Test(dependsOnMethods = "createMetadata")
    public void testParsingOnMethod2() {


        IMethodMetadata method = getUniqueMethodMetadata("anotherSetterMethod");
        CommonView view = method.as(CommonView.class);
        IJAnnotationResource jAnnotationResource = view.getJAnnotationResource();
        assertNotNull(jAnnotationResource);

        assertEquals(jAnnotationResource.getAuthenticationType(), CONTAINER);
        assertEquals(jAnnotationResource.getDescription(), "");
        assertEquals(jAnnotationResource.getLookup(), null);
        assertEquals(jAnnotationResource.getMappedName(), null);
        assertEquals(jAnnotationResource.getMessageDestinationLink(), null);
        assertEquals(jAnnotationResource.getName(), "");
        assertTrue(jAnnotationResource.isShareable());
        assertEquals(jAnnotationResource.getType(), Object.class.getName());

    }




    @Test(dependsOnMethods = "createMetadata")
    public void testParsingOnClassResources() {

        CommonView view = classMetadata.as(CommonView.class);
        List<IJAnnotationResource> jAnnotationResources = view.getJAnnotationResources();
        assertNotNull(jAnnotationResources);
        assertEquals(jAnnotationResources.size(), 2);

        IJAnnotationResource jAnnotationResource = jAnnotationResources.get(0);
        if ("name1".equals(jAnnotationResource.getName())) {
            validateResource1(jAnnotationResource);
            validateResource2(jAnnotationResources.get(1));
        } else {
            validateResource2(jAnnotationResource);
            validateResource1(jAnnotationResources.get(1));
        }
    }


    protected void validateResource1(IJAnnotationResource jAnnotationResource) {
        assertNotNull(jAnnotationResource);
        assertEquals(jAnnotationResource.getAuthenticationType(), CONTAINER);
        assertEquals(jAnnotationResource.getDescription(), "desc1");
        assertEquals(jAnnotationResource.getLookup(), "lookup1");
        assertEquals(jAnnotationResource.getMappedName(), "mappedName1");
        assertEquals(jAnnotationResource.getMessageDestinationLink(), null);
        assertEquals(jAnnotationResource.getName(), "name1");
        assertFalse(jAnnotationResource.isShareable());
        assertEquals(jAnnotationResource.getType(), String.class.getName());
    }

    protected void validateResource2(IJAnnotationResource jAnnotationResource) {
        assertNotNull(jAnnotationResource);
        assertEquals(jAnnotationResource.getAuthenticationType(), APPLICATION);
        assertEquals(jAnnotationResource.getDescription(), "desc2");
        assertEquals(jAnnotationResource.getLookup(), "lookup2");
        assertEquals(jAnnotationResource.getMappedName(), "mappedName2");
        assertEquals(jAnnotationResource.getMessageDestinationLink(), null);
        assertEquals(jAnnotationResource.getName(), "name2");
        assertTrue(jAnnotationResource.isShareable());
        assertEquals(jAnnotationResource.getType(), Float.class.getName());
    }

}
