/**
 * Copyright 2013 Peergreen S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl;

import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertNotNull;

import java.util.List;

import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;
import org.ow2.util.ee.metadata.common.impl.clazz.EJBClass;
import org.ow2.util.ee.metadata.common.impl.clazz.ManagedBeanClass;
import org.ow2.util.ee.metadata.common.impl.view.CommonView;
import org.ow2.util.scan.api.metadata.IFieldMetadata;
import org.ow2.util.scan.api.metadata.IMethodMetadata;
import org.testng.annotations.Test;

/**
 * @author Florent Benoit
 */
public class JavaxEJBEJBTestCase extends AbstractAnnotationParsingTestCase {
    @Override
    protected String getParsedClassName() {
        return EJBClass.class.getName();
    }

    @Override
    protected ClassLoader getParsedClassClassLoader() {
        return ManagedBeanClass.class.getClassLoader();
    }

    @Test(dependsOnMethods = "createMetadata")
    public void testParsingOnClass() {
        // view
        CommonView view = this.classMetadata.as(CommonView.class);
        IJEjbEJB jeEjb = view.getJEjbEJB();
        assertNotNull(jeEjb);

        assertEquals(jeEjb.getBeanInterface(), String.class.getName());
        assertEquals(jeEjb.getBeanName(), "BeanOnClass");
        assertEquals(jeEjb.getMappedName(), "mappedNameClass");
        assertEquals(jeEjb.getName(), "nameOnClass");
        assertEquals(jeEjb.getLookup(), "lookupOnClass");

    }


    @Test(dependsOnMethods = "createMetadata")
    public void testParsingOnField1() {

        IFieldMetadata field = getUniqueFieldMetadata("myEJB");
        CommonView view = field.as(CommonView.class);
        IJEjbEJB jeEjb = view.getJEjbEJB();
        assertNotNull(jeEjb);

        assertEquals(jeEjb.getBeanInterface(), null);
        assertEquals(jeEjb.getBeanName(), "BeanOnField");
        assertEquals(jeEjb.getMappedName(), "mappedNameField");
        assertEquals(jeEjb.getName(), "nameOnField");
        assertEquals(jeEjb.getLookup(), "lookupField");

    }

    @Test(dependsOnMethods = "createMetadata")
    public void testParsingOnField2() {

        IFieldMetadata field = getUniqueFieldMetadata("defaultEjb");
        CommonView view = field.as(CommonView.class);
        IJEjbEJB jeEjb = view.getJEjbEJB();
        assertNotNull(jeEjb);

        assertEquals(jeEjb.getBeanInterface(), null);
        assertEquals(jeEjb.getBeanName(), "");
        assertEquals(jeEjb.getMappedName(), null);
        assertEquals(jeEjb.getName(), "");
        assertEquals(jeEjb.getLookup(), null);

    }


    @Test(dependsOnMethods = "createMetadata")
    public void testParsingOnMethod1() {

        IMethodMetadata method = getUniqueMethodMetadata("setterMethod");
        CommonView view = method.as(CommonView.class);
        IJEjbEJB jeEjb = view.getJEjbEJB();
        assertNotNull(jeEjb);

        assertEquals(jeEjb.getBeanInterface(), null);
        assertEquals(jeEjb.getBeanName(), "BeanOnMethod");
        assertEquals(jeEjb.getMappedName(), "mappedNameMethod");
        assertEquals(jeEjb.getName(), "nameOnMethod");
        assertEquals(jeEjb.getLookup(), "lookupMethod");

    }


    @Test(dependsOnMethods = "createMetadata")
    public void testParsingOnMethod2() {


        IMethodMetadata method = getUniqueMethodMetadata("anotherSetterMethod");
        CommonView view = method.as(CommonView.class);
        IJEjbEJB jeEjb = view.getJEjbEJB();
        assertNotNull(jeEjb);

        assertEquals(jeEjb.getBeanInterface(), null);
        assertEquals(jeEjb.getBeanName(), "");
        assertEquals(jeEjb.getMappedName(), null);
        assertEquals(jeEjb.getName(), "");
        assertEquals(jeEjb.getLookup(), null);

    }




    @Test(dependsOnMethods = "createMetadata")
    public void testParsingOnClassEjbs() {

        CommonView view = classMetadata.as(CommonView.class);
        List<IJEjbEJB> jeEjbs = view.getJEjbEJBs();
        assertNotNull(jeEjbs);
        assertEquals(jeEjbs.size(), 2);

        IJEjbEJB jeEjb1 = jeEjbs.get(0);
        if ("beanName1".equals(jeEjb1.getBeanName())) {
            validateEJB1(jeEjb1);
            validateEJB2(jeEjbs.get(1));
        } else {
            validateEJB2(jeEjb1);
            validateEJB1(jeEjbs.get(1));
        }
    }


    protected void validateEJB1(IJEjbEJB jeEjb) {
        assertEquals(jeEjb.getBeanInterface(), Integer.class.getName());
        assertEquals(jeEjb.getBeanName(), "beanName1");
        assertEquals(jeEjb.getMappedName(), "mappedName1");
        assertEquals(jeEjb.getName(), "name1");
        assertEquals(jeEjb.getLookup(), "lookup1");
    }

    protected void validateEJB2(IJEjbEJB jeEjb) {
        assertEquals(jeEjb.getBeanInterface(), Float.class.getName());
        assertEquals(jeEjb.getBeanName(), "beanName2");
        assertEquals(jeEjb.getMappedName(), "mappedName2");
        assertEquals(jeEjb.getName(), "name2");
        assertEquals(jeEjb.getLookup(), "lookup2");
    }

}
