/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl;

import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.ow2.util.archive.api.IArchive;
import org.ow2.util.ee.metadata.common.impl.configurator.CommonAnnotationConfigurator;
import org.ow2.util.ee.metadata.common.impl.view.CommonMetadataViewFactory;
import org.ow2.util.ee.metadata.common.impl.view.CommonView;
import org.ow2.util.scan.api.IClassesLocator;
import org.ow2.util.scan.api.IScanner;
import org.ow2.util.scan.api.ScanException;
import org.ow2.util.scan.api.classlocator.ArchiveClassesLocator;
import org.ow2.util.scan.api.classlocator.ClassLoaderClassesLocator;
import org.ow2.util.scan.api.configurator.IAnnotationConfigurator;
import org.ow2.util.scan.api.configurator.IClassConfigurator;
import org.ow2.util.scan.api.configurator.ISessionConfigurator;
import org.ow2.util.scan.api.configurator.basic.ClassMetadataConfigurator;
import org.ow2.util.scan.api.configurator.basic.SessionConfigurator;
import org.ow2.util.scan.api.configurator.basic.ViewConfigurator;
import org.ow2.util.scan.api.metadata.IClassMetadata;
import org.ow2.util.scan.impl.ASMScannerImpl;

/**
 * This class is only for test (common metadata is abstract). This class only do
 * annotation stuff. You should read your xml before (to determine if annotation
 * scan should be enabled and to know which class are referenced). You should
 * also write your own merge procedure after.
 * @author Gael Lalire
 */
public class TestCommonDeployableMetadataFactory  {

    /**
     * @param initialClassNameSet class name from xml
     * @param annotationParsingDesactived allow to avoid annotation visitor
     * @param archive the archive
     * @return a map which associate metadata for scanned classes
     * @throws ScanException if error occurs
     */
    public Map<String, IClassMetadata> createDeployableMetadata(final List<String> initialClassNameSet,
            final boolean annotationParsingDesactived, final IArchive archive) throws ScanException {

        final Map<String, IClassMetadata> result = new HashMap<>();

        List<? extends IClassesLocator> externClassLocator = Arrays.asList(new ClassLoaderClassesLocator(ClassLoader
                .getSystemClassLoader()));
        IClassesLocator archiveClassLocator = new ArchiveClassesLocator(archive);
        ISessionConfigurator sessionConfigurator = new SessionConfigurator() {

            @Override
            public IClassConfigurator createClassConfigurator(IClassMetadata classMetadata) {
                result.put(classMetadata.getClassName(), classMetadata);
                return new ClassMetadataConfigurator(classMetadata);
            }

            @Override
            public List<IAnnotationConfigurator> getAnnotationConfigurators() {
                return Collections.singletonList((IAnnotationConfigurator) new CommonAnnotationConfigurator());
            }

        };

        ViewConfigurator viewConfigurator = new ViewConfigurator();
        viewConfigurator.registerView(CommonView.class, new CommonMetadataViewFactory());
        sessionConfigurator.getViewConfigurators().add(viewConfigurator);


        Set<String> set = new HashSet<String>();
        set.addAll(initialClassNameSet);

        IScanner scanner = new ASMScannerImpl();
        scanner.scan(set, archiveClassLocator, externClassLocator, sessionConfigurator);

        return result;

    }

}
