/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl;

import java.util.Collection;
import java.util.Collections;

import org.ow2.util.ee.metadata.common.api.interfaces.IEnvironmentRefAccessor;
import org.ow2.util.ee.metadata.common.api.xml.struct.IEnvironment;
import org.ow2.util.ee.metadata.common.impl.xml.merge.MetadataMerge;
import org.ow2.util.scan.api.metadata.IClassMetadata;
import org.ow2.util.scan.api.metadata.IFieldMetadata;
import org.ow2.util.scan.api.metadata.IMethodMetadata;

/**
 * Ease testing of common merge features.
 */
public class TestCommonMetadataMerge extends MetadataMerge {

    /**
     * Stores the clazz metadata to return.
     */
    private final IClassMetadata metadata;

    public TestCommonMetadataMerge(final IClassMetadata metadata) {
        this.metadata = metadata;
    }

    /**
     * @param className the class name
     * @return the common class metadata which name is classname
     */
    @Override
    public IClassMetadata getClassMetadata(final String className) {
        return metadata;
    }

    @Override
    public String findDefaultClassForEnvironment(final IEnvironmentRefAccessor env) {
        return metadata.getJClass().getName().replace('.', '/');
    }

    /**
     * Apply rules for a an environment.
     * @param envGroup the struct (XML DD)
     * @param classAnnotationMetadata (Annotation metadata)
     */
    @Override
    public void applyJndiEnvironmentRefsGroup(final IEnvironment envGroup, final IEnvironmentRefAccessor classAnnotationMetadata) {
        super.applyJndiEnvironmentRefsGroup(envGroup, classAnnotationMetadata);
    }

    /**
     * @return A collection of all ClassMetadata of the merged object.
     */
    @Override
    protected Collection<IClassMetadata> getAllClassMetadatas() {
        return Collections.singleton(metadata);
    }

    /**
     * @return A collection of all MethodMetadata of the merged object.
     */
    @Override
    protected Collection<IMethodMetadata> getAllMethodMetadatas() {
        return metadata.getMethodMetadataCollection();
    }

    /**
     * @return A collection of all FieldMetadata of the merged object.
     */
    @Override
    protected Collection<IFieldMetadata> getAllFieldMetadatas() {
        return metadata.getFieldMetadataCollection();
    }

}
