/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl;

import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertNotNull;

import org.ow2.util.ee.metadata.common.api.struct.IJaxwsWebServiceRef;
import org.ow2.util.ee.metadata.common.impl.clazz.AttributeParsingClass;
import org.ow2.util.ee.metadata.common.impl.view.CommonView;
import org.ow2.util.scan.api.metadata.IFieldMetadata;
import org.testng.annotations.Test;

/**
 * Created by IntelliJ IDEA.
 * User: sauthieg
 * Date: 2 oct. 2008
 * Time: 08:25:17
 * To change this template use File | Settings | File Templates.
 */
public class WebServiceRefAttributeParsingTestCase extends AbstractAnnotationParsingTestCase  {

    @Test(dependsOnMethods = "createMetadata")
    public void testAllAttributesParsed() throws Exception {
        IFieldMetadata field = getUniqueFieldMetadata("service");
        assertNotNull(field);

        CommonView view = field.as(CommonView.class);
        IJaxwsWebServiceRef ref = view.getJaxwsWebServiceRef();
        assertNotNull(ref);

        assertEquals(ref.getMappedName(), "A", "mappedName attribute not parsed");
        assertEquals(ref.getName(), "B", "name attribute not parsed");
        assertEquals(ref.getType(), "org.ow2.util.ee.metadata.common.impl.clazz.IEndpoint", "type attribute not parsed");
        assertEquals(ref.getValue(), "javax.xml.ws.Service", "value attribute not parsed");
        assertEquals(ref.getWsdlLocation(), "location", "wsdlLocation attribute not parsed");

    }

    @Override
    protected String getParsedClassName() {
        return AttributeParsingClass.class.getName();
    }

    @Override
    protected ClassLoader getParsedClassClassLoader() {
        return AttributeParsingClass.class.getClassLoader();
    }
}
