/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.enc;

import java.util.Collection;
import java.util.Collections;

import org.ow2.util.scan.api.metadata.IClassMetadata;

/**
 * Simply extends the abstract ENCBindingBuilder and make some protected methods public.
 * @author Guillaume Sauthier
 */
public class TestENCBindingBuilder extends AbsENCBindingBuilder {

    /**
     * All class metadata are kept by this object.
     */
    private IClassMetadata classMetadata = null;


    /**
     * Constructor used only by this class/subclasses.
     * @param classMetadata the given metadata to analyze.
     */
    public TestENCBindingBuilder(final IClassMetadata classMetadata) {
        super();
        this.classMetadata = classMetadata;
    }

    /**
     * @return list of metadata to analyze.
     */
    @Override
    protected Collection<IClassMetadata> getClassMetadataCollection() {
        return Collections.singleton(classMetadata);
    }

    /**
     * Analyze the metadata and populate the binding holder.
     *
     * @throws org.ow2.util.ee.metadata.common.impl.enc.ENCBindingException
     *          if the analyze is failing.
     */
    @Override
    public void analyze() throws ENCBindingException {
        super.analyze();
    }

    /**
     * @return the Holder of all ENC bindings.
     */
    @Override
    public ENCBindingHolder getHolder() {
        return super.getHolder();
    }
}
