/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ear.api;

import org.ow2.util.archive.api.IArchive;
import org.ow2.util.ee.metadata.ear.api.exception.EARMetadataException;

/**
 * IWarDeployableMetadataFactory. This interface is used by OSGi.
 * @author Gael Lalire
 */
public interface IEarMetadataFactory {


    /**
     * Create war metadata.
     * @param archive the war archive
     * @return the metadata
     * @throws EARMetadataException if error occurs
     */
    IEarMetadata createArchiveMetadata(final IArchive archive) throws EARMetadataException;

    /**
     * Create war metadata.
     * @param archive the war archive
     * @param classLoader a classloader to use if a class is not in archive
     * @return the metadata
     * @throws EARMetadataException if error occurs
     */
    IEarMetadata createArchiveMetadata(final IArchive archive, final ClassLoader classLoader)
            throws EARMetadataException;
}
