/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ear.impl;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import org.ow2.util.archive.api.IArchive;
import org.ow2.util.ee.metadata.car.api.ICarMetadata;
import org.ow2.util.ee.metadata.ear.api.IEarMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarMetadata;
import org.ow2.util.ee.metadata.war.api.IWarMetadata;

/**
 * Implementation of ear deployable metadata.
 * @author Gael Lalire
 */
public class EarMetadata implements IEarMetadata {

    /**
     * List of car deployable.
     */
    private final List<ICarMetadata> carDeployableMetadataList;

    /**
     * List of war deployable.
     */
    private final List<IWarMetadata> warDeployableMetadataList;

    /**
     * List of ejb3 deployable.
     */
    private final List<IEjbJarMetadata> ejbJarDeployableMetadataList;

    /**
     * The ear archive.
     */
    private final IArchive archive;

    /**
     * Constructor.
     * @param earDeployable the ear deployable
     */
    public EarMetadata(final IArchive archive) {
        this.archive = archive;
        carDeployableMetadataList = new ArrayList<>();
        warDeployableMetadataList = new ArrayList<>();
        ejbJarDeployableMetadataList = new ArrayList<>();
    }

    /**
     * Add a car deployable metadata.
     * @param carDeployableMetadata the car deployable metadata to add
     */
    public void addCarDeployableMetadata(final ICarMetadata carDeployableMetadata) {
        carDeployableMetadataList.add(carDeployableMetadata);
    }

    /**
     * Add a war deployable metadata.
     * @param warDeployableMetadata the war deployable metadata to add
     */
    public void addWarDeployableMetadata(final IWarMetadata warDeployableMetadata) {
        warDeployableMetadataList.add(warDeployableMetadata);
    }

    /**
     * Add a war deployable metadata.
     * @param ejbJarDeployableMetadata the ejb3 deployable metadata to add
     */
    public void addEjbJarDeployableMetadata(final IEjbJarMetadata ejbJarDeployableMetadata) {
        ejbJarDeployableMetadataList.add(ejbJarDeployableMetadata);
    }

    /**
     * @return a collection of client archive metadata.
     */
    @Override
    public Collection<ICarMetadata> getCarMetadataCollection() {
        return carDeployableMetadataList;
    }

    /**
     * @return a collection of web archive metadata.
     */
    @Override
    public Collection<IWarMetadata> getWarMetadataCollection() {
        return warDeployableMetadataList;
    }

    /**
     * @return a collection of ejb3 archive metadata.
     */
    @Override
    public Collection<IEjbJarMetadata> getEjbJarMetadataCollection() {
        return ejbJarDeployableMetadataList;
    }

    /**
     * @return the ear archive
     */
    public IArchive getArchive() {
        return archive;
    }


}
