/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.api;

import java.util.Collection;
import java.util.List;
import java.util.Map;

import org.ow2.util.ee.metadata.common.api.struct.IJInterceptors;
import org.ow2.util.ee.metadata.ejbjar.api.struct.IApplicationException;
import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IEJB3;
import org.ow2.util.scan.api.metadata.IClassMetadata;
import org.ow2.util.scan.api.metadata.IMetadata;

/**
 * IEjbJarDeployableMetadata.
 * @author Gael Lalire
 */
public interface IEjbJarMetadata extends IMetadata {

    /**
     * Gets the class metadata for the given ejb-name/ejbclass.
     * @return class metadata or null if not found
     * @param ejbName the name of the EJB.
     * @param ejbClass the class of the EJB.
     */
    IClassMetadata getBeanEjbJarClassMetadataForEjbName(final String ejbName, final String ejbClass);


    /**
     * Add annotation metadata for a given class.
     * @param classAnnotationMetadata annotation metadata of a class.
     */
    void addScannedClassMetadata(final IClassMetadata classAnnotationMetadata);

    /**
     * Gets the class metadata for the given ejb-name.
     * @return class metadata or null if not found
     * @param ejbName the name of the EJB.
     */
    IClassMetadata getEjbJarClassMetadataForEjbName(final String ejbName);

    /**
     * Get interceptor class metadata.
     * @param className key of the map of annotations bean.
     * @return interceptor class metadata of a given name or null if class not
     *         found.
     */
    IClassMetadata getScannedClassMetadata(final String className);

    /**
     * Get collections of bean annotation metadata.
     * @return collections of bean annotation metadata.
     */
    Collection<IClassMetadata> getEjbJarClassMetadataCollection();

    /**
     * Gets the list of application exceptions defined on this ejb jar metadata.
     * @return the list of application exceptions defined on this ejb jar
     *         metadata.
     */
    Map<String, IApplicationException> getApplicationExceptions();

    /**
     * @return object representing list of default interceptor classes.
     */
    IJInterceptors getDefaultInterceptorsClasses();

    /**
     * Sets the object representing the default interceptor classes.
     * @param defaultInterceptorsClasses list of classes
     */
    void setDefaultInterceptorsClasses(final IJInterceptors defaultInterceptorsClasses);


    /**
     * @return the ejb3 deployment descriptor object.
     */
    IEJB3 getEjb3();

    /**
     * Sets the ejb3 deployment descriptor object.
     * @param ejb3 the ejb3 deployment descriptor object.
     */
    void setEjb3(final IEJB3 ejb3);

    /**
     * @return a list of all beans that are defined
     */
    List<String> getBeanNames();

    /**
     * @param beanName the bean that will be used in order to get the classes.
     * @return a list of all classes that are for a given bean
     */
    Collection<IClassMetadata> getClassesForBean(final String beanName);

}
