/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ow2.util.ee.metadata.ejbjar.api.interfaces;

import java.io.Serializable;
import java.util.List;

import org.ow2.util.ee.metadata.ejbjar.api.struct.IJEjbSchedule;

/**
 * This interface represents methods which can be call on
 * MethodAnnotationMetadata.<br>
 * It manages &#64;{@link javax.ejb.Schedule} and &#64;{@link javax.ejb.Schedules} annotation.
 * @author Florent Benoit
 */
public interface IEjbSchedule extends Serializable {

    /**
     * @return the list of all schedules of this method.
     */
    List<IJEjbSchedule> getJavaxEjbSchedules();

    /**
     * Adds a new jEjbSchedule on this method.
     * @param jEjbSchedule information on the schedules.
     */
    void addJavaxEjbSchedule(IJEjbSchedule jEjbSchedule);
    
    /**
     * Sets the list of jEjbSchedule on this method.
     * @param jEjbSchedules information on the schedules.
     */
    void setJavaxEjbSchedules(List<IJEjbSchedule> jEjbSchedules);
    
}
