/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ow2.util.ee.metadata.ejbjar.api.xml.struct;

import java.io.Serializable;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.xml.struct.IMethodDD;
import org.ow2.util.ee.metadata.ejbjar.api.struct.IApplicationException;

/**
 * Assembly descriptor interface.
 * @author Florent Benoit
 */
public interface IAssemblyDescriptor extends Serializable {

    /**
     * Name of this element.
     */
    String NAME = "assembly-descriptor";

    /**
     * Gets the list of &lt;application-exception&gt; elements.
     * @return list of &lt;application-exception&gt; elements.
     */
    List<IApplicationException> getApplicationExceptionList();

    /**
     * Adds a new &lt;application-exception&gt; element to assembly descriptor.
     * @param applicationException the &lt;application-exception&gt; element
     */
    void addApplicationException(final IApplicationException applicationException);

    /**
     * Gets the list of &lt;container-transaction&gt; elements.
     * @return list of &lt;container-transaction&gt; elements.
     */
    List<IContainerTransaction> getContainerTransactionList();

    /**
     * Adds a new &lt;container-transaction&gt; element to assembly descriptor.
     * @param containerTransaction the &lt;application-exception&gt; element
     */
    void addContainerTransaction(final IContainerTransaction containerTransaction);

    /**
     * Gets the list of &lt;interceptor-binding&gt; elements.
     * @return list of &lt;interceptor-binding&gt; elements.
     */
    List<IInterceptorBinding> getInterceptorBindingList();

    /**
     * Adds a new &lt;interceptor-binding&gt; element to assembly descriptor.
     * @param interceptorBinding the &lt;interceptor-binding&gt; element
     */
    void addInterceptorBinding(final IInterceptorBinding interceptorBinding);

    /**
     * Gets the list of &lt;method-permission&gt; elements.
     * @return list of &lt;method-permission&gt; elements.
     */
    List<IMethodPermission> getMethodPermissionList();

    /**
     * Adds a new &lt;method-permission&gt; element to assembly descriptor.
     * @param methodPermission the &lt;method-permission&gt; element
     */
    void addMethodPermission(final IMethodPermission methodPermission);

    /**
     * Gets the list of &lt;exclude-list&gt; elements.
     * @return list of &lt;exclude-list&gt; elements.
     */
    List<IMethodDD> getExcludeListMethods();

    /**
     * Adds a new &lt;exclude-list&gt; element to assembly descriptor.
     * @param excludeListMethod the &lt;exclude-list&gt; element
     */
    void addExcludeList(final IMethodDD excludeListMethod);

    /**
     * Gets the list of &lt;security-role&gt; elements.
     * @return list of &lt;security-role&gt; elements.
     */
    List<String> getSecurityRoleList();

    /**
     * Adds a new &lt;security-role&gt; element to assembly descriptor.
     * @param securityRole the &lt;security-role&gt; element
     */
    void addSecurityRole(final String securityRole);

    /**
     * Gets the list of &lt;message-destination&gt; elements.
     * @return list of &lt;message-destination&gt; elements.
     */
    List<IMessageDestination> getMessageDestinationlist();

    /**
     * Adds a new &lt;message-destination&gt; element to assembly descriptor.
     * @param messageDestination the &lt;message-destination&gt; element
     */
    void addMessageDestination(final IMessageDestination messageDestination);

}
