/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ow2.util.ee.metadata.ejbjar.api.xml.struct;

import java.util.List;

import org.ow2.util.ee.metadata.common.api.xml.struct.IEnvironment;
import org.ow2.util.ee.metadata.common.api.xml.struct.IMethodDD;

/**
 * Common stuff of beans.
 * @author Florent Benoit
 */
public interface IBean extends IEnvironment {

    /**
     * Gets the ejb-name.
     * @return the ejb-name
     */
    String getEjbName();

    /**
     * Set the ejb-name.
     * @param ejbName ejbName
     */
    void setEjbName(final String ejbName);

    /**
     * Gets the ejb-class.
     * @return the ejb-class
     */
    String getEjbClass();

    /**
     * Set the ejb-class.
     * @param ejbClass ejb-class
     */
    void setEjbClass(final String ejbClass);

    /**
     * Gets the run-as role.
     * @return the run-as role
     */
    String getRunAsRole();

    /**
     * Set the run-as role.
     * @param runAsRole the run-as role
     */
    void setRunAsRole(final String runAsRole);

    /**
     * Gets the mapped name.
     * @return the mapped name
     */
    String getMappedName();

    /**
     * Set the mapped name.
     * @param mappedName the given mapped name.
     */
    void setMappedName(final String mappedName);

    /**
     * Gets the transaction-type.
     * @return the transaction-type
     */
    String getTransactionType();

    /**
     * Set the transaction-type.
     * @param transactionType transaction-type.
     */
    void setTransactionType(final String transactionType);

    /**
     * @return list of timers
     */
    List<ITimer> getTimers();
    
    /**
     * Adds a new timer.
     * @param timer the new timer
     */
    void addTimer(final ITimer timer);
    
    /**
     * @return the timeout method
     */
    IMethodDD getTimeoutMethod();


    /**
     * Set the timeout method.
     * @param timeoutMethod the given timeout.
     */
    void setTimeoutMethod(IMethodDD timeoutMethod);
}
