/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ow2.util.ee.metadata.ejbjar.api.xml.struct;

import java.io.Serializable;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.struct.ITransactionAttributeType;
import org.ow2.util.ee.metadata.common.api.xml.struct.IMethodDD;

/**
 * Interface for element container-transaction.
 * @author Florent Benoit
 */
public interface IContainerTransaction extends Serializable {

    /**
     * Name of this element.
     */
    String NAME = "container-transaction";

    /**
     * Add a new Method.
     * @param method the given method.
     */
    void addMethod(final IMethodDD method);

    /**
     * @return list of methods.
     */
    List<IMethodDD> getMethods();

    /**
     * Sets the transaction attribute for this block.
     * @param txAttribute the given transaction attribute
     */
    void setTransactionAttribute(final ITransactionAttributeType txAttribute);

    /**
     * Gets the transaction attribute for this block.
     * @return the transaction attribute
     */
    ITransactionAttributeType getTransactionAttribute();

    /**
     * @return string representation of this module.
     */
    @Override
    String toString();

}
