/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ow2.util.ee.metadata.ejbjar.api.xml.struct;

import java.io.Serializable;


/**
 * Defines the interface of the XML representation of an EJB 3 deployment
 * descriptor.
 * @author Florent Benoit
 */
public interface IEJB3 extends Serializable {

    /**
     * Gets the enterprise-beans element.
     * @return the enterprise-beans
     */
    IEnterpriseBeans getEnterpriseBeans();

    /**
     * Sets the enterprise-beans element.
     * @param enterpriseBeans the element to set.
     */
    void setEnterpriseBeans(final IEnterpriseBeans enterpriseBeans);

    /**
     * Gets the interceptors element.
     * @return the interceptors
     */
    IInterceptors getInterceptors();

    /**
     * Sets the interceptors element.
     * @param interceptors the element to set.
     */
    void setInterceptors(final IInterceptors interceptors);

    /**
     * Gets the assembly-descriptor element.
     * @return the assembly-descriptor
     */
    IAssemblyDescriptor getAssemblyDescriptor();

    /**
     * Sets the assembly-descriptor element.
     * @param assemblyDescriptor the element to set.
     */
    void setAssemblyDescriptor(final IAssemblyDescriptor assemblyDescriptor);

    /**
     * Set metadataComplete.
     * @param metadataComplete true if deployment descriptor contains all
     *        information
     */
    void setMetadataComplete(final boolean metadataComplete);

    /**
     * Get metadataComplete.
     * @return true if deployment descriptor contains all information
     */
    boolean isMetadataComplete();

}
