/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ow2.util.ee.metadata.ejbjar.api.xml.struct;

import java.io.Serializable;
import java.util.List;

/**
 * Interface for enterprise-beans element.
 * @author Florent Benoit
 */
public interface IEnterpriseBeans extends Serializable {

    /**
     * Name of this element.
     */
    String NAME = "enterprise-beans";

    /**
     * Gets the list of &lt;session&gt; elements.
     * @return list of &lt;session&gt; elements.
     */
    List<ISession> getSessionList();

    /**
     * Adds a new &lt;session&gt; element to enterprise beans.
     * @param session the &lt;session&gt; element
     */
    void addSession(final ISession session);

    /**
     * Gets the list of &lt;message-driven&gt; elements.
     * @return list of &lt;message-driven&gt; elements.
     */
    List<IMessageDriven> getMessageDrivenList();

    /**
     * Adds a new &lt;message-driven&gt; element to enterprise beans.
     * @param messageDriven the &lt;message-driven&gt; element
     */
    void addMessageDriven(final IMessageDriven messageDriven);

}
