/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ow2.util.ee.metadata.ejbjar.api.xml.struct;

import java.io.Serializable;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.xml.struct.IMethodDD;

/**
 * Interface for element interceptor-binding.
 * @author Florent Benoit

 */
public interface IInterceptorBinding extends Serializable {

    /**
     * Name of this element.
     */
    String NAME = "interceptor-binding";

    /**
     * @return the name of the EJB.
     */
    String getEjbName();

    /**
     * Sets the name of this ejb (or wildcard).
     * @param ejbName the name of the ejb.
     */
    void setEjbName(final String ejbName);

    /**
     * @return the method element
     */
    IMethodDD getMethod();

    /**
     * Method on which define the interceptors.
     * @param method the given method.
     */
    void setMethod(final IMethodDD method);

    /**
     * @return true if the class interceptors are excluded for the given method
     */
    boolean isExcludeClassInterceptors();

    /**
     * Exclude or not class interceptors ?
     * @param excludeClassInterceptors true/false
     */
    void setExcludeClassInterceptors(final boolean excludeClassInterceptors);

    /**
     * @return true if method setExcludeClassInterceptors has been called (with false or true)
     */
    boolean isExcludeClassInterceptorsCalled();

    /**
     * @return true if the default interceptors are excluded for the given bean
     */
    boolean isExcludeDefaultInterceptors();

    /**
     * Exclude or not default interceptors ?
     * @param excludeDefaultInterceptors true/false
     */
    void setExcludeDefaultInterceptors(final boolean excludeDefaultInterceptors);

    /**
     * @return true if method setExcludeDefaultInterceptors has been called (with false or true)
     */
    boolean isExcludeDefaultInterceptorsCalled();

    /**
     * @return list of the interceptor classes.
     */
    List<String> getInterceptorClassList();

    /**
     * @return list of ordered interceptor classes.
     */
    List<String> getOrderInterceptorClassList();

    /**
     * Add the given interceptor to the list.
     * @param interceptorClassName the name of the interceptor's class
     */
    void addInterceptorClass(final String interceptorClassName);

    /**
     * Add the given interceptor to the ordered list.
     * @param interceptorClassName the name of the interceptor's class
     */
    void addOrderedInterceptorClass(final String interceptorClassName);

}
