/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ow2.util.ee.metadata.ejbjar.api.xml.struct;

import java.util.List;

import org.ow2.util.ee.metadata.common.api.xml.struct.IActivationConfig;


/**
 * Interface for element message-driven.
 * @author Florent Benoit
 */
public interface IMessageDriven extends IBean {

    /**
     * Name of this element.
     */
    String NAME = "message-driven";

    /**
     * Set the messaging-type.
     * @param messagingType the message listener interface of the message-driven
     *        bean.
     */
    void setMessagingType(final String messagingType);

    /**
     * Gets the messaging-type.
     * @return the messaging-type
     */
    String getMessagingType();

    /**
     * Set the message destination type.
     * @param messageDestinationType message destination type.
     */
    void setMessageDestinationType(final String messageDestinationType);

    /**
     * Gets the message destination type.
     * @return the message destination type
     */
    String getMessageDestinationType();

    /**
     * Set the message destination link.
     * @param messageDestinationLink message destination link.
     */
    void setMessageDestinationLink(final String messageDestinationLink);

    /**
     * Gets the message destination link.
     * @return the message destination link
     */
    String getMessageDestinationLink();

    /**
     * Gets the activation-config list.
     * @return activation-config list
     */
    List<IActivationConfig> getActivationConfigList();

    /**
     * Add the activation-config property.
     * @param activationConfig activation-config property
     */
    void addActivationConfig(final IActivationConfig activationConfig);

}
