/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ow2.util.ee.metadata.ejbjar.api.xml.struct;

import java.io.Serializable;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.xml.struct.IMethodDD;

/**
 * Interface for element method-permission.
 * @author Florent Benoit
 */
public interface IMethodPermission extends Serializable {

    /**
     * Name of this element.
     */
    String NAME = "method-permission";

    /**
     * Sets the unchecked flag.
     * @param unchecked the given boolean value.
     */
    void setUnchecked(final boolean unchecked);

    /**
     * Is it unchecked ?.
     * @return true if it is unchecked, else false.
     */
    boolean isUnchecked();

    /**
     * Add a new Method.
     * @param method the given method.
     */
    void addMethod(final IMethodDD method);

    /**
     * @return list of methods.
     */
    List<IMethodDD> getMethods();

    /**
     * Gets the name of the role.
     * @return the role's name.
     */
    List<String> getRoleNameList();

    /**
     * Add the given role.
     * @param roleName the name of the role.
     */
    void addRoleName(final String roleName);

}
