/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.api.xml.struct;

import java.io.Serializable;

import org.ow2.util.ee.metadata.common.api.xml.struct.IMethodDD;

/**
 * Interface for element remove-method.
 * @author Florent Benoit
 */
public interface IRemoveMethod extends Serializable {

    /**
     * Name of this element.
     */
    String NAME = "remove-method";

    /**
     * Sets the method of the bean which needs to be marked.
     * @param method the method to use
     */
    void setMethod(final IMethodDD method);

    /**
     * @return the method that will be used as a remove method
     */
    IMethodDD getMethod();

    /**
     * If there is an exception, the bean should be kept or not.
     * @param retainIfException true to keep, or false to remove
     */
    void setRetainIfException(final boolean retainIfException);

    /**
     * @return the flag to know if when there is an exception, the bean should be kept or not.
     * It returns null if it was not set.
     */
    Boolean getRetainIfException();

}
