/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.api.xml.struct;

import java.util.List;

import org.ow2.util.ee.metadata.common.api.xml.struct.IMethodDD;

/**
 * Interface for element session.
 * @author Florent Benoit
 */
public interface ISession extends IBean {

    /**
     * Name of this element.
     */
    String NAME = "session";

    /**
     * Gets the business-remote interface list.
     * @return business-remote interface list
     */
    List<String> getBusinessRemoteList();

    /**
     * Gets the business-local interface list.
     * @return business-local interface list
     */
    List<String> getBusinessLocalList();

    /**
     * Add the business-remote interface.
     * @param businessRemote business-remote interface.
     */
    void addBusinessRemote(final String businessRemote);

    /**
     * Add the business-local interface.
     * @param businessLocal business-remote interface.
     */
    void addBusinessLocal(final String businessLocal);

    /**
     * Gets the list of remove methods.
     * @return list of remove methods
     */
    List<IRemoveMethod> getRemoveMethodList();

    /**
     * Add the method used as a remove method.
     * @param removeMethod the given remove method
     */
    void addRemoveMethod(final IRemoveMethod removeMethod);

    /**
     * Add the method used as a concurrent method.
     * @param concurrentMethod the given concurrent method
     */
    void addConcurrentMethod(final IConcurrentMethod concurrentMethod);
    
    /**
     * Gets the list of concurrent methods.
     * @return list of concurrent methods
     */
    List<IConcurrentMethod> getConcurrentMethodList();
    
    /**
     * Gets the session-type.
     * @return the session-type.
     */
    String getSessionType();

    /**
     * Set the session-type.
     * @param sessionType the type of session.
     */
    void setSessionType(final String sessionType);

    /**
     * Gets the remote Home.
     * @return the remote Home
     */
    String getRemoteHome();

    /**
     * Set the remote Home.
     * @param remoteHome the given remote Home.
     */
    void setRemoteHome(final String remoteHome);

    /**
     * Gets the local Home.
     * @return the local Home
     */
    String getLocalHome();

    /**
     * Set the local Home.
     * @param localHome the given local Home.
     */
    void setLocalHome(final String localHome);
    
    /**
     * Flag this bean with a no-interface view.
     */
    void setLocalBean();

    /**
     * @return true if this bean has a no-interface view.
     */
    boolean isLocalBean();
    
    /**
     * Sets the afterBegin method used by stateful.
     * @param afterBeginMethod the given afterBegin method
     */
    void setAfterBeginMethod(final IMethodDD afterBeginMethod);
    
    /**
     * @return the given afterBegin method
     */
    IMethodDD getAfterBeginMethod();
    
    /**
     * Sets the afterCompletion method used by stateful.
     * @param afterCompletionMethod the given afterCompletion method
     */
    void setAfterCompletionMethod(final IMethodDD afterCompletionMethod);
    
    /**
     * @return the given afterCompletion method
     */
    IMethodDD getAfterCompletionMethod();
    
    /**
     * Sets the beforeCompletion method used by stateful.
     * @param beforeCompletionMethod the given afterCompletion method
     */
    void setBeforeCompletionMethod(final IMethodDD beforeCompletionMethod);
    
    /**
     * @return the given beforeCompletion method
     */
    IMethodDD getBeforeCompletionMethod();

    /**
     * Set the stateful timeout .
     *
     * @param statefulTimeout the given stateful timeout.
     */
    void setStatefulTimeout(IStatefulTimeout statefulTimeout);
    
    /**
     * @return the given timeout.
     */
    IStatefulTimeout getStatefulTimeout();
}
