/**
 * Copyright 2013 Peergreen S.A.S.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ow2.util.ee.metadata.ejbjar.impl.configurator;

import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxAnnotationSecurityPermitAllVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxAnnotationSecurityRolesAllowedVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxInterceptorExcludeDefaultInterceptorsVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.JavaxEjbAccessTimeoutVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.JavaxEjbLockVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.JavaxEjbTransactionAttributeVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz.JavaxAnnotationSecurityDeclareRolesVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz.JavaxEjbApplicationExceptionVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz.JavaxEjbConcurrencyManagementVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz.JavaxEjbDependsOnVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz.JavaxEjbLocalBeanVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz.JavaxEjbLocalHomeVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz.JavaxEjbLocalVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz.JavaxEjbMessageDrivenVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz.JavaxEjbRemoteHomeVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz.JavaxEjbRemoteVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz.JavaxEjbSingletonVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz.JavaxEjbStartupVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz.JavaxEjbStatefulTimeoutVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz.JavaxEjbStatefulVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz.JavaxEjbStatelessVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz.JavaxEjbTransactionManagementVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.method.JavaxAnnotationSecurityDenyAllVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.method.JavaxEjbAfterBeginVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.method.JavaxEjbAfterCompletionVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.method.JavaxEjbBeforeCompletionVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.method.JavaxEjbInitVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.method.JavaxEjbPostActivateVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.method.JavaxEjbPrePassivateVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.method.JavaxEjbRemoveVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.method.JavaxEjbScheduleVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.method.JavaxEjbSchedulesVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.method.JavaxEjbTimeoutVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.method.JavaxInterceptorAroundInvokeVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.method.JavaxInterceptorExcludeClassInterceptorsVisitor;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.method.JavaxJwsWebMethodVisitor;
import org.ow2.util.scan.api.configurator.basic.AnnotationConfigurator;

/**
 * Configurator for EJB annotations
 * @author Florent Benoit
 */
public class EjbAnnotationConfigurator extends AnnotationConfigurator {


    public EjbAnnotationConfigurator() {
        registerAnnotationVisitors();
    }

    /**
     * register annotation visitor.
     */
    protected void registerAnnotationVisitors() {

        // add @Local
        registerAnnotationVisitor(new JavaxEjbLocalVisitor());

        // add @LocalBean
        registerAnnotationVisitor(new JavaxEjbLocalBeanVisitor());

        // add @Remote
        registerAnnotationVisitor(new JavaxEjbRemoteVisitor());

        // add @Stateless
        registerAnnotationVisitor(new JavaxEjbStatelessVisitor());

        // add @Stateful
        registerAnnotationVisitor(new JavaxEjbStatefulVisitor());

        // add @MessageDriven
        registerAnnotationVisitor(new JavaxEjbMessageDrivenVisitor());

        // add @LocalHome
        registerAnnotationVisitor(new JavaxEjbLocalHomeVisitor());

        // add @RemoteHome
        registerAnnotationVisitor(new JavaxEjbRemoteHomeVisitor());

        // add @TransactionManagement
        registerAnnotationVisitor(new JavaxEjbTransactionManagementVisitor());

        // add @TransactionAttribute
        registerAnnotationVisitor(new JavaxEjbTransactionAttributeVisitor());

        // add @ApplicationException
        registerAnnotationVisitor(new JavaxEjbApplicationExceptionVisitor());

        // add @DeclareRoles
        registerAnnotationVisitor(new JavaxAnnotationSecurityDeclareRolesVisitor());

        // add @RolesAllowed
        registerAnnotationVisitor(new JavaxAnnotationSecurityRolesAllowedVisitor());

        // add @PermitAll
        registerAnnotationVisitor(new JavaxAnnotationSecurityPermitAllVisitor());

        // add @ExcludeDefaultInterceptors
        registerAnnotationVisitor(new JavaxInterceptorExcludeDefaultInterceptorsVisitor());

        // add @Singleton
        registerAnnotationVisitor(new JavaxEjbSingletonVisitor());

        // add @Startup
        registerAnnotationVisitor(new JavaxEjbStartupVisitor());

        // add @Lock
        registerAnnotationVisitor(new JavaxEjbLockVisitor());

        // add @ConcurrencyManagement
        registerAnnotationVisitor(new JavaxEjbConcurrencyManagementVisitor());

        // add @DependsOn
        registerAnnotationVisitor(new JavaxEjbDependsOnVisitor());

        // add @AccessTimeout
        registerAnnotationVisitor(new JavaxEjbAccessTimeoutVisitor());

        // add @StatefulTimeout
        registerAnnotationVisitor(new JavaxEjbStatefulTimeoutVisitor());

        // add @Init
        registerAnnotationVisitor(new JavaxEjbInitVisitor());

        // add @Remove
        registerAnnotationVisitor(new JavaxEjbRemoveVisitor());

        // add @PostActivate
        registerAnnotationVisitor(new JavaxEjbPostActivateVisitor());

        // add @PrePassivate
        registerAnnotationVisitor(new JavaxEjbPrePassivateVisitor());

        // add @Timeout
        registerAnnotationVisitor(new JavaxEjbTimeoutVisitor());

        // add @AroundInvoke
        registerAnnotationVisitor(new JavaxInterceptorAroundInvokeVisitor());

        // add @ExcludeClassInterceptors
        registerAnnotationVisitor(new JavaxInterceptorExcludeClassInterceptorsVisitor());

        // add @PermitAll
        registerAnnotationVisitor(new JavaxAnnotationSecurityDeclareRolesVisitor());

        // add @DenyAll
        registerAnnotationVisitor(new JavaxAnnotationSecurityDenyAllVisitor());

        // add @WebMethod
        registerAnnotationVisitor(new JavaxJwsWebMethodVisitor());

        // add @AfterBegin
        registerAnnotationVisitor(new JavaxEjbAfterBeginVisitor());

        // add @BeforeCompletion
        registerAnnotationVisitor(new JavaxEjbBeforeCompletionVisitor());

        // add @AfterCompletion
        registerAnnotationVisitor(new JavaxEjbAfterCompletionVisitor());

        // add @Schedule
        registerAnnotationVisitor(new JavaxEjbScheduleVisitor());

        // add @Schedules
        registerAnnotationVisitor(new JavaxEjbSchedulesVisitor());

    }
}
