/**
 * Copyright 2009-2012 Bull S.A.S.
 * Copyright 2013 Peergreen S.A.S.
 *
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.configurator;

import org.ow2.util.ee.metadata.common.api.struct.IJInterceptors;
import org.ow2.util.ee.metadata.common.impl.view.CommonView;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarMetadata;
import org.ow2.util.scan.api.IScannerResult;
import org.ow2.util.scan.api.configurator.basic.ClassMetadataConfigurator;
import org.ow2.util.scan.api.metadata.IClassMetadata;
import org.ow2.util.scan.api.metadata.IMethodMetadata;

/**
 * WarClassMetadataConfigurator.
 * @author Florent Benoit
 */
public class EjbJarClassMetadataConfigurator extends ClassMetadataConfigurator {

    private final IEjbJarMetadata ejbJarMetadata;

    /**
     * WarClassMetadataConfigurator.
     * @param jClass signature
     * @param warArchiveMetadata parent
     * @param annotationParsingDesactived annotationParsingDesactived
     * @param specificWarDeployableMetadataConfiguratorList specificWarDeployableMetadataConfiguratorList
     */
    public EjbJarClassMetadataConfigurator(
            final IClassMetadata classMetadata,
            final IEjbJarMetadata ejbJarMetadata) {
        super(classMetadata);
        this.ejbJarMetadata = ejbJarMetadata;
    }


    /**
     * add class to archive.
     * @param scannerResult
     */
    @Override
    public void configurationComplete(IScannerResult scannerResult) {
        IClassMetadata classMetadata = getClassMetadata();
        ejbJarMetadata.addScannedClassMetadata(classMetadata);
        classMetadata.setParent(ejbJarMetadata);
        CommonView view = classMetadata.as(CommonView.class);

        // add interceptors class name on class
        IJInterceptors interceptors = view.getAnnotationInterceptors();
        if (interceptors != null) {
            scannerResult.getReferencedClasses().addAll(interceptors.getClasses());
        }
        for (IMethodMetadata methodMetadata : classMetadata.getMethodMetadataCollection()) {
            // add interceptors class name on method
            CommonView methodView = methodMetadata.as(CommonView.class);
            interceptors = methodView.getAnnotationInterceptors();
            if (interceptors != null) {
                scannerResult.getReferencedClasses().addAll(interceptors.getClasses());
            }
        }
        super.configurationComplete(scannerResult);
    }

}
