/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor;

import static java.lang.annotation.ElementType.TYPE;
import static org.ow2.util.ee.metadata.common.api.struct.ITransactionAttributeType.MANDATORY;
import static org.ow2.util.ee.metadata.common.api.struct.ITransactionAttributeType.NEVER;
import static org.ow2.util.ee.metadata.common.api.struct.ITransactionAttributeType.NOT_SUPPORTED;
import static org.ow2.util.ee.metadata.common.api.struct.ITransactionAttributeType.REQUIRED;
import static org.ow2.util.ee.metadata.common.api.struct.ITransactionAttributeType.REQUIRES_NEW;
import static org.ow2.util.ee.metadata.common.api.struct.ITransactionAttributeType.SUPPORTS;

import org.ow2.util.ee.metadata.ejbjar.api.view.IEJBClassView;
import org.ow2.util.scan.api.IAnnotationVisitorContext;
import org.ow2.util.scan.api.VoidAnnotationVisitor;
import org.ow2.util.scan.api.annotation.VisitorTarget;
import org.ow2.util.scan.api.annotation.VisitorType;


/**
 * This class manages the handling of &#64;{@link javax.ejb.JavaxEjbTransactionAttributeVisitor} annotation.
 * @author Florent Benoit
 */
@VisitorTarget(TYPE)
@VisitorType("javax.ejb.TransactionAttribute")
public class JavaxEjbTransactionAttributeVisitor extends VoidAnnotationVisitor {

    /**
     * Visits an enumeration value of the annotation.
     * @param name the value name.
     * @param desc the class descriptor of the enumeration class.
     * @param value the actual enumeration value.
     */
    @Override
    public void visitEnum(final String name, final String desc, final String value, IAnnotationVisitorContext<Void> annotationVisitorContext) {
        if (MANDATORY.name().equals(value)) {
            annotationVisitorContext.getView(IEJBClassView.class).setTransactionAttributeType(MANDATORY);
        } else if (REQUIRED.name().equals(value)) {
            annotationVisitorContext.getView(IEJBClassView.class).setTransactionAttributeType(REQUIRED);
        } else if (REQUIRES_NEW.name().equals(value)) {
            annotationVisitorContext.getView(IEJBClassView.class).setTransactionAttributeType(REQUIRES_NEW);
        } else if (SUPPORTS.name().equals(value)) {
            annotationVisitorContext.getView(IEJBClassView.class).setTransactionAttributeType(SUPPORTS);
        } else if (NOT_SUPPORTED.name().equals(value)) {
            annotationVisitorContext.getView(IEJBClassView.class).setTransactionAttributeType(NOT_SUPPORTED);
        } else if (NEVER.name().equals(value)) {
            annotationVisitorContext.getView(IEJBClassView.class).setTransactionAttributeType(NEVER);
        } else {
            // set default
            annotationVisitorContext.getView(IEJBClassView.class).setTransactionAttributeType(REQUIRED);
        }
    }


}