/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz;

import org.ow2.util.ee.metadata.ejbjar.api.struct.IJCommonBean;
import org.ow2.util.ee.metadata.ejbjar.api.view.IEJBClassView;
import org.ow2.util.scan.api.IAnnotationVisitorContext;
import org.ow2.util.scan.api.IType;
import org.ow2.util.scan.api.visitor.DefaultAnnotationVisitor;

/**
 * This class manages the handling of common annotations used by beans.
 * @author Florent Benoit
 */
public abstract class AbsCommonEjbVisitor<T extends IJCommonBean> extends DefaultAnnotationVisitor<T> {

    /**
     * Name attribute of the annotation.
     */
    private static final String NAME = "name";

    /**
     * mappedName attribute of the annotation.
     */
    private static final String MAPPED_NAME = "mappedName";

    /**
     * description attribute of the annotation.
     */
    private static final String DESCRIPTION = "description";

    /**
     * Visits a primitive value of the annotation.<br>
     * @param name the value name.
     * @param value the actual value, whose type must be {@link Byte},
     *        {@link Boolean}, {@link Character}, {@link Short},
     *        {@link Integer}, {@link Long}, {@link Float}, {@link Double},
     *        {@link String} or {@link IType}.
     */
    @Override
    public void visit(final String name, final Object value, IAnnotationVisitorContext<T> annotationVisitorContext) {
        T jcommonBean = annotationVisitorContext.getLocal();
        if (name.equals(NAME)) {
            jcommonBean.setName((String) value);
        } else if (name.equals(MAPPED_NAME)) {
            jcommonBean.setMappedName((String) value);
        } else if (name.equals(DESCRIPTION)) {
            jcommonBean.setDescription((String) value);
        }
    }

    /**
     * Visits the end of the annotation. <br> Creates the object and store it.
     */
    @Override
    public void visitEnd(IAnnotationVisitorContext<T> annotationVisitorContext) {
        IEJBClassView view = annotationVisitorContext.getView(IEJBClassView.class);
        view.setJCommonBean(annotationVisitorContext.getLocal());
    }

}
