/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz;

import static java.lang.annotation.ElementType.TYPE;

import java.util.List;

import org.ow2.util.ee.metadata.ejbjar.api.view.IEJBClassView;
import org.ow2.util.scan.api.IAnnotationVisitorContext;
import org.ow2.util.scan.api.annotation.VisitorTarget;
import org.ow2.util.scan.api.annotation.VisitorType;
import org.ow2.util.scan.api.visitor.ObjectArrayAnnotationVisitor;

/**
 * This class manages the handling of &#64;{@link javax.annotation.security.DeclareRoles}
 * annotation.
 * @author Florent Benoit
 */
@VisitorTarget(TYPE)
@VisitorType("javax.annotation.security.DeclareRoles")
public class JavaxAnnotationSecurityDeclareRolesVisitor extends ObjectArrayAnnotationVisitor<String> {

    /**
     * Visits the end of the annotation.<br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd(IAnnotationVisitorContext<List<String>> annotationVisitorContext) {
        if (annotationVisitorContext.getLocal().size() > 0) {
            annotationVisitorContext.getView(IEJBClassView.class).setDeclareRoles(annotationVisitorContext.getLocal());
        }

    }

}