/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz;

import static java.lang.annotation.ElementType.TYPE;

import org.ow2.util.ee.metadata.ejbjar.api.struct.IApplicationException;
import org.ow2.util.ee.metadata.ejbjar.impl.struct.JApplicationException;
import org.ow2.util.scan.api.IAnnotationVisitorContext;
import org.ow2.util.scan.api.IType;
import org.ow2.util.scan.api.annotation.VisitorTarget;
import org.ow2.util.scan.api.annotation.VisitorType;
import org.ow2.util.scan.api.visitor.DefaultAnnotationVisitor;

/**
 * This class manages the handling of the &#64;{@link javax.ejb.ApplicationException} annotation.<br>
 * @author Florent Benoit
 */
@VisitorTarget(TYPE)
@VisitorType("javax.ejb.ApplicationException")
public class JavaxEjbApplicationExceptionVisitor extends DefaultAnnotationVisitor<IApplicationException> {

    /**
     * rollback attribute of the annotation.
     */
    private static final String ROLLBACK = "rollback";

    /**
     * inherited attribute of the annotation.
     */
    private static final String INHERITED = "inherited";

    /**
     * Visits a primitive value of the annotation.<br>
     * @param name the value name.
     * @param value the actual value, whose type must be {@link Byte},
     *        {@link Boolean}, {@link Character}, {@link Short},
     *        {@link Integer}, {@link Long}, {@link Float}, {@link Double},
     *        {@link String} or {@link IType}.
     */
    @Override
    public void visit(final String name, final Object value, IAnnotationVisitorContext<IApplicationException> annotationVisitorContext) {
        IApplicationException applicationException = annotationVisitorContext.getLocal();

        if (ROLLBACK.equals(name)) {
            applicationException.setRollback(((Boolean) value));
        } else if (INHERITED.equals(name)) {
            applicationException.setInherited(((Boolean) value));
        }
    }


    /**
     * Visits the end of the annotation. Creates the object and store it.
     */
    @Override
    public void visitEnd(IAnnotationVisitorContext<IApplicationException> annotationVisitorContext) {
        annotationVisitorContext.set(annotationVisitorContext.getLocal());
    }


    @Override
    public IApplicationException buildInstance() {
        return new JApplicationException();
    }

}
