/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.method;

import static java.lang.annotation.ElementType.METHOD;

import org.ow2.util.ee.metadata.ejbjar.api.struct.IJEjbSchedule;
import org.ow2.util.ee.metadata.ejbjar.api.view.IEJBMethodView;
import org.ow2.util.ee.metadata.ejbjar.impl.struct.JEJBSchedule;
import org.ow2.util.scan.api.IAnnotationVisitorContext;
import org.ow2.util.scan.api.annotation.VisitorTarget;
import org.ow2.util.scan.api.annotation.VisitorType;
import org.ow2.util.scan.api.visitor.DefaultAnnotationVisitor;

/**
 * This class manages the handling of &#64;{@link javax.ejb.Schedule} annotation.
 * @param <T> An implementation of IAnnotationEJB interface.
 * @author Florent Benoit
 */
@VisitorTarget(METHOD)
@VisitorType("javax.ejb.Schedule")
public class JavaxEjbScheduleVisitor extends DefaultAnnotationVisitor<IJEjbSchedule> {

    /**
     * second attribute of the annotation.
     */
    private static final String SECOND = "second";

    /**
     * minute attribute of the annotation.
     */
    private static final String MINUTE = "minute";

    /**
     * hour attribute of the annotation.
     */
    private static final String HOUR = "hour";

    /**
     * dayOfMonth attribute of the annotation.
     */
    private static final String DAY_OF_MONTH = "dayOfMonth";

    /**
     * month attribute of the annotation.
     */
    private static final String MONTH = "month";

    /**
     * dayOfWeek attribute of the annotation.
     */
    private static final String DAY_OF_WEEK = "dayOfWeek";

    /**
     * year attribute of the annotation.
     */
    private static final String YEAR = "year";

    /**
     * timezone attribute of the annotation.
     */
    private static final String TIMEZONE = "timezone";

    /**
     * info attribute of the annotation.
     */
    private static final String INFO = "info";

    /**
     * persistent attribute of the annotation.
     */
    private static final String PERSISTENT = "persistent";

    /**
     * Visits a primitive value of the annotation.<br>
     * @param name the value name.
     * @param value the actual value, whose type must be {@link Byte},
     *        {@link Boolean}, {@link Character}, {@link Short},
     *        {@link Integer}, {@link Long}, {@link Float}, {@link Double},
     *        {@link String} or {@link org.ow2.util.scan.api.IType}.
     */
    @Override
    public void visit(final String name, final Object value, IAnnotationVisitorContext<IJEjbSchedule> annotationVisitorContext) {
        IJEjbSchedule jEjbSchedule = annotationVisitorContext.getLocal();
        if (SECOND.equals(name)) {
            jEjbSchedule.setSecond((String) value);
        } else if (MINUTE.equals(name)) {
            jEjbSchedule.setMinute((String) value);
        } else if (HOUR.equals(name)) {
            jEjbSchedule.setHour((String) value);
        } else if (DAY_OF_MONTH.equals(name)) {
            jEjbSchedule.setDayOfMonth((String) value);
        } else if (MONTH.equals(name)) {
            jEjbSchedule.setMonth((String) value);
        } else if (DAY_OF_WEEK.equals(name)) {
            jEjbSchedule.setDayOfWeek((String) value);
        } else if (YEAR.equals(name)) {
            jEjbSchedule.setYear((String) value);
        } else if (TIMEZONE.equals(name)) {
            jEjbSchedule.setTimezone((String) value);
        } else if (INFO.equals(name)) {
            jEjbSchedule.setInfo((String) value);
        } else if (PERSISTENT.equals(name)) {
            jEjbSchedule.setPersistent((Boolean) value);
        }
    }

    /**
     * Visits the end of the annotation. <br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd(IAnnotationVisitorContext<IJEjbSchedule> annotationVisitorContext) {
        // add object
        annotationVisitorContext.getView(IEJBMethodView.class).addJavaxEjbSchedule(annotationVisitorContext.getLocal());
    }

    @Override
    public IJEjbSchedule buildInstance() {
        return new JEJBSchedule();
    }



}
