/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.struct;

import java.io.Serializable;

import org.ow2.util.ee.metadata.ejbjar.api.struct.IActivationConfigProperty;

/**
 * Acts as an implementation of &#64;{javax.ejb.ActivationConfigProperty} annotation.
 * @author Florent Benoit
 */
public class JActivationConfigProperty implements IActivationConfigProperty, Serializable {

    /**
     * Serial Version UID.
     */
    private static final long serialVersionUID = 8915019314363468405L;

    /**
     * Name.
     */
    private String name = null;

    /**
     * Value.
     */
    private String value = null;

    /**
     * Constructor.<br>
     * Build an object with a given name and a given value.
     * @param name given name
     * @param value given value
     */
    public JActivationConfigProperty(final String name, final String value) {
        this.name = name;
        this.value = value;
    }


    /**
     * @return property name
     */
    @Override
    public String propertyName() {
        return name;
    }

    /**
     * @return property value
     */
    @Override
    public String propertyValue() {
        return value;
    }

    /**
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));
        // property name
        sb.append("[propertyName=");
        sb.append(name);

        // property value
        sb.append(", propertyValue=");
        sb.append(value);

        sb.append("]");
        return sb.toString();
    }

    /**
     * Set property name
     * @param name
     */
    @Override
    public void setPropertyName(String name) {
        this.name = name;
    }

    /**
     * Set property value
     * @param value
     */
    @Override
    public void setPropertyValue(String value) {
        this.value = value;
    }
}
