/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.struct;

import org.ow2.util.ee.metadata.ejbjar.api.struct.IJEjbSchedule;

/**
 * Acts as an implementation of &#64;{@link javax.ejb.Schedule} annotation.
 * @author Florent Benoit
 */
public class JEJBSchedule implements IJEjbSchedule {

    /**
     * Serial Version UID.
     */
    private static final long serialVersionUID = 74805725422913109L;

    /**
     * Seconds. 
     */
    private String second = "0";

    /**
     * Minutes.
     */
    private String minute = "0";

    /**
     * Hour.
     */
    private String hour = "0";

    /**
     * Day of Month.
     */
    private String dayOfMonth = "*";

    /**
     * Month.
     */
    private String month = "*";

    /**
     * Day of Week.
     */
    private String dayOfWeek = "*";

    /**
     * Year
     */
    private String year = "*";

    /**
     * Timezone.
     */
    private String timezone = "";

    /**
     * Callback info.
     */
    private String info = "";

    /**
     * Timer is persistent.
     */
    private boolean persistent = true;

    /**
     * Start.
     */
    private String start = null;
    
    /**
     * End.
     */
    private String end = null;
    
    
    /**
     * Constructor.
     */
    public JEJBSchedule() {
    }

    /**
     * @return seconds
     */
    public String getSecond() {
        return second;
    }

    /**
     * Sets the seconds
     * @param second the value
     */
    public void setSecond(String second) {
        this.second = second;
    }

    /**
     * @return minutes
     */
    public String getMinute() {
        return minute;
    }

    /**
     * Sets the minute
     * @param minute the value
     */
    public void setMinute(String minute) {
        this.minute = minute;
    }

    /**
     * @return hour
     */
    public String getHour() {
        return hour;
    }

    /**
     * Sets the hour
     * @param hour the value
     */
    public void setHour(String hour) {
        this.hour = hour;
    }

    /**
     * @return day of month
     */
    public String getDayOfMonth() {
        return dayOfMonth;
    }

    /**
     * Sets the day of month
     * @param dayOfMonth the value
     */
    public void setDayOfMonth(String dayOfMonth) {
        this.dayOfMonth = dayOfMonth;
    }

    /**
     * @return month
     */
    public String getMonth() {
        return month;
    }

    /**
     * Sets the month
     * @param month the value
     */
    public void setMonth(String month) {
        this.month = month;
    }

    /**
     * @return day of week
     */
    public String getDayOfWeek() {
        return dayOfWeek;
    }

    /**
     * Sets the day of week
     * @param dayOfWeek the value
     */
    public void setDayOfWeek(String dayOfWeek) {
        this.dayOfWeek = dayOfWeek;
    }

    /**
     * @return year
     */
    public String getYear() {
        return year;
    }

    /**
     * Sets the year
     * @param year the value
     */
    public void setYear(String year) {
        this.year = year;
    }

    /**
     * @return timezone
     */
    public String getTimezone() {
        return timezone;
    }

    /**
     * Sets the timezone
     * @param timezone the value
     */
    public void setTimezone(String timezone) {
        this.timezone = timezone;
    }

    /**
     * @return info used for the timer callback
     */
    public String getInfo() {
        return info;
    }

    /**
     * Sets the info
     * @param info the value
     */
    public void setInfo(String info) {
        this.info = info;
    }

    /**
     * @return true if schedule is persistent
     */
    public boolean isPersistent() {
        return persistent;
    }

    /**
     * Sets the persistent
     * @param persistent the value
     */
    public void setPersistent(boolean persistent) {
        this.persistent = persistent;
    }
    
    /**
     * @return start time
     */
    public String getStart() {
        return start;
    }

    /**
     * Sets the start time
     * @param start the value
     */
    public void setStart(String start) {
        this.start = start;
    }

    /**
     * @return end time
     */
    public String getEnd() {
        return end;
    }
    
    /**
     * Sets the end time
     * @param end the value
     */
    public void setEnd(String end) {
        this.end = end;
    }

    /**
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));

        // second
        sb.append("[second=");
        sb.append(second);

        // minute
        sb.append(", minute=");
        sb.append(minute);

        // hour
        sb.append(", hour=");
        sb.append(hour);

        // dayOfMonth
        sb.append(", dayOfMonth=");
        sb.append(dayOfMonth);

        // month
        sb.append(", month=");
        sb.append(month);

        // dayOfWeek
        sb.append(", dayOfWeek=");
        sb.append(dayOfWeek);

        // year
        sb.append(", year=");
        sb.append(year);

        // timezone
        sb.append(", timezone=");
        sb.append(timezone);

        // info
        sb.append(", info=");
        sb.append(info);
        
        // start
        if (start != null) {
            sb.append(", start=");
            sb.append(start);
        }
        
        // end
        if (end != null) {
            sb.append(", end=");
            sb.append(end);
        }

        sb.append("]");
        return sb.toString();
    }

}
