/**
 * OW2 Utilities
 * Copyright (C) 2009-2012 Bull S.A.S.
 * Contact: utilities@ow2.org
 *
 * Licensed  under the  Apache License,  Version 2.0  (the "License");
 * you may not use  this file  except in  compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed  under the  License is distributed on an "AS IS" BASIS,
 * WITHOUT  WARRANTIES OR CONDITIONS  OF ANY KIND, either  express  or
 * implied.
 *
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.struct;

import java.util.concurrent.TimeUnit;

import org.ow2.util.ee.metadata.ejbjar.api.struct.IJEjbStatefulTimeout;

/**
 * Acts as an implementation of &#64;{@link javax.ejb.StatefulTimeout} annotation.
 * @author Florent Benoit
 */
public class JEJBStatefulTimeout implements IJEjbStatefulTimeout {

    /**
     * Serial Version UID.
     */
    private static final long serialVersionUID = 952116570290841137L;

    /**
     * value.
     */
    private long value;

    /**
     * TimeUnit.
     */
    private TimeUnit timeUnit;

    /**
     * Constructor.
     */
    public JEJBStatefulTimeout() {
        // default type
        this.timeUnit = TimeUnit.MINUTES;
    }

    /**
     * @return value (value to be used).
     */
    public long getValue() {
        return value;
    }

    /**
     * Sets the value.
     * @param value the given value.
     */
    public void setValue(final long value) {
        this.value = value;
    }

    /**
     * @return the unit type.
     */
    public TimeUnit getUnit() {
        return timeUnit;
    }

    /**
     * Sets the unit type.
     * @param timeUnit value to set.
     */
    public void setUnit(final TimeUnit timeUnit) {
        this.timeUnit = timeUnit;
    }

    /**
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));

        // name
        sb.append("[value=");
        sb.append(value);

        // type
        sb.append(", unit=");
        sb.append(timeUnit);

        sb.append("]");
        return sb.toString();
    }

}
