/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.struct;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.ee.metadata.ejbjar.api.struct.IJInterface;

/**
 * List of interfaces.
 * @author Florent Benoit
 */
public abstract class JInterface implements IJInterface {

    /**
     * Serial Version UID.
     */
    private static final long serialVersionUID = 6039778943125019974L;

    /**
     * List of interfaces.
     */
    private List<String> interfaces = null;

    /**
     * Constructor.
     */
    public JInterface() {
        interfaces = new ArrayList<String>();
    }

    /**
     * Add an interface.
     * @param itf name of the interface (asm)
     */
    public void addInterface(final String itf) {
        interfaces.add(itf);
    }

    /**
     * @return list of interfaces.
     */
    public List<String> getInterfaces() {
        return interfaces;
    }

    /**
     * @param itf the name of an encoded interface.
     * @return true if the interface is already in the list.
     */
    public boolean contains(final String itf) {
        return interfaces.contains(itf);
    }

    /**
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));

        // list
        sb.append(interfaces);
        return sb.toString();
    }
}
