/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.struct;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.ee.metadata.ejbjar.api.struct.IActivationConfigProperty;
import org.ow2.util.ee.metadata.ejbjar.api.struct.IJMessageDriven;

/**
 * Acts as an implementation of &#64;{@link javax.ejb.MessageDriven} annotation.
 * @author Florent Benoit
 */
public class JMessageDriven extends JCommonBean implements IJMessageDriven {

    /**
     * Serial Version UID.
     */
    private static final long serialVersionUID = 6169724975477306344L;

    /**
     * List of ActivationConfigProperty.
     */
    private List<IActivationConfigProperty> activationConfigProperties = null;

    /**
     * Message listener Interface.
     */
    private String messageListenerInterface = null;

    /**
     * Message destination link.
     */
    private String messageDestinationLink = null;

    /**
     * Build an object which represents &#64;{@link javax.ejb.MessageDriven} object.
     */
    public JMessageDriven() {
        super();
        activationConfigProperties = new ArrayList<IActivationConfigProperty>();
    }

    /**
     * Adds an activation config property.
     * @param activationConfigProperty object to add in the list
     */
    public void addActivationConfigProperty(final IActivationConfigProperty activationConfigProperty) {
        activationConfigProperties.add(activationConfigProperty);
    }

    /**
     * Gets the activation config properties.
     * @return the list of activation config properties
     */
    public List<IActivationConfigProperty> getActivationConfigProperties() {
        return activationConfigProperties;
    }

    /**
     * @return message listener interface.
     */
    public String getMessageListenerInterface() {
        return messageListenerInterface;
    }

    /**
     * Sets the message listener interface.
     * @param messageListenerInterface the given interface.
     */
    public void setMessageListenerInterface(final String messageListenerInterface) {
        this.messageListenerInterface = messageListenerInterface;
    }

    /**
     * Set the message destination link.
     * @param messageDestinationLink message destination link.
     */
    public void setMessageDestinationLink(final String messageDestinationLink) {
        this.messageDestinationLink = messageDestinationLink;
    }

    /**
     * Gets the message destination link.
     * @return the message destination link
     */
    public String getMessageDestinationLink() {
        return messageDestinationLink;
    }

    /**
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));

        sb.append(super.toString());

        // messageListenerInterface
        sb.append("[messageListenerInterface=");
        sb.append(messageListenerInterface);

        //messageDestinationLink
        sb.append(", messageDestinationLink=");
        sb.append(messageDestinationLink);

        // property value
        sb.append(", activationConfigProperties=");
        sb.append(activationConfigProperties);

        sb.append("]");
        return sb.toString();
    }
}
