/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.struct;

import java.io.Serializable;

import org.ow2.util.ee.metadata.ejbjar.api.struct.IJEjbRemove;

/**
 * Acts as an implementation of &#64;{javax.ejb.Remove} annotation.
 * @author Florent Benoit
 */
public class JRemove implements IJEjbRemove, Serializable {

    /**
     * Serial Version UID.
     */
    private static final long serialVersionUID = 5621152969822142924L;

    /**
     * Don't remove object if there is an application exception.
     */
    private boolean retainIfException = false;

    /**
     * Build an object which represents&#64;{javax.ejb.Remove}.<br>
     * Default value for retainIfException is false.
     */
    public JRemove() {
        this(false);
    }

    /**
     * Build an object which represents&#64;{@link javax.ejb.Remove} with a
     * given boolean.
     * @param retainIfException true/false (false is a default value)
     */
    public JRemove(final boolean retainIfException) {
        this.retainIfException = retainIfException;
    }

    /**
     * @return the retainIfException value (true/false).
     */
    @Override
    public boolean retainIfException() {
        return retainIfException;
    }


    @Override
    public void setRetainIfException(boolean retainIfException) {
        this.retainIfException = retainIfException;
    }

    /**
     * @return string representation.
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));
        // retainIfException
        sb.append("[retainIfException=");
        sb.append(retainIfException);

        sb.append("]");
        return sb.toString();
    }
}
