/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.xml.helper;

import java.util.Collection;

import org.ow2.util.ee.metadata.common.api.interfaces.IEnvironmentRefAccessor;
import org.ow2.util.ee.metadata.common.impl.xml.merge.MetadataMerge;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarMetadata;
import org.ow2.util.scan.api.metadata.IClassMetadata;
import org.ow2.util.scan.api.metadata.IFieldMetadata;
import org.ow2.util.scan.api.metadata.IMethodMetadata;

/**
 * Defines common stuff that can be used by merger of Deployment Descriptor into
 * the metadata.
 * @author Florent BENOIT
 */
public class CommonMetadataMerge extends MetadataMerge {

    /**
     * Metadata for an ejb-jar.
     */
    private IEjbJarMetadata ejbMetadata = null;

    /**
     * Logger.
     */
    //private static Log logger = LogFactory.getLog(CommonMetadataMerge.class);

    /**
     * Constructor that can be used by subclass.
     * @param ejbMetadata the metadata corresponding to an EJB-JAR file.
     */
    protected CommonMetadataMerge(final IEjbJarMetadata ejbMetadata) {
        this.ejbMetadata = ejbMetadata;
    }

    /**
     * @return the EJB metadata of this merger.
     */
    public IEjbJarMetadata getEjbJarDeployableMetadata() {
        return ejbMetadata;
    }

    @Override
    public String findDefaultClassForEnvironment(final IEnvironmentRefAccessor env) {
        return null;
    }

    @Override
    public IClassMetadata getClassMetadata(final String className) {
        return ejbMetadata.getScannedClassMetadata(className);
    }

    /**
     * @return A collection of all ClassMetadata of the merged object.
     */
    @Override
    protected Collection<IClassMetadata> getAllClassMetadatas() {
        throw new UnsupportedOperationException("EjbJar does not supports metadata browsing.");
    }

    /**
     * @return A collection of all MethodMetadata of the merged object.
     */
    @Override
    protected Collection<IMethodMetadata> getAllMethodMetadatas() {
        throw new UnsupportedOperationException("EjbJar does not supports metadata browsing.");
    }

    /**
     * @return A collection of all FieldMetadata of the merged object.
     */
    @Override
    protected Collection<IFieldMetadata> getAllFieldMetadatas() {
        throw new UnsupportedOperationException("EjbJar does not supports metadata browsing.");
    }


}
