/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.xml.parsing;

import java.net.URL;

import org.ow2.util.archive.api.ArchiveException;
import org.ow2.util.archive.api.IArchive;
import org.ow2.util.ee.metadata.common.impl.xml.parsing.ParsingException;
import org.ow2.util.ee.metadata.ejbjar.impl.xml.struct.EJB3;

/**
 * Utility class to get a deployment descriptor.
 * @author Florent Benoit
 */
public final class EJB3DeploymentDesc {

    /**
     * Utility class, no public constructor.
     */
    private EJB3DeploymentDesc() {

    }

    /**
     * Gets EJB3 for a given archive.
     * @param archive file/directory.
     * @throws ParsingException if no xml is present.
     * @return EJB3 instance or null.
     */
    public static EJB3 getEjb3(final IArchive archive) throws ParsingException {

        // Get XML entry
        URL ejbjarXmlURL = null;
        try {
            ejbjarXmlURL = archive.getResource("META-INF/ejb-jar.xml");
        } catch (ArchiveException e) {
            throw new ParsingException("Cannot get resource 'META-INF/ejb-jar.xml' on the archive '"
                    + archive.getName() + "'.");
        }

        EJB3 ejb3 = null;
        // Get EJB3 object (if url valid)
        if (ejbjarXmlURL != null) {
            ejb3 = EJB3DeploymentDescLoader.loadDeploymentDescriptor(ejbjarXmlURL);
        }
        return ejb3;
    }

}
