/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.xml.struct;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.xml.struct.IMethodDD;
import org.ow2.util.ee.metadata.common.impl.xml.struct.AbsEnvironment;
import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IBean;
import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.ITimer;

/**
 * Defines common rules used by Bean (Session, MDB).
 * @author Florent Benoit
 *
 */
public class AbsBean extends AbsEnvironment implements IBean {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = -6950366820850131731L;

    /**
     * ejb-name.
     */
    private String ejbName = null;

    /**
     * ejb-class.
     */
    private String ejbClass = null;

    /**
     * Run-As Role.
     */
    private String runAsRole = null;

    /**
     * Mapped name.
     */
    private String mappedName = null;

    /**
     * Type of transaction.
     */
    private String transactionType = null;

    
    /**
     * List of timers.
     */
    private List<ITimer> timers = null;
    
    /**
     * Timeout Method.
     */
    private IMethodDD timeoutMethod = null;
    
    /**
     * Constructor.
     */
    public AbsBean() {
        super();
        this.timers = new ArrayList<ITimer>();
    }

    /**
     * Gets the ejb-name.
     * @return the ejb-name
     */
    public String getEjbName() {
        return ejbName;
    }

    /**
     * Set the ejb-name.
     * @param ejbName ejbName
     */
    public void setEjbName(final String ejbName) {
        this.ejbName = ejbName;
    }

    /**
     * Gets the ejb-class.
     * @return the ejb-class
     */
    public String getEjbClass() {
        return ejbClass;
    }

    /**
     * Set the ejb-class.
     * @param ejbClass ejb-class
     */
    public void setEjbClass(final String ejbClass) {
        this.ejbClass = ejbClass;
    }

    /**
     * Gets the run-as role.
     * @return the run-as role
     */
    public String getRunAsRole() {
        return runAsRole;
    }

    /**
     * Set the run-as role.
     * @param runAsRole the run-as role
     */
    public void setRunAsRole(final String runAsRole) {
        this.runAsRole = runAsRole;
    }

    /**
     * Gets the mapped name.
     * @return the mapped name
     */
    public String getMappedName() {
        return mappedName;
    }

    /**
     * Set the mapped name.
     * @param mappedName the given mapped name.
     */
    public void setMappedName(final String mappedName) {
        this.mappedName = mappedName;
    }

    /**
     * Gets the transaction-type.
     * @return the transaction-type
     */
    public String getTransactionType() {
        return transactionType;
    }

    /**
     * Set the transaction-type.
     * @param transactionType transaction-type.
     */
    public void setTransactionType(final String transactionType) {
        this.transactionType = transactionType;
    }
    
    /**
     * @return list of timers
     */
    public List<ITimer> getTimers() {
        return timers;
    }
    
    /**
     * Adds a new timer.
     * @param timer the new timer
     */
    public void addTimer(final ITimer timer) {
        this.timers.add(timer);
    }

    /**
     * @return the timeout method
     */
    public IMethodDD getTimeoutMethod() {
        return timeoutMethod;
    }

    /**
     * Set the timeout method.
     * @param timeoutMethod the given timeout.
     */
    public void setTimeoutMethod(IMethodDD timeoutMethod) {
        this.timeoutMethod = timeoutMethod;
    }
    
    
}
