/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.xml.struct;

import java.util.concurrent.TimeUnit;

import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IAccessTimeout;

/**
 * AccessTimeout parsed in XML
 * @author Florent Benoit
 */
public class AccessTimeout implements IAccessTimeout {

    /**
     *
     */
    private static final long serialVersionUID = -6491563195797338739L;

    /**
     * value.
     */
    private long timeout;

    /**
     * TimeUnit.
     */
    private TimeUnit timeUnit;

    /**
     * Constructor.
     */
    public AccessTimeout() {
        // default type
        this.timeUnit = TimeUnit.MILLISECONDS;
    }

    /**
     * @return value (value to be used).
     */
    @Override
    public long getTimeout() {
        return timeout;
    }

    /**
     * Sets the value.
     * @param value the given value.
     */
    public void setTimeout(final long timeout) {
        this.timeout = timeout;
    }

    /**
     * @return the unit type.
     */
    @Override
    public TimeUnit getUnit() {
        return timeUnit;
    }

    /**
     * Sets the unit type.
     * @param timeUnit value to set.
     */
    public void setUnit(final TimeUnit timeUnit) {
        this.timeUnit = timeUnit;
    }

    /**
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));

        // name
        sb.append("[timeout=");
        sb.append(timeout);

        // type
        sb.append(", unit=");
        sb.append(timeUnit);

        sb.append("]");
        return sb.toString();
    }

}