/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.xml.struct;

import org.ow2.util.ee.metadata.common.api.xml.struct.IMethodDD;
import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IAccessTimeout;
import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IConcurrentMethod;
import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.ILockType;

/**
 * Defines a concurrent method.
 * @author Florent Benoit
 */
public class ConcurrentMethod implements IConcurrentMethod {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = 1052367118609706597L;

    /**
     * Method on which we're applying concurrent method.
     */
    private IMethodDD methodDD;
    
    /**
     * Lock type to use.
     */
    private ILockType lockType;
    
    /**
     * Access Timeout.
     */
    private IAccessTimeout accessTimeout;
    
    /**
     * @return business method for which the concurrency applies. 
     */
    public IMethodDD getMethod() {
        return methodDD;
    }
    
    /**
     * @return concurrency locking type.
     */
    public ILockType getLockType() {
        return lockType;
    }
  
    /**
     * @return access timeout for this concurrent method.
     */
    public IAccessTimeout getAccessTimeout() {
        return accessTimeout;
    }

    /**
     * Sets the method.
     * @param methodDD the given method
     */
    public void setMethod(IMethodDD methodDD) {
        this.methodDD = methodDD;
    }

    /**
     * Sets the lockType.
     * @param lockType the given lock type
     */
    public void setLockType(ILockType lockType) {
        this.lockType = lockType;
    }
    
    /**
     * Sets the access timeout.
     * @param accessTimeout the given access timeout
     */
    public void setAccessTimeout(IAccessTimeout accessTimeout) {
        this.accessTimeout = accessTimeout;
    }
    
    
}
