/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.xml.struct;

import java.util.LinkedList;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.struct.ITransactionAttributeType;
import org.ow2.util.ee.metadata.common.api.xml.struct.IMethodDD;
import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IContainerTransaction;

/**
 * Defines a contrainer transaction used within an assembly descriptor.
 * @author Florent BENOIT
 */
public class ContainerTransaction implements IContainerTransaction {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = -7325215406090066426L;

    /**
     * List of method on which apply this container transaction block.
     */
    private List<IMethodDD> methods = null;

    /**
     * Transaction Attribute set by this container transaction.
     */
    private ITransactionAttributeType txAttribute = null;


    /**
     * Defines a new Container transaction object.
     */
    public ContainerTransaction() {
        this.methods = new LinkedList<IMethodDD>();
    }

    /**
     * Add a new Method.
     * @param method the given method.
     */
    @Override
    public void addMethod(final IMethodDD method) {
        this.methods.add(method);
    }

    /**
     * @return list of methods.
     */
    @Override
    public List<IMethodDD> getMethods() {
        return this.methods;
    }

    /**
     * Sets the transaction attribute for this block.
     * @param txAttribute the given transaction attribute
     */
    @Override
    public void setTransactionAttribute(final ITransactionAttributeType txAttribute) {
        this.txAttribute = txAttribute;
    }

    /**
     * Gets the transaction attribute for this block.
     * @return the transaction attribute
     */
    @Override
    public ITransactionAttributeType getTransactionAttribute() {
        return this.txAttribute;
    }

    /**
     * @return string representation of this module.
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder(ContainerTransaction.class.getSimpleName());
        sb.append("[");
        for (IMethodDD method : methods) {
            sb.append(method);
        }
        sb.append(", txAttribute=");
        sb.append(txAttribute);
        sb.append("]");
        return sb.toString();
    }

}
