/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.xml.struct;

import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IAssemblyDescriptor;
import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IEJB3;
import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IEnterpriseBeans;
import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IInterceptors;

/**
 * This class represents an EJB-Jar deployment descriptor.
 * @author Florent Benoit
 */
public class EJB3 implements IEJB3 {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = 3046313759582470535L;

    /**
     * Enterprise-beans element.
     */
    private IEnterpriseBeans enterpriseBeans = null;

    /**
     * interceptors element.
     */
    private IInterceptors interceptors = null;

    /**
     * assembly-descriptor element.
     */
    private IAssemblyDescriptor assemblyDescriptor = null;

    /**
     * metadataComplete.
     */
    private boolean metadataComplete;

    /**
     * Gets the enterprise-beans element.
     * @return the enterprise-beans
     */
    public IEnterpriseBeans getEnterpriseBeans() {
        return enterpriseBeans;
    }

    /**
     * Sets the enterprise-beans element.
     * @param enterpriseBeans the element to set.
     */
    public void setEnterpriseBeans(final IEnterpriseBeans enterpriseBeans) {
        this.enterpriseBeans = enterpriseBeans;
    }

    /**
     * Gets the interceptors element.
     * @return the interceptors
     */
    public IInterceptors getInterceptors() {
        return interceptors;
    }

    /**
     * Sets the interceptors element.
     * @param interceptors the element to set.
     */
    public void setInterceptors(final IInterceptors interceptors) {
        this.interceptors = interceptors;
    }

    /**
     * Gets the assembly-descriptor element.
     * @return the assembly-descriptor
     */
    public IAssemblyDescriptor getAssemblyDescriptor() {
        return assemblyDescriptor;
    }

    /**
     * Sets the assembly-descriptor element.
     * @param assemblyDescriptor the element to set.
     */
    public void setAssemblyDescriptor(final IAssemblyDescriptor assemblyDescriptor) {
        this.assemblyDescriptor = assemblyDescriptor;
    }

    /**
     * Set metadataComplete.
     * @param metadataComplete true if deployment descriptor contains all information
     */
    public void setMetadataComplete(final boolean metadataComplete) {
        this.metadataComplete = metadataComplete;
    }

    /**
     * Get metadataComplete.
     * @return true if deployment descriptor contains all information
     */
    public boolean isMetadataComplete() {
        return metadataComplete;
    }

}
