/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.xml.struct;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IEnterpriseBeans;
import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IMessageDriven;
import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.ISession;

/**
 * This class defines the implementation of the element enterprise-beans.
 * @author Florent Benoit
 */
public class EnterpriseBeans implements IEnterpriseBeans {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = 1612685980173953082L;

    /**
     * List of &lt;session&gt; elements.
     */
    private List<ISession> sessionList = null;

    /**
     * List of &lt;message-driven&gt; elements.
     */
    private List<IMessageDriven> messageDrivenList = null;

    /**
     * Constructor.
     */
    public EnterpriseBeans() {
        this.sessionList = new ArrayList<ISession>();
        this.messageDrivenList = new ArrayList<IMessageDriven>();
    }

    /**
     * Gets the list of &lt;session&gt; elements.
     * @return list of &lt;session&gt; elements.
     */
    public List<ISession> getSessionList() {
        return sessionList;
    }

    /**
     * Adds a new &lt;session&gt; element to enterprise beans.
     * @param session the &lt;session&gt; element
     */
    public void addSession(final ISession session) {
        sessionList.add(session);
    }

    /**
     * Gets the list of &lt;message-driven&gt; elements.
     * @return list of &lt;message-driven&gt; elements.
     */
    public List<IMessageDriven> getMessageDrivenList() {
        return messageDrivenList;
    }

    /**
     * Adds a new &lt;message-driven&gt; element to enterprise beans.
     * @param messageDriven the &lt;message-driven&gt; element
     */
    public void addMessageDriven(final IMessageDriven messageDriven) {
        messageDrivenList.add(messageDriven);
    }

}
