/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.xml.struct;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IInterceptor;
import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IInterceptors;


/**
 * This class defines the implementation of the element interceptors.
 * @author Florent Benoit
 */
public class Interceptors implements IInterceptors {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = -2356057010509614266L;

    /**
     * List of &lt;interceptor&gt; elements.
     */
    private List<IInterceptor> interceptorList = null;

    /**
     * Constructor.
     */
    public Interceptors() {
        interceptorList = new ArrayList<IInterceptor>();
    }

    /**
     * Gets the list of &lt;interceptor&gt; elements.
     * @return list of &lt;interceptor&gt; elements.
     */
    public List<IInterceptor> getInterceptorList() {
        return interceptorList;
    }

    /**
     * Adds a new &lt;interceptor&gt; element to assembly descriptor.
     * @param interceptor the &lt;interceptor&gt; element
     */
    public void addInterceptor(final IInterceptor interceptor) {
        interceptorList.add(interceptor);
    }

}
