/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.xml.struct;

import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IMessageDestination;

/**
 * Defines a message destination object used within an assembly descriptor.
 * @author Florent BENOIT
 */
public class MessageDestination implements IMessageDestination {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = -5480995989512024015L;

    /**
     * Name of the message-destination.
     */
    private String name = null;

    /**
     * JNDI name of the message-destination.
     */
    private String mappedName = null;


    /**
     * @return the name of the message-destination.
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the name of the message destination.
     * @param messageDestinationName the name of the message destination.
     */
    public void setName(final String messageDestinationName) {
        this.name = messageDestinationName;
    }

    /**
     * @return the JNDI name of the message-destination.
     */
    public String getMappedName() {
        return mappedName;
    }

    /**
     * Sets the JNDI name of the message destination.
     * @param mappedName the JNDI name of the message destination.
     */
    public void setMappedName(final String mappedName) {
        this.mappedName = mappedName;
    }
}
