/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.xml.struct;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.xml.struct.IActivationConfig;
import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IMessageDriven;


/**
 * Defines a representation for &lt;message-driven&gt; element.
 * @author Florent Benoit
 */
public class MessageDriven extends AbsBean implements IMessageDriven {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = -2461372094570670079L;

    /**
     * The messaging-type element specifies the message listener interface of
     * the message-driven bean.
     */
    private String messagingType = null;

    /**
     * The message destination type.
     */
    private String messageDestinationType = null;

    /**
     * The message destination link.
     */
    private String messageDestinationLink = null;

    /**
     * List of activation-config properties.
     */
    private List<IActivationConfig> activationConfigList = null;

    /**
     * Constructor.
     */
    public MessageDriven() {
        super();
        this.activationConfigList = new ArrayList<IActivationConfig>();
    }

    /**
     * Set the messaging-type.
     * @param messagingType the message listener interface of the message-driven
     *        bean.
     */
    public void setMessagingType(final String messagingType) {
        this.messagingType = messagingType;
    }

    /**
     * Gets the messaging-type.
     * @return the messaging-type
     */
    public String getMessagingType() {
        return messagingType;
    }

   /**
     * Set the message destination type.
     * @param messageDestinationType message destination type.
     */
    public void setMessageDestinationType(final String messageDestinationType) {
        this.messageDestinationType = messageDestinationType;
    }

    /**
     * Gets the message destination type.
     * @return the message destination type
     */
    public String getMessageDestinationType() {
        return messageDestinationType;
    }

    /**
     * Set the message destination link.
     * @param messageDestinationLink message destination link.
     */
    public void setMessageDestinationLink(final String messageDestinationLink) {
        this.messageDestinationLink = messageDestinationLink;
    }

    /**
     * Gets the message destination link.
     * @return the message destination link
     */
    public String getMessageDestinationLink() {
        return messageDestinationLink;
    }

    /**
     * Gets the activation-config list.
     * @return activation-config list
     */
    public List<IActivationConfig> getActivationConfigList() {
        return activationConfigList;
    }

    /**
     * Add the activation-config property.
     * @param activationConfig activation-config property
     */
    public void addActivationConfig(final IActivationConfig activationConfig) {
        activationConfigList.add(activationConfig);
    }
}
