/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.xml.struct;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.xml.struct.IMethodDD;
import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IMethodPermission;

/**
 * Defines a method permission used within an assembly descriptor.
 * @author Florent BENOIT
 */
public class MethodPermission implements IMethodPermission {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = -5555400138755503507L;

    /**
     * List of methods on which apply this method permission block.
     */
    private List<IMethodDD> methods = null;

    /**
     * Unchecked method block ?
     */
    private boolean unchecked = false;

    /**
     * Name of the roles.
     */
    private List<String> roleNameList = null;

    /**
     * Default constructor.
     */
    public MethodPermission() {
        this.roleNameList = new ArrayList<String>();
        this.methods = new ArrayList<IMethodDD>();
    }


    /**
     * Sets the unchecked flag.
     * @param unchecked the given boolean value.
     */
    public void setUnchecked(final boolean unchecked) {
        this.unchecked = unchecked;
    }

    /**
     * Is it unchecked ?.
     * @return true if it is unchecked, else false.
     */
    public boolean isUnchecked() {
        return this.unchecked;
    }

    /**
     * Add a new Method.
     * @param method the given method.
     */
    public void addMethod(final IMethodDD method) {
        this.methods.add(method);
    }

    /**
     * @return list of methods.
     */
    public List<IMethodDD> getMethods() {
        return this.methods;
    }

    /**
     * Gets the name of the role.
     * @return the role's name.
     */
    public List<String> getRoleNameList() {
        return this.roleNameList;
    }

    /**
     * Add the given role.
     * @param roleName the name of the role.
     */
    public void addRoleName(final String roleName) {
        this.roleNameList.add(roleName);
    }
}
