/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.xml.struct;

import org.ow2.util.ee.metadata.common.api.xml.struct.IMethodDD;
import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IRemoveMethod;

/**
 * This class manages the &lt;remove-method&gt; element of the xml DD.
 * @author Florent Benoit
 */
public class RemoveMethod implements IRemoveMethod {

    /**
     * Serial Version UID.
     */
    private static final long serialVersionUID = 2987877258694863129L;

    /**
     * This remove method is linked to a Method of the Bean (with params).
     */
    private IMethodDD method = null;

    /**
     * boolean used to know if when there is an exception, the bean should be kept or not.
     * It uses a boolean object to know if the element has been set or not
     */
    private Boolean retainIfException = null;


    /**
     * Sets the method of the bean which needs to be marked.
     * @param method the method to use
     */
    public void setMethod(final IMethodDD method) {
        this.method = method;
    }

    /**
     * @return the method that will be used as a remove method
     */
    public IMethodDD getMethod() {
        return method;
    }

    /**
     * If there is an exception, the bean should be kept or not.
     * @param retainIfException true to keep, or false to remove
     */
    public void setRetainIfException(final boolean retainIfException) {
        this.retainIfException = Boolean.valueOf(retainIfException);
    }

    /**
     * @return the flag to know if when there is an exception, the bean should be kept or not.
     * It returns null if it was not set.
     */
    public Boolean getRetainIfException() {
        return retainIfException;
    }

}
