/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.test;

import javax.ejb.Schedule;
import javax.ejb.Schedules;
import javax.ejb.Stateless;
import javax.interceptor.Interceptors;
import javax.jws.WebMethod;

/**
 * EJB3 Stateless sample.
 * @author Gael Lalire
 */
@Stateless
@Interceptors(MyInterceptor.class)
public class MyEJB3Stateless implements MyInterface {

    /**
     * Dummy method.
     * @param a dummy int
     * @param b dummy long
     * @param c dummy Integer
     */
    @Interceptors(MyInterceptor.class)
    public void dummy(final int a, final long b, final Integer c) {

    }

    /**
     * Method exposed as a webservice.
     */
    @WebMethod(exclude=false, action="actionNameFlorent", operationName="opName2")
    public void webserviceMethod() {

    }
    
    
    @Schedule(second="1", minute="2", hour="3", dayOfMonth="4", month="5", dayOfWeek="6", year="2012", info="infoTimer", persistent=false, timezone="CEST")
    public void dummyTimerMethod1() {
        
    }

    @Schedule(second="50", persistent=true)
    public void dummyTimerMethod2() {
        
    }

    @Schedules({
        @Schedule(second="10", minute="15", hour="25"),    
        @Schedule(second="20", minute="25", hour="35"),    
        @Schedule(second="30", minute="35", hour="45")    
    })
    public void dummyTimerMethod3() {
        
    }

    @Schedules({
        @Schedule(second="10"),    
        @Schedule(second="20"),    
        @Schedule(second="30")    
    })
    @Schedule(second="40")
    public void dummyTimerMethod4() {
        
    }
    
}
