/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.war.impl;

import java.lang.annotation.ElementType;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import org.ow2.util.archive.api.IArchive;
import org.ow2.util.ee.metadata.war.api.IWarMetadata;
import org.ow2.util.scan.api.metadata.CommonMetadata;
import org.ow2.util.scan.api.metadata.IClassMetadata;
import org.ow2.util.scan.api.metadata.structures.IMember;

/**
 * This class represents the annotation metadata of all classes of a War
 * file. From this class, we can get metadata of all classes.
 * @author Florent Benoit
 */
public class WarMetadata extends CommonMetadata implements IWarMetadata {

    /**
     * List of class annotations metadata.
     */
    private Map<String, IClassMetadata> warClassMetadataMap = null;

    /**
     * The war archive.
     */
    private final IArchive archive;

    /**
     * Constructor.
     * @param warDeployable the war deployable
     */
    public WarMetadata(final IArchive archive) {
        this.archive = archive;
        warClassMetadataMap = new HashMap<String, IClassMetadata>();
    }

    /**
     * Add annotation metadata for a given class.
     * @param warClassMetadata metadata of a class.
     */
    public void addClassMetadata(final IClassMetadata warClassMetadata) {
        String key = warClassMetadata.getJClass().getName();
        // already exists ?
        if (warClassMetadataMap.containsKey(key)) {
            throw new IllegalStateException("addWarClassMetadata : key already exists");
        }
        warClassMetadataMap.put(key, warClassMetadata);
    }


    /**
     * Get class annotation metadata.
     * @param className key of the map of annotations bean.
     * @return Bean annotation metadata of a given name.
     */
    public IClassMetadata getClassMetadata(final String className) {
        return warClassMetadataMap.get(className);
    }

    /**
     * Get collections of bean annotation metadata.
     * @return collections of bean annotation metadata.
     */
    public Collection<IClassMetadata> getClassMetadataCollection() {
        return warClassMetadataMap.values();
    }

    /**
     * @return the web archive
     */
    public IArchive getArchive() {
        return archive;
    }

    public IMember getMember() {
        return null;
    }

    @Override
    public ElementType getElementType() {
        return ElementType.PACKAGE;
    }

}
