/**
 * Copyright 2013 Peergreen S.A.S.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ow2.util.ee.metadata.war.impl.configurator;

import org.ow2.util.archive.api.IArchive;
import org.ow2.util.ee.metadata.common.api.view.IJavaxPersistenceView;
import org.ow2.util.ee.metadata.common.impl.configurator.CommonAnnotationConfigurator;
import org.ow2.util.ee.metadata.common.impl.view.CommonMetadataViewFactory;
import org.ow2.util.ee.metadata.common.impl.view.CommonView;
import org.ow2.util.ee.metadata.common.impl.view.JavaxPersistenceViewFactory;
import org.ow2.util.ee.metadata.war.api.IWarMetadata;
import org.ow2.util.ee.metadata.war.impl.WarMetadata;
import org.ow2.util.ee.metadata.ws.api.view.IWebservicesView;
import org.ow2.util.ee.metadata.ws.impl.configurator.WebservicesAnnotationConfigurator;
import org.ow2.util.ee.metadata.ws.impl.view.WebServicesViewFactory;
import org.ow2.util.scan.api.configurator.IAnnotationConfigurator;
import org.ow2.util.scan.api.configurator.IClassConfigurator;
import org.ow2.util.scan.api.configurator.IViewConfigurator;
import org.ow2.util.scan.api.configurator.basic.SessionConfigurator;
import org.ow2.util.scan.api.configurator.basic.ViewConfigurator;
import org.ow2.util.scan.api.metadata.IClassMetadata;

/**
 * WarSessionConfigurator.
 * @author Florent Benoit
 */
public class WarSessionConfigurator extends SessionConfigurator {

    /**
     * archive metadata.
     */
    private final IWarMetadata warMetadata;

    /**
     * annotationParsingDesactived.
     */
    private boolean annotationParsingDesactived;

    /**
     * Constructor.
     * @param warDeployable the web archive
     */
    public WarSessionConfigurator(final IArchive archive) {
        super();
        this.warMetadata = new WarMetadata(archive);

        // add a new view
        IViewConfigurator viewConfigurator =  new ViewConfigurator();
        viewConfigurator.registerView(CommonView.class, new CommonMetadataViewFactory());
        viewConfigurator.registerView(IJavaxPersistenceView.class, new JavaxPersistenceViewFactory());


        viewConfigurator.registerView(IWebservicesView.class, new WebServicesViewFactory());
        warMetadata.addViewConfigurator(viewConfigurator);
        getViewConfigurators().add(viewConfigurator);

        IAnnotationConfigurator commonAnnotationConfigurator = new CommonAnnotationConfigurator();
        getAnnotationConfigurators().add(commonAnnotationConfigurator);

        IAnnotationConfigurator wsAnnotationConfigurator = new WebservicesAnnotationConfigurator();
        getAnnotationConfigurators().add(wsAnnotationConfigurator);


        annotationParsingDesactived = false;
    }

    /**
     * @return the archive metadata
     */
    public IWarMetadata getWarMetadata() {
        return this.warMetadata;
    }

    /**
     * @return true if annotation parsing is desactived
     */
    public boolean isAnnotationParsingDesactived() {
        return this.annotationParsingDesactived;
    }

    /**
     * Set annotationParsingDesactived.
     * @param annotationParsingDesactived true if you want to desactive
     *        annotation parsing
     */
    public void setAnnotationParsingDesactived(final boolean annotationParsingDesactived) {
        this.annotationParsingDesactived = annotationParsingDesactived;
    }

    @Override
    public IClassConfigurator createClassConfigurator(IClassMetadata classMetadata) {
        return new WarClassMetadataConfigurator(classMetadata, this.warMetadata);
    }


}
