/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.war.impl.xml.parsing;


import org.ow2.util.ee.metadata.common.impl.xml.parsing.IEntityResolver;
import org.ow2.util.xml.SchemaEntityResolver;


/**
 * Entity resolver allowing to find schema within the classloader.
 *
 * @author Florent Benoit
 */
public class WAREntityResolver extends SchemaEntityResolver implements IEntityResolver {

    /**
     * All schemas used by WARs.
     */
    private static final String[] WAR_SCHEMAS = new String[]{
            PREFIX + JSP20_SCHEMA,
            PREFIX + JSP21_SCHEMA,
            PREFIX + JSP22_SCHEMA,
            PREFIX + WEBAPP24_SCHEMA,
            PREFIX + WEBAPP25_SCHEMA,
            PREFIX + WEBAPP30_SCHEMA,
            PREFIX + WEBAPPCOMMON30_SCHEMA,
            PREFIX + CLIENT50_SCHEMA,
            PREFIX + CLIENT60_SCHEMA,
            PREFIX + JAVAEE5_SCHEMA,
            PREFIX + JAVAEE6_SCHEMA,
            PREFIX + J2EE14_SCHEMA,
            PREFIX + JAVAEE_WEBSERVICES12_CLIENT_SCHEMA,
            PREFIX + JAVAEE_WEBSERVICES13_CLIENT_SCHEMA,
            PREFIX + J2EE_WEBSERVICES_CLIENT_SCHEMA,
            PREFIX + XML_SCHEMA};

    /**
     * All Public ID used by Clients.
     */
    private static final String[] WAR_PUBLIC_IDS = new String[] {
            XMLSCHEMA_PUBLIC_ID,
            DATATYPES_PUBLIC_ID,
            WEBAPP22_PUBLIC_ID,
            WEBAPP23_PUBLIC_ID
    };

    /**
     * All DTDs filename used by Clients.
     */
    private static final String[] WAR_DTDS = new String[] {
            PREFIX + XMLSCHEMA_DTD,
            PREFIX + DATATYPES_DTD,
            PREFIX + WEBAPP22_DTD,
            PREFIX + WEBAPP23_DTD
    };


    /**
     * Constructor. Finds the XSD with classloader.
     */
    public WAREntityResolver() {
        super(WAR_SCHEMAS, WAR_PUBLIC_IDS, WAR_DTDS);
    }

}
