/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.war.impl.xml.struct;

import java.util.LinkedList;
import java.util.List;

import org.ow2.util.ee.metadata.common.impl.xml.struct.AbsEnvironment;

/**
 * This class represents a WEB deployment descriptor.
 * @author Florent Benoit
 */
public class WAR extends AbsEnvironment {

    /**
     * True if metadata is complete.
     */
    private boolean metadataComplete;

    /**
     * List of servlet objects.
     */
    private List<Servlet> servlets = null;

    /**
     * List of listener objects.
     */
    private List<Listener> listeners = null;

    /**
     * List of filter objects.
     */
    private List<Filter> filters = null;

    /**
     * List of tag objects.
     */
    private List<Tag> tags = null;

    /**
     * Default constructor.
     */
    public WAR() {
        metadataComplete = false;
        this.filters = new LinkedList<Filter>();
        this.listeners = new LinkedList<Listener>();
        this.servlets = new LinkedList<Servlet>();
        this.tags = new LinkedList<Tag>();
    }

    /**
     * @param metadataComplete true if metadata is complete
     */
    public void setMetadataComplete(final boolean metadataComplete) {
        this.metadataComplete = metadataComplete;
    }

    /**
     * @return true if metadata is complete
     */
    public boolean isMetadataComplete() {
        return metadataComplete;
    }

    /**
     * Add a given servlet.
     * @param servlet the given servlet object.
     */
    public void addServlet(final Servlet servlet) {
        this.servlets.add(servlet);
    }

    /**
     * @return list of servlets.
     */
    public List<Servlet> getServlets() {
        return this.servlets;
    }

    /**
     * Add a given listener.
     * @param listener the given listener object.
     */
    public void addListener(final Listener listener) {
        this.listeners.add(listener);
    }

    /**
     * @return list of listeners.
     */
    public List<Listener> getListeners() {
        return this.listeners;
    }

    /**
     * Add a given tag.
     * @param tag the given tag object.
     */
    public void addTag(final Tag tag) {
        this.tags.add(tag);
    }

    /**
     * @return list of tags.
     */
    public List<Tag> getTags() {
        return this.tags;
    }

    /**
     * Add a given listener.
     * @param filter the given filter object.
     */
    public void addFilter(final Filter filter) {
        this.filters.add(filter);
    }

    /**
     * @return list of filters.
     */
    public List<Filter> getFilters() {
        return this.filters;
    }
}
