/**
 * OW2 Utilities
 * Copyright (C) 2009-2012 Bull S.A.S.
 * Contact: utilities@ow2.org
 *
 * Licensed  under the  Apache License,  Version 2.0  (the "License");
 * you may not use  this file  except in  compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed  under the  License is distributed on an "AS IS" BASIS,
 * WITHOUT  WARRANTIES OR CONDITIONS  OF ANY KIND, either  express  or
 * implied.
 *
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.war.test;

import static org.testng.Assert.assertNotNull;

import java.io.IOException;
import java.util.Arrays;
import java.util.List;

import org.ow2.util.archive.impl.MemoryArchive;
import org.ow2.util.ee.metadata.common.api.enc.IENCBinding;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationSqlDataSourceDefinition;
import org.ow2.util.ee.metadata.common.impl.enc.ENCBindingException;
import org.ow2.util.ee.metadata.common.impl.enc.ENCBindingHolder;
import org.ow2.util.ee.metadata.war.api.IWarMetadata;
import org.ow2.util.ee.metadata.war.api.exceptions.WARMetadataException;
import org.ow2.util.ee.metadata.war.impl.WarMetadataFactory;
import org.ow2.util.ee.metadata.war.impl.enc.ENCBindingBuilder;
import org.ow2.util.scan.impl.ASMScannerImpl;
import org.testng.Assert;
import org.testng.annotations.AfterClass;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.Test;

/**
 * @author Gael Lalire
 */
public class TestWarDataSourceDefinitionENCBindings {

    /**
     * archive.
     */
    private MemoryArchive archive = null;

    /**
     * Create directories for the test.
     *
     * @throws java.io.IOException if directories are not created
     * @throws org.ow2.util.ee.deploy.api.helper.DeployableHelperException
     *                             if deployables are not created
     */
    @BeforeClass
    public void init() throws IOException {
        archive = new WarMemoryArchive();
        archive.addClassResource(MyServlet.class.getClassLoader(), Arrays.asList(MyServlet.class.getName()));
        archive.addResource("WEB-INF/web.xml", TestWarDataSourceDefinitionENCBindings.class.getResource("web.xml"));
    }

    /**
     * Remote the temp folder created at the end of the test.
     */
    @AfterClass
    public void remove() {
    }

    /**
     * The metadata of memory archive.
     */
    private IWarMetadata warMetadata;

    /**
     * Add ejb-jar v3 metadata factory.
     */
    @Test
    public void testMetadataFactory() throws WARMetadataException  {
        WarMetadataFactory metadataFactory = new WarMetadataFactory(new ASMScannerImpl(), null);
        warMetadata = metadataFactory.createArchiveMetadata(archive);
        assertNotNull(warMetadata);
    }

    /**
     * Verify the validity of metadata archive.
     */
    @Test(dependsOnMethods = "testMetadataFactory")
    public void testENCBindings() throws ENCBindingException {
        final ENCBindingHolder encBindingHolder = ENCBindingBuilder.analyze(warMetadata);
        final List<IENCBinding<IJAnnotationSqlDataSourceDefinition>> bindings =
            encBindingHolder.getDataSourceBindings();
        Assert.assertNotNull(bindings);
        Assert.assertEquals(bindings.size(), 1);
        IJAnnotationSqlDataSourceDefinition dataSourceDefinition =
            bindings.get(0).getValue();
        Assert.assertEquals(dataSourceDefinition.getName(), "java:global/MyDataSource");
        Assert.assertEquals(dataSourceDefinition.getUrl(), "jdbc:postgres://user:pass@remote:3307/testdb");
        Assert.assertFalse(dataSourceDefinition.isTransactional(),
            "@DataSourceDefinition annotation not parsed.");
    }

}
