/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.war.test;

import static org.testng.Assert.assertNotNull;

import java.io.IOException;
import java.util.Arrays;

import org.ow2.util.archive.impl.MemoryArchive;
import org.ow2.util.ee.metadata.common.api.interfaces.ISharedMetadataView;
import org.ow2.util.ee.metadata.common.impl.view.CommonView;
import org.ow2.util.ee.metadata.war.api.IWarMetadata;
import org.ow2.util.ee.metadata.war.api.exceptions.WARMetadataException;
import org.ow2.util.ee.metadata.war.impl.WarMetadataFactory;
import org.ow2.util.scan.api.metadata.IClassMetadata;
import org.ow2.util.scan.api.metadata.IFieldMetadata;
import org.ow2.util.scan.impl.ASMScannerImpl;
import org.testng.Assert;
import org.testng.annotations.AfterClass;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.Test;

/**
 * @author Gael Lalire
 */
public class TestWarMetadata {

    /**
     * archive.
     */
    private MemoryArchive archive = null;

    /**
     * Create directories for the test.
     * @throws IOException if directories are not created
     * @throws DeployableHelperException if deployables are not created
     */
    @BeforeClass
    public void init() throws IOException {
        archive = new WarMemoryArchive();
        archive.addClassResource(MyServlet.class.getClassLoader(), Arrays.asList(MyServlet.class.getName()));
        archive.addResource("WEB-INF/web.xml", TestWarMetadata.class.getResource("web.xml"));
    }

    /**
     * Remote the temp folder created at the end of the test.
     */
    @AfterClass
    public void remove() {
    }

    /**
     * The metadata of memory archive.
     */
    private IWarMetadata warMetadata;

    /**
     * Add metadata factory.
     * @throws WARMetadataException
     */
    @Test
    public void testMetadataFactory() throws WARMetadataException {
        WarMetadataFactory metadataFactory = new WarMetadataFactory(new ASMScannerImpl(), null);
        warMetadata = metadataFactory.createArchiveMetadata(archive);
        assertNotNull(warMetadata);
    }

    /**
     * Verify the validity of metadata archive.
     */
    @Test(dependsOnMethods = "testMetadataFactory")
    public void testMetadataValidity()  {
        IClassMetadata warClassMetadata = warMetadata.getClassMetadata(MyServlet.class.getName().replace('.', '/'));
        Assert.assertNotNull(warClassMetadata);
        for (IFieldMetadata warFieldMetadata : warClassMetadata.getFieldMetadataCollection()) {

            ISharedMetadataView view = warFieldMetadata.as(CommonView.class);

            String fieldName = warFieldMetadata.getJField().getName();
            if (fieldName.equals("topicConnectionFactory")) {
                Assert.assertEquals(view.getJAnnotationResource().getMappedName(), "TCF");
            } else if (fieldName.equals("queueConnectionFactory")) {
                Assert.assertEquals(view.getJAnnotationResource().getMappedName(), "QCF");
            } else if (fieldName.equals("connectionFactory")) {
                Assert.assertEquals(view.getJAnnotationResource().getMappedName(), "CF");
            }
        }
    }

}
