/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.war.test;

import java.net.URL;
import java.util.List;

import org.ow2.util.archive.impl.MemoryArchive;

/**
 * WarMemoryArchive.
 * @author Gael Lalire
 */
public class WarMemoryArchive extends MemoryArchive {

    /**
     * Root url of archive.
     */
    private URL rootURL;

    /**
     * Constructor.
     */
    public WarMemoryArchive() {
        super();
        rootURL = getClass().getResource("/");
        addResource("WEB-INF/classes", rootURL);
    }

    /**
     * Place resources in WEB-INF/classes.
     * @param classLoader classLoader
     * @param classNames classNames
     */
    @Override
    public void addClassResource(final ClassLoader classLoader, final List<String> classNames) {
        for (String className : classNames) {
            String classLocation = className.replace('.', '/').concat(".class");
            addResource("WEB-INF/classes/" + classLocation, classLoader.getResource(classLocation));
        }
    }

    /**
     * @return the root url of archive
     */
    @Override
    public URL getURL() {
        return rootURL;
    }

}
