/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ws.api.struct;

import javax.xml.namespace.QName;
import java.io.Serializable;

import org.ow2.util.ee.metadata.common.api.xml.struct.IHandlerChains;

/**
 * Manage WebService metadata.
 * @author Guillaume Sauthier
 */
public interface IWebServiceMarker extends Serializable {

    /**
     * @return true if this marker denotes a class annotated with @WebServiceProvider
     * instead of @WebService.
     */
    boolean isWebServiceProvider();

    /**
     * Set if this class is annotated with @WebService or @WebServiceprovider
     * @param wsProvider
     */
    void setWebServiceProvider(boolean wsProvider);

    /**
     * @return the WSDL location (may be null).
     */
    String getWsdlLocation();

    /**
     * @param wsdlLocation the overrided WSDL location.
     */
    void setWsdlLocation(String wsdlLocation);

    /**
     * @return the overrided wsdl:service name (may be null)
     */
    QName getServiceName();

    /**
     * @param serviceName overriding value for wsdl:service name.
     */
    void setServiceName(QName serviceName);

    /**
     * @return the overrided wsdl:port name (may be null)
     */
    QName getPortName();

    /**
     * @param portName overriding value for wsdl:port name.
     */
    void setPortName(QName portName);

    /**
     * @return the overriding value for the protocol binding URI (may be null)
     */
    String getProtocolBinding();

    /**
     * @param protocolBinding new URI specifying the overriding value for binding URI.
     */
    void setProtocolBinding(String protocolBinding);

    /**
     * @return true if MTOM is enabled (false by default)
     */
    boolean isEnableMtom();

    /**
     * @param enableMtom should MTOM be enabled on this port ?
     */
    void setEnableMtom(boolean enableMtom);

    /**
     * @return the overrided value for Service Endpoint Interface (may be null).
     */
    String getEndpointInterface();

    /**
     * @param serviceEndpointInterface the overriding value for SEI.
     */
    void setEndpointInterface(String serviceEndpointInterface);

    /**
     * @return the name of this web service (only applicable when using @WebService)
     */
    String getName();

    /**
     * Set the name of this serviceweb.
     * @param name name of this webservice.
     */
    void setName(String name);

    /**
     * Set the HandlerChains resolved from deployment descriptor.
     * @param handlerChains HandlerChains resolved from deployment descriptor.
     */
    void setHandlerChains(IHandlerChains handlerChains);

    /**
     * @return the HandlerChains elements resolved from deployment descriptor.
     */
    IHandlerChains getHandlerChains();
}