/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ws.api.xml.struct;

import javax.xml.namespace.QName;

import org.ow2.util.ee.metadata.common.api.xml.struct.IHandlerChains;

/**
 * The IPortComponent is the view of the <port-component> element in the webservices.xml.
 *
 * @author Guillaume Sauthier
 */
public interface IPortComponent {

    /**
     * @return the <code>port-component-name</code> value
     */
    String getName();

    /**
     * @return the <code>wsdl-service</code> value (as a QName)
     */
    QName getWsdlService();

    /**
     * @return the <code>wsdl-port</code> value (as a QName)
     */
    QName getWsdlPort();

    /**
     * @return the <code>enable-mtom</code> value.
     */
    boolean isMTOMEnabled();

    /**
     * @return the <code>protocol-binding</code> value.
     */
    String getProtocolBinding();

    /**
     * @return the <code>service-endpoint-interface</code> value.
     */
    String getServiceEndpointInterface();

    /**
     * @return the <code>service-impl-bean</code> content.
     */
    IServiceImplBean getServiceImplBean();

    /**
     * @return the <code>webservice-description</code> element,
     * parent of the port-component
     */
    IWebserviceDescription getParent();

    /**
     * @return the <code>handler-chains</code> element.
     */
    IHandlerChains getHandlerChains();
}
