/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ws.impl.configurator.visitor.clazz;

import static java.lang.annotation.ElementType.TYPE;

import org.ow2.util.ee.metadata.ws.api.struct.IWebServiceMarker;
import org.ow2.util.ee.metadata.ws.impl.struct.WebServiceMarker;
import org.ow2.util.scan.api.IAnnotationVisitorContext;
import org.ow2.util.scan.api.annotation.VisitorTarget;
import org.ow2.util.scan.api.annotation.VisitorType;
import org.ow2.util.scan.api.visitor.DefaultAnnotationVisitor;

/**
 * This class manages the handling of &#64;{@link javax.xml.ws.WebServiceProvider} annotation.
 * @author Guillaume Sauthier
 */
@VisitorTarget({TYPE})
@VisitorType("javax.xml.ws.WebServiceProvider")
public class JavaxXmlWsWebServiceProviderVisitor extends DefaultAnnotationVisitor<IWebServiceMarker> {

    /**
     * Visits the end of the annotation.
     */
    @Override
    public void visitEnd(IAnnotationVisitorContext<IWebServiceMarker> annotationVisitorContext) {
        IWebServiceMarker webServiceMarker = annotationVisitorContext.getLocal();
        webServiceMarker.setWebServiceProvider(true);

        // Compute default port component name (FQN of the class)
        String name = annotationVisitorContext.getVisitedMember().getName().replace('/', '.');
        webServiceMarker.setName(name);
        annotationVisitorContext.set(webServiceMarker);
    }

    @Override
    public IWebServiceMarker buildInstance() {
        return new WebServiceMarker();
    }

}