/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ws.impl.xml.parsing;

import org.ow2.util.archive.api.ArchiveException;
import org.ow2.util.archive.api.IArchive;
import org.ow2.util.ee.metadata.ws.api.xml.struct.IWebservices;
import org.ow2.util.ee.metadata.common.impl.xml.parsing.ParsingException;

import java.net.URL;

/**
 * The Webservices12DeploymentDesc is responsible to load the
 * webservices.xml (version 1.2/JAX-Ws only).
 *
 * @author Guillaume Sauthier
 */
public class Webservices12DeploymentDesc {

    /**
     * Defines where to look up the webservices.xml file.
     */
    public static enum Type {
        EJBJAR, WEBAPP
    }

    /**
     * Utility class, no public constructor.
     */
    private Webservices12DeploymentDesc() {

    }

    /**
     * Gets Webservices for a given archive.
     * @param archive file/directory.
     * @throws org.ow2.util.ee.metadata.common.impl.xml.parsing.ParsingException if no xml is present.
     * @return Webservices 1.2 instance or null.
     */
    public static IWebservices getWebservices12(final IArchive archive, Type type) throws ParsingException {

        // Get XML entry
        URL webservicesXmlURL = null;

        // Compute entry name
        String entryName = null;
        switch (type) {
            case EJBJAR:
                entryName = "META-INF/webservices.xml";
                break;
            case WEBAPP:
                entryName = "WEB-INF/webservices.xml";
                break;
        }

        try {
            webservicesXmlURL = archive.getResource(entryName);
        } catch (ArchiveException e) {
            throw new ParsingException("Cannot get resource '" + entryName + "' on the archive '"
                    + archive.getName() + "'.");
        }

        IWebservices webservices12 = null;
        // Get webservices object (if url valid)
        if (webservicesXmlURL != null) {
            webservices12 = WebservicesDeploymentDescLoader.loadDeploymentDescriptor(webservicesXmlURL);
        }

        // Only return something if this is a JAX-WS descriptor
        if ((webservices12 != null) && ("1.2".equals(webservices12.getVersion()))) {
            return webservices12;
        }

        return null;
    }

}
