/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ws.impl.xml.struct;

import org.ow2.util.ee.metadata.ws.api.xml.struct.IPortComponent;
import org.ow2.util.ee.metadata.ws.api.xml.struct.IServiceImplBean;
import org.ow2.util.ee.metadata.ws.api.xml.struct.IWebserviceDescription;
import org.ow2.util.ee.metadata.common.api.xml.struct.IHandlerChains;

import javax.xml.namespace.QName;

/**
 * The PortComponent is ...
 *
 * @author Guillaume Sauthier
 */
public class PortComponent implements IPortComponent {

    /**
     * XML element's name.
     */
    public static final String NAME = "port-component";

    /**
     * This port component's name.
     */
    private String name;

    /**
     * Name of the wsdl:service targeted by this port component (may be null)
     */
    private QName wsdlService;

    /**
     * Name of the wsdl:port targeted by this port component (may be null)
     */
    private QName wsdlPort;

    /**
     * Is MTOM enabled ?
     */
    private boolean mtomEnabled;

    /**
     * The overriding Binding URI (may be null).
     */
    private String protocolBinding;

    /**
     * The overriding SEI (only applicable is @WebService) (may be null).
     */
    private String serviceEndpointInterface;

    /**
     * The SIB.
     */
    private IServiceImplBean serviceImplBean;

    /**
     * The parent webservice-description.
     */
    private IWebserviceDescription parent;

    /**
     * Handler Chains element.
     */
    private IHandlerChains handlerChains;

    /**
     * Build a port component child of the given description element.
     * @param parent the description
     */
    public PortComponent(IWebserviceDescription parent) {
        this.parent = parent;
    }

    public void setName(String name) {
        this.name = name;
    }

    public void setWsdlService(QName wsdlService) {
        this.wsdlService = wsdlService;
    }

    public void setWsdlPort(QName wsdlPort) {
        this.wsdlPort = wsdlPort;
    }

    public void setMTOMEnabled(boolean mtomEnabled) {
        this.mtomEnabled = mtomEnabled;
    }

    public void setProtocolBinding(String protocolBinding) {
        this.protocolBinding = protocolBinding;
    }

    public void setServiceEndpointInterface(String serviceEndpointInterface) {
        this.serviceEndpointInterface = serviceEndpointInterface;
    }

    public void setServiceImplBean(IServiceImplBean serviceImplBean) {
        this.serviceImplBean = serviceImplBean;
    }

    public String getName() {
        return name;
    }

    public QName getWsdlService() {
        return wsdlService;
    }

    public QName getWsdlPort() {
        return wsdlPort;
    }

    public boolean isMTOMEnabled() {
        return mtomEnabled;
    }

    public String getProtocolBinding() {
        return protocolBinding;
    }

    public String getServiceEndpointInterface() {
        return serviceEndpointInterface;
    }

    public IServiceImplBean getServiceImplBean() {
        return serviceImplBean;
    }

    public IWebserviceDescription getParent() {
        return parent;
    }

    public void setHandlerChains(IHandlerChains handlerChains) {
        this.handlerChains = handlerChains;
    }

    /**
     * @return the <code>handler-chains</code> element.
     */
    public IHandlerChains getHandlerChains() {
        return this.handlerChains;
    }
}
