/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ws.impl.xml.struct;

import org.ow2.util.ee.metadata.ws.api.xml.struct.IWebserviceDescription;
import org.ow2.util.ee.metadata.ws.api.xml.struct.IPortComponent;

import java.util.List;
import java.util.ArrayList;

/**
 * The WebserviceDescription is ...
 *
 * @author Guillaume Sauthier
 */
public class WebserviceDescription implements IWebserviceDescription {

    /**
     * XML element's name.
     */
    public static final String NAME = "webservice-description";

    /**
     * Name of this description.
     */
    private String name;

    /**
     * Value of the <code>wsdl-file</code> element (may be null).
     */
    private String wsdlFile;

    /**
     * List of childs port-components.
     */
    private List<IPortComponent> portComponents;

    /**
     * Default constructor.
     */
    public WebserviceDescription() {
        this.portComponents = new ArrayList<IPortComponent>();
    }

    public void setName(String name) {
        this.name = name;
    }

    public void setWsdlFile(String wsdlFile) {
        this.wsdlFile = wsdlFile;
    }

    public void addPortComponent(IPortComponent portComponent) {
        this.portComponents.add(portComponent);
    }

    public String getName() {
        return name;
    }

    public String getWsdlFile() {
        return wsdlFile;
    }

    public List<IPortComponent> getPortComponents() {
        return portComponents;
    }
}
