/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ws.impl.xml.struct;

import org.ow2.util.ee.metadata.ws.api.xml.struct.IWebservices;
import org.ow2.util.ee.metadata.ws.api.xml.struct.IWebserviceDescription;
import org.ow2.util.ee.metadata.ws.api.xml.struct.IPortComponent;
import org.ow2.util.ee.metadata.ws.api.xml.struct.IServiceImplBean;

import java.util.List;
import java.util.ArrayList;

/**
 * The Webservices is ...
 *
 * @author Guillaume Sauthier
 */
public class Webservices implements IWebservices {

    /**
     * Value of the @version attribute.
     */
    private String version;

    /**
     * List of descriptions declared in this file.
     */
    private List<IWebserviceDescription> webserviceDescriptions;

    /**
     * Default constructor.
     */
    public Webservices() {
        this.webserviceDescriptions = new ArrayList<IWebserviceDescription>();
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public void addWebserviceDescription(IWebserviceDescription webserviceDescription) {
        this.webserviceDescriptions.add(webserviceDescription);
    }

    public String getVersion() {
        return version;
    }

    public List<IWebserviceDescription> getWebserviceDescriptions() {
        return webserviceDescriptions;
    }

    public IPortComponent findPortComponent(String sibLink) {

        for (IWebserviceDescription description : webserviceDescriptions) {

            for (IPortComponent portComponent : description.getPortComponents()) {

                IServiceImplBean sib = portComponent.getServiceImplBean();

                if (sibLink.equals(sib.getServletLink()) || sibLink.equals(sib.getEjbLink())) {
                    return portComponent;
                }
            }
        }
        return null;
    }
}
